@@ -18,7 +18,7 @@
 #define FAIL_ON_GRIB_ERROR(function, gribHandle, key, ...)                                                                 \
   do                                                                                                                       \
     {                                                                                                                      \
-      const int errorCode = (int) function(gribHandle, key, __VA_ARGS__);                                                  \
+      int errorCode = (int) function(gribHandle, key, __VA_ARGS__);                                                        \
       if (errorCode)                                                                                                       \
         {                                                                                                                  \
           fprintf(stderr, "%s:%d: Error in function `%s`: `%s` returned error code %d for key \"%s\"", __FILE__, __LINE__, \
@@ -179,7 +179,7 @@ gribEditionNumber(grib_handle *gh)
 // This return value of this should be passed to a call to resetTz(), it is a malloc'ed string with the content of the TZ
 // environment variable before the call (or NULL if that was not set).
 static char *
-setUtc()
+setUtc(void)
 {
   char *temp = getenv("TZ"), *result = NULL;
   if (temp) result = strdup(temp);
@@ -573,7 +573,7 @@ has_ni(grib_handle *gh)
 int
 gribapiGetGridType(grib_handle *gh)
 {
-  const long gridDefinitionTemplateNumber = gribGetLongDefault(gh, "gridDefinitionTemplateNumber", -1);
+  long gridDefinitionTemplateNumber = gribGetLongDefault(gh, "gridDefinitionTemplateNumber", -1);
   switch (gridDefinitionTemplateNumber)
     {
     case GRIB2_GTYPE_LATLON: return has_ni(gh) ? GRID_LONLAT : GRID_GENERIC;
@@ -584,6 +584,7 @@ gribapiGetGridType(grib_handle *gh)
     case GRIB2_GTYPE_SPECTRAL: return GRID_SPECTRAL;
     case GRIB2_GTYPE_GME: return GRID_GME;
     case GRIB2_GTYPE_UNSTRUCTURED: return GRID_UNSTRUCTURED;
+    case GRIB2_GTYPE_HEALPIX: return CDI_PROJ_HEALPIX;
     default:
       {
         static bool lwarn = true;
@@ -675,9 +676,9 @@ gribapiGetGridRegular(grib_handle *gh, grid_t *grid, int editionNumber, int grid
 {
   long lpar;
   FAIL_ON_GRIB_ERROR(grib_get_long, gh, "Ni", &lpar);
-  const size_t nlon = (size_t) lpar;
+  size_t nlon = (size_t) lpar;
   FAIL_ON_GRIB_ERROR(grib_get_long, gh, "Nj", &lpar);
-  const size_t nlat = (size_t) lpar;
+  size_t nlat = (size_t) lpar;
 
   if (gridtype == GRID_GAUSSIAN)
     {
@@ -756,9 +757,9 @@ gribapiGetGridProj(grib_handle *gh, grid_t *grid, size_t numberOfPoints)
 {
   long lpar;
   FAIL_ON_GRIB_ERROR(grib_get_long, gh, "Nx", &lpar);
-  const size_t nlon = (size_t) lpar;
+  size_t nlon = (size_t) lpar;
   FAIL_ON_GRIB_ERROR(grib_get_long, gh, "Ny", &lpar);
-  const size_t nlat = (size_t) lpar;
+  size_t nlat = (size_t) lpar;
 
   if (numberOfPoints != nlon * nlat) Error("numberOfPoints (%zu) and gridSize (%zu) differ!", numberOfPoints, nlon * nlat);
 
@@ -780,6 +781,12 @@ gribapiGetGridProj(grib_handle *gh, grid_t *grid, size_t numberOfPoints)
   grid->y.flag = 2;
 }
 
+static void
+gribapiGetGridHealpix(grib_handle *gh, grid_t *grid, size_t numberOfPoints)
+{
+  grid->size = numberOfPoints;
+}
+
 static void
 gribapiGetGridSpectral(grib_handle *gh, grid_t *grid, size_t datasize)
 {
@@ -841,12 +848,12 @@ static void
 gribapiGetGridGeneric(grib_handle *gh, grid_t *grid, size_t numberOfPoints)
 {
   long lpar;
-  const size_t nlon = (grib_get_long(gh, "Ni", &lpar) == 0) ? (size_t) lpar : 0;
-  const size_t nlat = (grib_get_long(gh, "Nj", &lpar) == 0) ? (size_t) lpar : 0;
+  size_t nlon = (grib_get_long(gh, "Ni", &lpar) == 0) ? (size_t) lpar : 0;
+  size_t nlat = (grib_get_long(gh, "Nj", &lpar) == 0) ? (size_t) lpar : 0;
 
   grid->size = numberOfPoints;
 
-  const bool lgeneric = (nlon > 0 && nlat > 0 && nlon * nlat == numberOfPoints);
+  bool lgeneric = (nlon > 0 && nlat > 0 && nlon * nlat == numberOfPoints);
   grid->x.size = lgeneric ? nlon : 0;
   grid->y.size = lgeneric ? nlat : 0;
 }
@@ -856,10 +863,10 @@ bool
 gribapiGetGrid(grib_handle *gh, grid_t *grid)
 {
   bool uvRelativeToGrid = false;
-  const long editionNumber = gribEditionNumber(gh);
+  long editionNumber = gribEditionNumber(gh);
   int gridtype = gribapiGetGridType(gh);
   int projtype = (gridtype == GRID_PROJECTION && gribapiGetIsRotated(gh)) ? CDI_PROJ_RLL : CDI_UNDEFID;
-  if (gridtype == CDI_PROJ_LCC || gridtype == CDI_PROJ_STERE)
+  if (gridtype == CDI_PROJ_LCC || gridtype == CDI_PROJ_STERE || gridtype == CDI_PROJ_HEALPIX)
     {
       projtype = gridtype;
       gridtype = GRID_PROJECTION;
@@ -897,6 +904,10 @@ gribapiGetGrid(grib_handle *gh, grid_t *grid)
     {
       gribapiGetGridProj(gh, grid, numberOfPoints);
     }
+  else if (projtype == CDI_PROJ_HEALPIX)
+    {
+      gribapiGetGridHealpix(gh, grid, numberOfPoints);
+    }
   else if (gridtype == GRID_SPECTRAL)
     {
       gribapiGetGridSpectral(gh, grid, datasize);
@@ -918,15 +929,16 @@ gribapiGetGrid(grib_handle *gh, grid_t *grid)
       Error("Unsupported grid type: %s", gridNamePtr(gridtype));
     }
 
-  if (gridtype == GRID_GAUSSIAN || gridtype == GRID_LONLAT || projtype == CDI_PROJ_RLL || projtype == CDI_PROJ_LCC)
+  if (gridtype == GRID_GAUSSIAN || gridtype == GRID_LONLAT || projtype == CDI_PROJ_RLL || projtype == CDI_PROJ_LCC
+      || projtype == CDI_PROJ_HEALPIX)
     {
-      long temp;
+      long temp = 0;
       GRIB_CHECK(grib_get_long(gh, "uvRelativeToGrid", &temp), 0);
       assert(temp == 0 || temp == 1);
       uvRelativeToGrid = (bool) temp;
     }
 
-  if (gridtype == GRID_GAUSSIAN || gridtype == GRID_LONLAT || gridtype == GRID_PROJECTION)
+  if (gridtype == GRID_GAUSSIAN || gridtype == GRID_LONLAT || (gridtype == GRID_PROJECTION && projtype != CDI_PROJ_HEALPIX))
     {
       long iScansNegatively, jScansPositively, jPointsAreConsecutive;
       GRIB_CHECK(grib_get_long(gh, "iScansNegatively", &iScansNegatively), 0);
