@@ -63,7 +63,7 @@ cgribexInit(cgribexrec_t *cgribexp)
 }
 
 void *
-cgribexNew()
+cgribexNew(void)
 {
   cgribexrec_t *cgribexp = (cgribexrec_t *) Malloc(sizeof(cgribexrec_t));
   cgribexInit(cgribexp);
@@ -1850,6 +1850,11 @@ cgribexDefGrid(int *isec1, int *isec2, double *fsec2, int *isec4, int gridID, in
         ISEC1_Sec2Or3Flag = 0;
         break;
       }
+    case CDI_PROJ_HEALPIX:
+      {
+        Error("CGRIBEX library doesn't support HEALPix grids!");
+        break;
+      }
     default:
       {
         static bool lwarn = true;
@@ -2023,14 +2028,14 @@ cgribexDefEnsembleVar(int *isec1, int vlistID, int varID)
   // Put2Byte(isec1[38]);        // individual ensemble member
   // Put2Byte(isec1[39]);        // number of forecasts in ensemble
 
-  int perturbationNumber, numberOfForecastsInEnsemble, typeOfEnsembleForecast;
-  int r1 = cdiInqKeyInt(vlistID, varID, CDI_KEY_PERTURBATIONNUMBER, &perturbationNumber);
-  int r2 = cdiInqKeyInt(vlistID, varID, CDI_KEY_NUMBEROFFORECASTSINENSEMBLE, &numberOfForecastsInEnsemble);
-  int r3 = cdiInqKeyInt(vlistID, varID, CDI_KEY_TYPEOFENSEMBLEFORECAST, &typeOfEnsembleForecast);
-
-  if (r1 == 0 && r2 == 0 && r3 == 0)
+  if (ISEC1_CenterID == 252)
     {
-      if (ISEC1_CenterID == 252)
+      int perturbationNumber, numberOfForecastsInEnsemble, typeOfEnsembleForecast;
+      int r1 = cdiInqKeyInt(vlistID, varID, CDI_KEY_PERTURBATIONNUMBER, &perturbationNumber);
+      int r2 = cdiInqKeyInt(vlistID, varID, CDI_KEY_NUMBEROFFORECASTSINENSEMBLE, &numberOfForecastsInEnsemble);
+      int r3 = cdiInqKeyInt(vlistID, varID, CDI_KEY_TYPEOFENSEMBLEFORECAST, &typeOfEnsembleForecast);
+
+      if (r1 == 0 && r2 == 0 && r3 == 0)
         {
           ISEC1_LocalFLag = 1;
           isec1[36] = 1;
