@@ -301,8 +301,7 @@ changeLtype(int vlistID2, int nch, const std::vector<int> &chltypes)
     }
 }
 
-void *
-Change(void *process)
+class ModuleChange
 {
   const char *chname = nullptr;
   int chcode = 0;
@@ -310,125 +309,152 @@ Change(void *process)
   std::vector<int> chints, chltypes;
   std::vector<double> chlevels;
 
-  cdo_initialize(process);
+  CdoStreamID streamID1;
+  int taxisID1;
 
-  // clang-format off
-  auto CHCODE   = cdo_operator_add("chcode",   0, 0, "pairs of old and new code numbers");
-  auto CHTABNUM = cdo_operator_add("chtabnum", 0, 0, "pairs of old and new GRIB1 table numbers");
-  auto CHPARAM  = cdo_operator_add("chparam",  0, 0, "pairs of old and new parameter identifiers");
-  auto CHNAME   = cdo_operator_add("chname",   0, 0, "pairs of old and new variable names");
-  auto CHUNIT   = cdo_operator_add("chunit",   0, 0, "pairs of old and new variable units");
-  auto CHLEVEL  = cdo_operator_add("chlevel",  0, 0, "pairs of old and new levels");
-  auto CHLEVELC = cdo_operator_add("chlevelc", 0, 0, "code number, old and new level");
-  auto CHLEVELV = cdo_operator_add("chlevelv", 0, 0, "variable name, old and new level");
-  auto CHLTYPE  = cdo_operator_add("chltype",  0, 0, "pairs of old and new type");
-  // clang-format on
-
-  auto operatorID = cdo_operator_id();
-
-  operator_input_arg(cdo_operator_enter(operatorID));
-
-  auto nch = cdo_operator_argc();
-
-  if (operatorID == CHCODE || operatorID == CHTABNUM)
-    {
-      if (nch % 2) cdo_abort("Odd number of input arguments!");
-      chints.resize(nch);
-      for (int i = 0; i < nch; ++i) chints[i] = parameter_to_int(cdo_operator_argv(i));
-    }
-  else if (operatorID == CHPARAM || operatorID == CHNAME || operatorID == CHUNIT)
-    {
-      if (nch % 2) cdo_abort("Odd number of input arguments!");
-      chnames.resize(nch);
-      for (int i = 0; i < nch; ++i) chnames[i] = &cdo_operator_argv(i)[0];
-    }
-  else if (operatorID == CHLEVEL)
-    {
-      if (nch % 2) cdo_abort("Odd number of input arguments!");
-      chlevels.resize(nch);
-      for (int i = 0; i < nch; ++i) chlevels[i] = parameter_to_double(cdo_operator_argv(i));
-    }
-  else if (operatorID == CHLEVELC)
-    {
-      operator_check_argc(3);
-
-      chcode = parameter_to_int(cdo_operator_argv(0));
-      chlevels.resize(2);
-      chlevels[0] = parameter_to_double(cdo_operator_argv(1));
-      chlevels[1] = parameter_to_double(cdo_operator_argv(2));
-    }
-  else if (operatorID == CHLEVELV)
-    {
-      operator_check_argc(3);
-
-      chname = cdo_operator_argv(0).c_str();
-      chlevels.resize(2);
-      chlevels[0] = parameter_to_double(cdo_operator_argv(1));
-      chlevels[1] = parameter_to_double(cdo_operator_argv(2));
-    }
-  else if (operatorID == CHLTYPE)
-    {
-      if (nch % 2) cdo_abort("Odd number of input arguments!");
-      chltypes.resize(nch);
-      for (int i = 0; i < nch; ++i) chltypes[i] = parameter_to_int(cdo_operator_argv(i));
-    }
-
-  auto streamID1 = cdo_open_read(0);
-
-  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  auto vlistID2 = vlistDuplicate(vlistID1);
-
-  auto taxisID1 = vlistInqTaxis(vlistID1);
-  auto taxisID2 = taxisDuplicate(taxisID1);
-  vlistDefTaxis(vlistID2, taxisID2);
+  CdoStreamID streamID2;
+  int taxisID2;
 
   VarList varList1;
-  varListInit(varList1, vlistID1);
-
-  // clang-format off
-  if      (operatorID == CHCODE)   changeCode(varList1, vlistID2, nch, chints);
-  else if (operatorID == CHTABNUM) changeTabnum(vlistID2, nch, chints);
-  else if (operatorID == CHPARAM)  changeParam(varList1, vlistID2, nch, chnames);
-  else if (operatorID == CHNAME)   changeName(varList1, vlistID2, nch, chnames);
-  else if (operatorID == CHUNIT)   changeUnit(varList1, vlistID2, nch, chnames);
-  else if (operatorID == CHLEVEL)  changeLevel(vlistID2, nch, chlevels);
-  else if (operatorID == CHLEVELC) changeLevelByCode(chcode, vlistID2, chlevels);
-  else if (operatorID == CHLEVELV) changeLevelByName(chname, varList1, vlistID2, chlevels);
-  else if (operatorID == CHLTYPE)  changeLtype(vlistID2, nch, chltypes);
-  // clang-format on
-
-  auto streamID2 = cdo_open_write(1);
-  cdo_def_vlist(streamID2, vlistID2);
-
   Field field;
 
-  int tsID = 0;
-  while (true)
-    {
-      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-      if (nrecs == 0) break;
+public:
+  void
+  init(void *process)
+  {
+    cdo_initialize(process);
 
-      cdo_taxis_copy_timestep(taxisID2, taxisID1);
-      cdo_def_timestep(streamID2, tsID);
+    // clang-format off
+    auto CHCODE   = cdo_operator_add("chcode",   0, 0, "pairs of old and new code numbers");
+    auto CHTABNUM = cdo_operator_add("chtabnum", 0, 0, "pairs of old and new GRIB1 table numbers");
+    auto CHPARAM  = cdo_operator_add("chparam",  0, 0, "pairs of old and new parameter identifiers");
+    auto CHNAME   = cdo_operator_add("chname",   0, 0, "pairs of old and new variable names");
+    auto CHUNIT   = cdo_operator_add("chunit",   0, 0, "pairs of old and new variable units");
+    auto CHLEVEL  = cdo_operator_add("chlevel",  0, 0, "pairs of old and new levels");
+    auto CHLEVELC = cdo_operator_add("chlevelc", 0, 0, "code number, old and new level");
+    auto CHLEVELV = cdo_operator_add("chlevelv", 0, 0, "variable name, old and new level");
+    auto CHLTYPE  = cdo_operator_add("chltype",  0, 0, "pairs of old and new type");
+    // clang-format on
 
-      for (int recID = 0; recID < nrecs; ++recID)
-        {
-          int varID, levelID;
-          cdo_inq_record(streamID1, &varID, &levelID);
-          cdo_def_record(streamID2, varID, levelID);
+    auto operatorID = cdo_operator_id();
 
-          field.init(varList1[varID]);
-          cdo_read_record(streamID1, field);
-          cdo_write_record(streamID2, field);
-        }
+    operator_input_arg(cdo_operator_enter(operatorID));
 
-      tsID++;
-    }
+    auto nch = cdo_operator_argc();
 
-  cdo_stream_close(streamID1);
-  cdo_stream_close(streamID2);
+    if (operatorID == CHCODE || operatorID == CHTABNUM)
+      {
+        if (nch % 2) cdo_abort("Odd number of input arguments!");
+        chints.resize(nch);
+        for (int i = 0; i < nch; ++i) chints[i] = parameter_to_int(cdo_operator_argv(i));
+      }
+    else if (operatorID == CHPARAM || operatorID == CHNAME || operatorID == CHUNIT)
+      {
+        if (nch % 2) cdo_abort("Odd number of input arguments!");
+        chnames.resize(nch);
+        for (int i = 0; i < nch; ++i) chnames[i] = &cdo_operator_argv(i)[0];
+      }
+    else if (operatorID == CHLEVEL)
+      {
+        if (nch % 2) cdo_abort("Odd number of input arguments!");
+        chlevels.resize(nch);
+        for (int i = 0; i < nch; ++i) chlevels[i] = parameter_to_double(cdo_operator_argv(i));
+      }
+    else if (operatorID == CHLEVELC)
+      {
+        operator_check_argc(3);
 
-  cdo_finish();
+        chcode = parameter_to_int(cdo_operator_argv(0));
+        chlevels.resize(2);
+        chlevels[0] = parameter_to_double(cdo_operator_argv(1));
+        chlevels[1] = parameter_to_double(cdo_operator_argv(2));
+      }
+    else if (operatorID == CHLEVELV)
+      {
+        operator_check_argc(3);
+
+        chname = cdo_operator_argv(0).c_str();
+        chlevels.resize(2);
+        chlevels[0] = parameter_to_double(cdo_operator_argv(1));
+        chlevels[1] = parameter_to_double(cdo_operator_argv(2));
+      }
+    else if (operatorID == CHLTYPE)
+      {
+        if (nch % 2) cdo_abort("Odd number of input arguments!");
+        chltypes.resize(nch);
+        for (int i = 0; i < nch; ++i) chltypes[i] = parameter_to_int(cdo_operator_argv(i));
+      }
+
+    streamID1 = cdo_open_read(0);
+
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID2 = vlistDuplicate(vlistID1);
+
+    taxisID1 = vlistInqTaxis(vlistID1);
+    taxisID2 = taxisDuplicate(taxisID1);
+    vlistDefTaxis(vlistID2, taxisID2);
+
+    varList_init(varList1, vlistID1);
+
+    // clang-format off
+    if      (operatorID == CHCODE)   changeCode(varList1, vlistID2, nch, chints);
+    else if (operatorID == CHTABNUM) changeTabnum(vlistID2, nch, chints);
+    else if (operatorID == CHPARAM)  changeParam(varList1, vlistID2, nch, chnames);
+    else if (operatorID == CHNAME)   changeName(varList1, vlistID2, nch, chnames);
+    else if (operatorID == CHUNIT)   changeUnit(varList1, vlistID2, nch, chnames);
+    else if (operatorID == CHLEVEL)  changeLevel(vlistID2, nch, chlevels);
+    else if (operatorID == CHLEVELC) changeLevelByCode(chcode, vlistID2, chlevels);
+    else if (operatorID == CHLEVELV) changeLevelByName(chname, varList1, vlistID2, chlevels);
+    else if (operatorID == CHLTYPE)  changeLtype(vlistID2, nch, chltypes);
+    // clang-format on
+
+    streamID2 = cdo_open_write(1);
+    cdo_def_vlist(streamID2, vlistID2);
+  }
+  void
+  run()
+  {
+    int tsID = 0;
+    while (true)
+      {
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        if (nrecs == 0) break;
+
+        cdo_taxis_copy_timestep(taxisID2, taxisID1);
+        cdo_def_timestep(streamID2, tsID);
+
+        for (int recID = 0; recID < nrecs; ++recID)
+          {
+            int varID, levelID;
+            cdo_inq_record(streamID1, &varID, &levelID);
+            cdo_def_record(streamID2, varID, levelID);
+
+            field.init(varList1[varID]);
+            cdo_read_record(streamID1, field);
+            cdo_write_record(streamID2, field);
+          }
+
+        tsID++;
+      }
+  }
+  void
+  close()
+  {
+    cdo_stream_close(streamID1);
+    cdo_stream_close(streamID2);
+
+    cdo_finish();
+  }
+};
+
+void *
+Change(void *process)
+{
+  ModuleChange change;
+
+  change.init(process);
+  change.run();
+  change.close();
 
   return nullptr;
 }
