@@ -18,36 +18,38 @@
 #include "cdo_vlist.h"
 #include "param_conversion.h"
 
+template <typename T>
 static void
-operator_IFTHENC(size_t n, double mv, const Varray<double> &vIn, const double cVal, Varray<double> &vOut)
+operator_IFTHENC(size_t n, T mv, Varray<T> &v, T cVal)
 {
+  constexpr T nullVal{ 0 };
   if (std::isnan(mv))
-    for (size_t i = 0; i < n; ++i) vOut[i] = (!dbl_is_equal(vIn[i], mv) && !dbl_is_equal(vIn[i], 0.0)) ? cVal : mv;
+    for (size_t i = 0; i < n; ++i) v[i] = (!dbl_is_equal(v[i], mv) && !dbl_is_equal(v[i], nullVal)) ? cVal : mv;
   else
-    for (size_t i = 0; i < n; ++i) vOut[i] = (!is_equal(vIn[i], mv) && !is_equal(vIn[i], 0.0)) ? cVal : mv;
+    for (size_t i = 0; i < n; ++i) v[i] = (!is_equal(v[i], mv) && !is_equal(v[i], nullVal)) ? cVal : mv;
 }
 
+template <typename T>
 static void
-operator_IFNOTTHENC(size_t n, double mv, const Varray<double> &vIn, const double cVal, Varray<double> &vOut)
+operator_IFNOTTHENC(size_t n, T mv, Varray<T> &v, T cVal)
 {
+  constexpr T nullVal{ 0 };
   if (std::isnan(mv))
-    for (size_t i = 0; i < n; ++i) vOut[i] = (!dbl_is_equal(vIn[i], mv) && dbl_is_equal(vIn[i], 0.0)) ? cVal : mv;
+    for (size_t i = 0; i < n; ++i) v[i] = (!dbl_is_equal(v[i], mv) && dbl_is_equal(v[i], nullVal)) ? cVal : mv;
   else
-    for (size_t i = 0; i < n; ++i) vOut[i] = (!is_equal(vIn[i], mv) && is_equal(vIn[i], 0.0)) ? cVal : mv;
+    for (size_t i = 0; i < n; ++i) v[i] = (!is_equal(v[i], mv) && is_equal(v[i], nullVal)) ? cVal : mv;
 }
 
 class ModuleCondc
 {
-
   CdoStreamID streamID1;
-  int vlistID1;
   int taxisID1;
+
   CdoStreamID streamID2;
   int taxisID2;
 
   int operatorID;
-
-  double rc;
+  double rconst;
 
   VarList varList;
 
@@ -67,11 +69,11 @@ public:
     operatorID = cdo_operator_id();
 
     operator_input_arg("constant value");
-    rc = parameter_to_double(cdo_operator_argv(0));
+    rconst = parameter_to_double(cdo_operator_argv(0));
 
     streamID1 = cdo_open_read(0);
 
-    vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
     auto vlistID2 = vlistDuplicate(vlistID1);
 
     vlist_unpack(vlistID2);
@@ -89,9 +91,7 @@ public:
   void
   run()
   {
-    auto gridsizemax = vlistGridsizeMax(vlistID1);
-    Varray<double> vaIn(gridsizemax);
-    Varray<double> vaOut(gridsizemax);
+    Field field;
 
     int tsID = 0;
     while (true)
@@ -106,23 +106,34 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            size_t nmiss;
-            cdo_read_record(streamID1, vaIn.data(), &nmiss);
+            field.init(varList[varID]);
+            cdo_read_record(streamID1, field);
 
-            auto missval = varList[varID].missval;
-            auto ngp = varList[varID].gridsize;
+            auto missval = field.missval;
+            auto ngp = field.size;
 
+            auto nmiss = field.nmiss;
             if (nmiss > 0) cdo_check_missval(missval, varList[varID].name);
 
             // clang-format off
-            if      (operatorID == IFTHENC)    operator_IFTHENC(ngp, missval, vaIn, rc, vaOut);
-            else if (operatorID == IFNOTTHENC) operator_IFNOTTHENC(ngp, missval, vaIn, rc, vaOut);
-            else cdo_abort("Operator not implemented!");
+            if (field.memType == MemType::Float)
+              {
+                if      (operatorID == IFTHENC)    operator_IFTHENC(ngp, (float) missval, field.vec_f, (float) rconst);
+                else if (operatorID == IFNOTTHENC) operator_IFNOTTHENC(ngp, (float) missval, field.vec_f, (float) rconst);
+                else cdo_abort("Operator not implemented!");
+              }
+            else
+              {
+                if      (operatorID == IFTHENC)    operator_IFTHENC(ngp, missval, field.vec_d, rconst);
+                else if (operatorID == IFNOTTHENC) operator_IFNOTTHENC(ngp, missval, field.vec_d, rconst);
+                else cdo_abort("Operator not implemented!");
+              }
             // clang-format on
 
-            nmiss = varray_num_mv(ngp, vaOut, missval);
+            if (nmiss > 0) field_num_mv(field);
+
             cdo_def_record(streamID2, varID, levelID);
-            cdo_write_record(streamID2, vaOut.data(), nmiss);
+            cdo_write_record(streamID2, field);
           }
 
         tsID++;
