@@ -15,6 +15,7 @@
 #include "param_conversion.h"
 #include <mpim_grid.h>
 #include "util_files.h"
+#include "util_string.h"
 
 struct GridInfo1
 {
@@ -36,7 +37,6 @@ struct DistgridInfo
   int gridID;
 };
 
-
 static void
 calc_boundbox(size_t gridsize2, size_t nv, bool withBounds, const Varray<double> &xvals2, const Varray<double> &yvals2,
               const Varray<double> &xbounds2, const Varray<double> &ybounds2, double *lonBounds, double *latBounds)
@@ -93,21 +93,21 @@ static void
 gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridInfo, size_t nxvals, size_t nyvals, size_t nxblocks,
                size_t nyblocks, size_t nsplit)
 {
-  const auto gridID1 = gridInfo1.gridID;
-  const auto gridtype = gridInfo1.gridtype;
-  const auto isReg2d = gridInfo1.isReg2d;
-  const auto isUnstructured = (gridtype == GRID_UNSTRUCTURED);
-  const auto isCurvilinear = (gridtype == GRID_CURVILINEAR);
-  const auto isRegular
+  auto gridID1 = gridInfo1.gridID;
+  auto gridtype = gridInfo1.gridtype;
+  auto isReg2d = gridInfo1.isReg2d;
+  auto isUnstructured = (gridtype == GRID_UNSTRUCTURED);
+  auto isCurvilinear = (gridtype == GRID_CURVILINEAR);
+  auto isRegular
       = (gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN || gridtype == GRID_GENERIC || gridtype == GRID_PROJECTION);
   if (!isRegular && !isCurvilinear && !isUnstructured) cdo_abort("Unsupported grid type: %s!", gridNamePtr(gridtype));
 
-  const auto nx = gridInqXsize(gridID1);
+  auto nx = gridInqXsize(gridID1);
   const size_t ny = isUnstructured ? 1 : gridInqYsize(gridID1);
 
-  const auto lxcoord = (gridInqXvals(gridID1, nullptr) > 0);
-  const auto lycoord = (gridInqYvals(gridID1, nullptr) > 0);
-  const auto withBounds = (!isRegular && gridHasBounds(gridID1));
+  auto lxcoord = (gridInqXvals(gridID1, nullptr) > 0);
+  auto lycoord = (gridInqYvals(gridID1, nullptr) > 0);
+  auto withBounds = (!isRegular && gridHasBounds(gridID1));
 
   std::vector<size_t> xlsize(nxblocks), ylsize(nyblocks);
 
@@ -121,8 +121,8 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
   if (Options::cdoVerbose)
     for (size_t iy = 0; iy < nyblocks; ++iy) cdo_print("yblock %zu: size=%zu", iy, ylsize[iy]);
 
-  const auto nxvmax = std::max(nxvals, xlsize[nxblocks - 1]);
-  const auto nyvmax = std::max(nyvals, ylsize[nyblocks - 1]);
+  auto nxvmax = std::max(nxvals, xlsize[nxblocks - 1]);
+  auto nyvmax = std::max(nyvals, ylsize[nyblocks - 1]);
 
   Varray<double> xpvals, ypvals;
   Varray<double> xvals, yvals, xbounds, ybounds;
@@ -164,7 +164,7 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
   for (size_t iy = 0; iy < nyblocks; ++iy)
     for (size_t ix = 0; ix < nxblocks; ++ix)
       {
-        const auto offset = iy * nyvals * nx + ix * nxvals;
+        auto offset = iy * nyvals * nx + ix * nxvals;
         auto gridsize2 = xlsize[ix] * ylsize[iy];
         if (!isReg2d) distgridInfo[index].cellindex.resize(gridsize2);
         auto &cellindex = distgridInfo[index].cellindex;
@@ -185,12 +185,20 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
                 {
                   if (lxcoord) xvals2[gridsize2] = xvals[offset + j * nx + i];
                   if (lycoord) yvals2[gridsize2] = yvals[offset + j * nx + i];
+                  if (lxcoord) lonBounds[0] = std::min(lonBounds[0], xvals2[gridsize2]);
+                  if (lxcoord) lonBounds[1] = std::max(lonBounds[1], xvals2[gridsize2]);
+                  if (lycoord) latBounds[0] = std::min(latBounds[0], yvals2[gridsize2]);
+                  if (lycoord) latBounds[1] = std::max(latBounds[1], yvals2[gridsize2]);
                   if (withBounds)
                     {
                       for (size_t k = 0; k < nv; ++k)
                         {
                           xbounds2[gridsize2 * nv + k] = xbounds[(offset + j * nx + i) * nv + k];
                           ybounds2[gridsize2 * nv + k] = ybounds[(offset + j * nx + i) * nv + k];
+                          lonBounds[0] = std::min(lonBounds[0], xbounds2[gridsize2 * nv + k]);
+                          lonBounds[1] = std::max(lonBounds[1], xbounds2[gridsize2 * nv + k]);
+                          latBounds[0] = std::min(latBounds[0], ybounds2[gridsize2 * nv + k]);
+                          latBounds[1] = std::max(latBounds[1], ybounds2[gridsize2 * nv + k]);
                         }
                     }
                 }
@@ -201,8 +209,8 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
 
         if (!isRegular && lxcoord && lycoord)
           calc_boundbox(gridsize2, nv, withBounds, xvals2, yvals2, xbounds2, ybounds2, lonBounds, latBounds);
- 
-        const auto gridID2 = gridCreate(gridtype, gridsize2);
+
+        auto gridID2 = gridCreate(gridtype, gridsize2);
         if (gridtype != GRID_UNSTRUCTURED)
           {
             gridDefXsize(gridID2, xlsize[ix]);
@@ -239,17 +247,17 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
               }
           }
 
-        const auto projID1 = gridInqProj(gridID1);
+        auto projID1 = gridInqProj(gridID1);
         if (projID1 != CDI_UNDEFID && gridInqType(projID1) == GRID_PROJECTION)
           {
-            const auto projID2 = gridCreate(GRID_PROJECTION, gridsize2);
+            auto projID2 = gridCreate(GRID_PROJECTION, gridsize2);
             gridDefXsize(projID2, xlsize[ix]);
             gridDefYsize(projID2, ylsize[iy]);
 
             grid_copy_names(projID1, projID2);
             grid_copy_mapping(projID1, projID2);
 
-            const auto lxpcoord = (gridInqXvals(projID1, nullptr) > 0);
+            auto lxpcoord = (gridInqXvals(projID1, nullptr) > 0);
             if (lxpcoord)
               {
                 if (!xpvals.size())
@@ -259,7 +267,7 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
                   }
                 gridDefXvals(projID2, &xpvals[ix * nxvals]);
               }
-            const auto lypcoord = (gridInqYvals(projID1, nullptr) > 0);
+            auto lypcoord = (gridInqYvals(projID1, nullptr) > 0);
             if (lypcoord)
               {
                 if (!ypvals.size())
@@ -280,7 +288,7 @@ gen_dist_grids(const GridInfo1 &gridInfo1, std::vector<DistgridInfo> &distgridIn
         if (index > nsplit) cdo_abort("Internal problem, index exceeded bounds!");
       }
 
-  const auto numBlocks = index;
+  auto numBlocks = index;
 
   for (size_t i = 0; i < numBlocks; ++i)
     {
@@ -297,13 +305,13 @@ dist_cells_reg2d(const Field &field1, Field &field2, const DistgridInfo &distgri
 {
   if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
 
-  const auto nx = distgridInfo.nx;
-  const auto ny = distgridInfo.ny;
+  auto nx = distgridInfo.nx;
+  auto ny = distgridInfo.ny;
 
   for (size_t j = 0; j < ny; ++j)
     {
-      const auto offset1 = distgridInfo.offset + j * nlon;
-      const auto offset2 = j * nx;
+      auto offset1 = distgridInfo.offset + j * nlon;
+      auto offset2 = j * nx;
 
       if (field1.memType == MemType::Float)
         for (size_t i = 0; i < nx; ++i) field2.vec_f[offset2 + i] = field1.vec_f[offset1 + i];
@@ -317,7 +325,7 @@ dist_cells(const Field &field1, Field &field2, const DistgridInfo &distgridInfo)
 {
   if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
 
-  const auto gridsize = distgridInfo.gridsize;
+  auto gridsize = distgridInfo.gridsize;
   const auto &cellidx = distgridInfo.cellindex;
 
   if (field1.memType == MemType::Float)
@@ -326,204 +334,230 @@ dist_cells(const Field &field1, Field &field2, const DistgridInfo &distgridInfo)
     for (size_t i = 0; i < gridsize; ++i) field2.vec_d[i] = field1.vec_d[cellidx[i]];
 }
 
-void *
-Distgrid(void *process)
+class ModuleDistgrid
 {
-  constexpr size_t MaxBlocks = 99999;
+  size_t MaxBlocks = 99999;
   int gridID1;
   int gridtype = -1;
+  int ngrids;
 
-  cdo_initialize(process);
+  CdoStreamID streamID1;
+  std::vector<CdoStreamID> streamIDs;
 
-  if (process_self().m_ID != 0) cdo_abort("This operator can't be combined with other operators!");
+  unsigned long nsplit;
 
-  operator_input_arg("nxblocks, [nyblocks]");
-  if (cdo_operator_argc() < 1) cdo_abort("Too few arguments!");
-  if (cdo_operator_argc() > 2) cdo_abort("Too many arguments!");
-  size_t nxblocks = parameter_to_int(cdo_operator_argv(0));
-  size_t nyblocks = 1;
-  if (cdo_operator_argc() == 2) nyblocks = parameter_to_int(cdo_operator_argv(1));
-
-  if (nxblocks == 0) cdo_abort("nxblocks has to be greater than 0!");
-  if (nyblocks == 0) cdo_abort("nyblocks has to be greater than 0!");
-
-  const auto streamID1 = cdo_open_read(0);
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-
-  const auto ngrids = vlistNgrids(vlistID1);
-
-  std::vector<GridInfo1> gridInfo1(ngrids);
-  for (int index = 0; index < ngrids; ++index)
-    {
-      const auto gridID = vlistGrid(vlistID1, index);
-      gridInfo1[index].gridID = gridID;
-      gridInfo1[index].gridtype = gridInqType(gridID);
-      gridInfo1[index].gridsize = gridInqSize(gridID);
-      gridInfo1[index].nx = gridInqXsize(gridID);
-      gridInfo1[index].ny = gridInqYsize(gridID);
-      gridInfo1[index].isReg2d = (gridInfo1[index].gridtype != GRID_UNSTRUCTURED);
-    }
+  std::vector<int> vlistIDs;
+  std::vector<GridInfo1> gridInfo1;
+  Field field1, field2;
+  VarList varList1;
+  std::vector<std::vector<DistgridInfo>> distgridInfo;
 
+public:
+  void
+  init(void *process)
   {
-    int index;
-    for (index = 0; index < ngrids; ++index)
+    cdo_initialize(process);
+
+    if (process_self().m_ID != 0) cdo_abort("This operator can't be combined with other operators!");
+
+    operator_input_arg("nxblocks, [nyblocks]");
+    if (cdo_operator_argc() < 1) cdo_abort("Too few arguments!");
+    if (cdo_operator_argc() > 2) cdo_abort("Too many arguments!");
+    size_t nxblocks = parameter_to_int(cdo_operator_argv(0));
+    size_t nyblocks = 1;
+    if (cdo_operator_argc() == 2) nyblocks = parameter_to_int(cdo_operator_argv(1));
+
+    if (nxblocks == 0) cdo_abort("nxblocks has to be greater than 0!");
+    if (nyblocks == 0) cdo_abort("nyblocks has to be greater than 0!");
+
+    streamID1 = cdo_open_read(0);
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+
+    ngrids = vlistNgrids(vlistID1);
+
+    gridInfo1 = std::vector<GridInfo1>(ngrids);
+    for (int index = 0; index < ngrids; ++index)
       {
-        gridID1 = vlistGrid(vlistID1, index);
-        gridtype = gridInqType(gridID1);
-        if (gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN || gridtype == GRID_CURVILINEAR || gridtype == GRID_UNSTRUCTURED
-            || gridtype == GRID_PROJECTION || (gridtype == GRID_GENERIC && gridInqXsize(gridID1) > 0 && gridInqYsize(gridID1) > 0))
-          break;
+        auto gridID = vlistGrid(vlistID1, index);
+        gridInfo1[index].gridID = gridID;
+        gridInfo1[index].gridtype = gridInqType(gridID);
+        gridInfo1[index].gridsize = gridInqSize(gridID);
+        gridInfo1[index].nx = gridInqXsize(gridID);
+        gridInfo1[index].ny = gridInqYsize(gridID);
+        gridInfo1[index].isReg2d = (gridInfo1[index].gridtype != GRID_UNSTRUCTURED);
       }
 
-    if (index == ngrids)
-      cdo_abort("No Lon/Lat, Gaussian, curvilinear or generic grid found (%s data unsupported)!", gridNamePtr(gridtype));
+    {
+      int index;
+      for (index = 0; index < ngrids; ++index)
+        {
+          gridID1 = vlistGrid(vlistID1, index);
+          gridtype = gridInqType(gridID1);
+          if (gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN || gridtype == GRID_CURVILINEAR || gridtype == GRID_UNSTRUCTURED
+              || gridtype == GRID_PROJECTION
+              || (gridtype == GRID_GENERIC && gridInqXsize(gridID1) > 0 && gridInqYsize(gridID1) > 0))
+            break;
+        }
+
+      if (index == ngrids)
+        cdo_abort("No Lon/Lat, Gaussian, curvilinear or generic grid found (%s data unsupported)!", gridNamePtr(gridtype));
+    }
+
+    auto isUnstructured = (gridtype == GRID_UNSTRUCTURED);
+
+    gridID1 = vlistGrid(vlistID1, 0);
+    auto gridsize = gridInqSize(gridID1);
+    auto nx = gridInqXsize(gridID1);
+    const size_t ny = isUnstructured ? 1 : gridInqYsize(gridID1);
+    for (int i = 1; i < ngrids; ++i)
+      {
+        gridID1 = vlistGrid(vlistID1, i);
+        if (gridsize != gridInqSize(gridID1)) cdo_abort("Gridsize must not change!");
+      }
+
+    if (nxblocks > nx)
+      {
+        cdo_print("nxblocks (%zu) greater than nx (%zu), set to %zu!", nxblocks, nx, nx);
+        nxblocks = nx;
+      }
+    if (nyblocks > ny)
+      {
+        cdo_print("nyblocks (%zu) greater than ny (%zu), set to %zu!", nyblocks, ny, ny);
+        nyblocks = ny;
+      }
+
+    auto xinc = nx / nxblocks;
+    auto yinc = ny / nyblocks;
+    if (nx % xinc && nx % (xinc + 1) && nxblocks * (xinc + 1) <= nx) xinc++;
+    if (ny % yinc && ny % (yinc + 1) && nyblocks * (yinc + 1) <= ny) yinc++;
+
+    nsplit = nxblocks * nyblocks;
+    if (nsplit > MaxBlocks) cdo_abort("Too many blocks (max = %d)!", MaxBlocks);
+
+    cdo::set_numfiles(nsplit + 8);
+
+    varList_init(varList1, vlistID1);
+
+    vlistIDs = std::vector<int>(nsplit);
+    streamIDs = std::vector<CdoStreamID>(nsplit);
+
+    distgridInfo = std::vector<std::vector<DistgridInfo>>(ngrids);
+
+    for (int i = 0; i < ngrids; ++i) distgridInfo[i].resize(nsplit);
+
+    for (size_t index = 0; index < nsplit; ++index) vlistIDs[index] = vlistDuplicate(vlistID1);
+
+    if (Options::cdoVerbose) cdo_print("ngrids=%d  nsplit=%zu", ngrids, nsplit);
+
+    for (int i = 0; i < ngrids; ++i)
+      {
+        gen_dist_grids(gridInfo1[i], distgridInfo[i], xinc, yinc, nxblocks, nyblocks, nsplit);
+        /*
+        if ( Options::cdoVerbose )
+          for ( size_t index = 0; index < nsplit; index++ )
+            cdo_print("Block %d,  gridID %d,  gridsize %zu", index+1,
+        distgridInfo[i].gridID[index], gridInqSize(grids[i].gridID[index]));
+        */
+        for (size_t index = 0; index < nsplit; ++index) vlistChangeGridIndex(vlistIDs[index], i, distgridInfo[i][index].gridID);
+      }
+
+    auto fileSuffix = FileUtils::gen_suffix(cdo_inq_filetype(streamID1), vlistID1, cdo_get_stream_name(0));
+
+    if (Options::test && ngrids == 1 && isUnstructured)
+      {
+        printf("#MGF\n");
+        printf("numfiles=%zu\n", nsplit);
+      }
+
+    for (size_t index = 0; index < nsplit; ++index)
+      {
+        auto fileName = cdo_get_obase() + string_format("%05ld", (long)index);
+        if (fileSuffix.size() > 0) fileName += fileSuffix;
+
+        streamIDs[index] = cdo_open_write(fileName.c_str());
+        cdo_def_vlist(streamIDs[index], vlistIDs[index]);
+
+        if (Options::test && ngrids == 1 && isUnstructured)
+          {
+            auto gridsize2 = distgridInfo[0][index].gridsize;
+            auto offset = distgridInfo[0][index].offset;
+            const auto &lons = distgridInfo[0][index].lonBounds;
+            const auto &lats = distgridInfo[0][index].latBounds;
+            printf("--- # %zu\n", index + 1);
+            printf("filename=%s\n", fileName.c_str());
+            printf("numcells=%zu\n", gridsize2);
+            printf("offset=%zu\n", offset);
+            printf("boundbox=%g/%g/%g/%g\n", lons[0], lons[1], lats[0], lats[1]);
+          }
+      }
   }
 
-  const auto isUnstructured = (gridtype == GRID_UNSTRUCTURED);
+  void
+  run()
+  {
+    int tsID = 0;
+    while (true)
+      {
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        if (nrecs == 0) break;
 
-  gridID1 = vlistGrid(vlistID1, 0);
-  const auto gridsize = gridInqSize(gridID1);
-  const auto nx = gridInqXsize(gridID1);
-  const size_t ny = isUnstructured ? 1 : gridInqYsize(gridID1);
-  for (int i = 1; i < ngrids; ++i)
-    {
-      gridID1 = vlistGrid(vlistID1, i);
-      if (gridsize != gridInqSize(gridID1)) cdo_abort("Gridsize must not change!");
-    }
+        for (auto &streamID : streamIDs) cdo_def_timestep(streamID, tsID);
 
-  if (nxblocks > nx)
-    {
-      cdo_print("nxblocks (%zu) greater than nx (%zu), set to %zu!", nxblocks, nx, nx);
-      nxblocks = nx;
-    }
-  if (nyblocks > ny)
-    {
-      cdo_print("nyblocks (%zu) greater than ny (%zu), set to %zu!", nyblocks, ny, ny);
-      nyblocks = ny;
-    }
-
-  auto xinc = nx / nxblocks;
-  auto yinc = ny / nyblocks;
-  if (nx % xinc && nx % (xinc + 1) && nxblocks * (xinc + 1) <= nx) xinc++;
-  if (ny % yinc && ny % (yinc + 1) && nyblocks * (yinc + 1) <= ny) yinc++;
-
-  const auto nsplit = nxblocks * nyblocks;
-  if (nsplit > MaxBlocks) cdo_abort("Too many blocks (max = %d)!", MaxBlocks);
-
-  cdo::set_numfiles(nsplit + 8);
-
-  Field field1, field2;
-
-  VarList varList1;
-  varListInit(varList1, vlistID1);
-
-  std::vector<int> vlistIDs(nsplit);
-  std::vector<CdoStreamID> streamIDs(nsplit);
-
-  std::vector<std::vector<DistgridInfo>> distgridInfo(ngrids);
-  for (int i = 0; i < ngrids; ++i) distgridInfo[i].resize(nsplit);
-
-  for (size_t index = 0; index < nsplit; ++index) vlistIDs[index] = vlistDuplicate(vlistID1);
-
-  if (Options::cdoVerbose) cdo_print("ngrids=%d  nsplit=%zu", ngrids, nsplit);
-
-  for (int i = 0; i < ngrids; ++i)
-    {
-      gen_dist_grids(gridInfo1[i], distgridInfo[i], xinc, yinc, nxblocks, nyblocks, nsplit);
-      /*
-      if ( Options::cdoVerbose )
-        for ( size_t index = 0; index < nsplit; index++ )
-          cdo_print("Block %d,  gridID %d,  gridsize %zu", index+1,
-      distgridInfo[i].gridID[index], gridInqSize(grids[i].gridID[index]));
-      */
-      for (size_t index = 0; index < nsplit; ++index) vlistChangeGridIndex(vlistIDs[index], i, distgridInfo[i][index].gridID);
-    }
-
-  char filename[8192];
-  strcpy(filename, cdo_get_obase().c_str());
-  const int nchars = strlen(filename);
-
-  auto refname = cdo_get_stream_name(0);
-  char filesuffix[32] = { 0 };
-  FileUtils::gen_suffix(filesuffix, sizeof(filesuffix), cdo_inq_filetype(streamID1), vlistID1, refname);
-
-  if (Options::test && ngrids == 1 && isUnstructured)
-    {
-      printf("#MGF\n");
-      printf("numfiles=%zu\n", nsplit);
-    }
-
-  for (size_t index = 0; index < nsplit; ++index)
-    {
-      sprintf(filename + nchars, "%05ld", (long) index);
-      if (filesuffix[0]) sprintf(filename + nchars + 5, "%s", filesuffix);
-
-      streamIDs[index] = cdo_open_write(filename);
-      cdo_def_vlist(streamIDs[index], vlistIDs[index]);
-
-      if (Options::test && ngrids == 1 && isUnstructured)
-        {
-          const auto gridsize2 = distgridInfo[0][index].gridsize;
-          const auto offset = distgridInfo[0][index].offset;
-          const auto &lons = distgridInfo[0][index].lonBounds;
-          const auto &lats = distgridInfo[0][index].latBounds;
-          printf("--- # %zu\n", index + 1);
-          printf("filename=%s\n", filename);
-          printf("numcells=%zu\n", gridsize2);
-          printf("offset=%zu\n", offset);
-          printf("boundbox=%g/%g/%g/%g\n", lons[0], lons[1], lats[0], lats[1]);
-        }
-    }
-
-  int tsID = 0;
-  while (true)
-    {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-      if (nrecs == 0) break;
-
-      for (auto &streamID : streamIDs) cdo_def_timestep(streamID, tsID);
-
-      for (int recID = 0; recID < nrecs; ++recID)
-        {
-          int varID, levelID;
-          cdo_inq_record(streamID1, &varID, &levelID);
-          field1.init(varList1[varID]);
-          cdo_read_record(streamID1, field1);
+        for (int recID = 0; recID < nrecs; ++recID)
+          {
+            int varID, levelID;
+            cdo_inq_record(streamID1, &varID, &levelID);
+            field1.init(varList1[varID]);
+            cdo_read_record(streamID1, field1);
 
 #ifdef _OPENMP
 #pragma omp parallel for default(shared)
 #endif
-          for (size_t index = 0; index < nsplit; ++index)
-            {
-              auto var = varList1[varID];
-              var.gridID = distgridInfo[0][index].gridID;
-              var.gridsize = distgridInfo[0][index].gridsize;
-              field2.init(var);
+            for (size_t index = 0; index < nsplit; ++index)
+              {
+                auto var = varList1[varID];
+                var.gridID = distgridInfo[0][index].gridID;
+                var.gridsize = distgridInfo[0][index].gridsize;
+                field2.init(var);
 
-              if (gridInfo1[0].isReg2d)
-                dist_cells_reg2d(field1, field2, distgridInfo[0][index], gridInfo1[0].nx);
-              else
-                dist_cells(field1, field2, distgridInfo[0][index]);
+                if (gridInfo1[0].isReg2d)
+                  dist_cells_reg2d(field1, field2, distgridInfo[0][index], gridInfo1[0].nx);
+                else
+                  dist_cells(field1, field2, distgridInfo[0][index]);
 
-              if (field1.nmiss) field_num_mv(field2);
+                if (field1.nmiss) field_num_mv(field2);
 
-              cdo_def_record(streamIDs[index], varID, levelID);
-              cdo_write_record(streamIDs[index], field2);
-            }
-        }
+                cdo_def_record(streamIDs[index], varID, levelID);
+                cdo_write_record(streamIDs[index], field2);
+              }
+          }
 
-      tsID++;
-    }
+        tsID++;
+      }
+  }
 
-  cdo_stream_close(streamID1);
+  void
+  close()
+  {
+    cdo_stream_close(streamID1);
 
-  for (auto &streamID : streamIDs) cdo_stream_close(streamID);
-  for (auto &vlistID : vlistIDs) vlistDestroy(vlistID);
+    for (auto &streamID : streamIDs) cdo_stream_close(streamID);
+    for (auto &vlistID : vlistIDs) vlistDestroy(vlistID);
 
-  for (int i = 0; i < ngrids; ++i)
-    for (size_t index = 0; index < nsplit; ++index) gridDestroy(distgridInfo[i][index].gridID);
+    for (int i = 0; i < ngrids; ++i)
+      for (size_t index = 0; index < nsplit; ++index) gridDestroy(distgridInfo[i][index].gridID);
 
-  cdo_finish();
+    cdo_finish();
+  }
+};
+
+void *
+Distgrid(void *process)
+{
+  ModuleDistgrid distrid;
+  distrid.init(process);
+  distrid.run();
+  distrid.close();
 
   return nullptr;
 }
