@@ -269,6 +269,8 @@ etccdi_op(ETCCDI_REQUEST &request)
   const auto vlistID3 = cdo_stream_inq_vlist(streamID3);
   const auto vlistID4 = vlistDuplicate(vlistID1);
 
+  vlist_unpack(vlistID4);
+
   vlist_compare(vlistID1, vlistID2, CmpVlist::All);
   vlist_compare(vlistID1, vlistID3, CmpVlist::All);
 
@@ -795,48 +797,40 @@ public:
     if (cdo_operator_argc() < 3) cdo_abort("Too few arguments!");
     if (cdo_operator_argc() > 4) cdo_abort("Too many arguments!");
 
-    int TX90P, TX10P, TN90P, TN10P, R99P, R95P;
-    if (cdo_operator_argc() == 4 && 'm' == cdo_operator_argv(3)[0])
-      {
-        TX90P = cdo_operator_add("etccdi_tx90p", func_selge, CMP_MONTH, nullptr);  // monthly mode
-        R99P = cdo_operator_add("etccdi_r99p", func_selge, CMP_MONTH, nullptr);    // monthly mode
-        R95P = cdo_operator_add("etccdi_r95p", func_selge, CMP_MONTH, nullptr);    // monthly mode
-        TX10P = cdo_operator_add("etccdi_tx10p", func_selle, CMP_MONTH, nullptr);  // monthly mode
-        TN90P = cdo_operator_add("etccdi_tn90p", func_selge, CMP_MONTH, nullptr);  // monthly mode
-        TN10P = cdo_operator_add("etccdi_tn10p", func_selle, CMP_MONTH, nullptr);  // monthly mode
-        cdo_operator_add("etccdi", 0, CMP_MONTH, nullptr);                  // monthly mode
-      }
-    else
-      {
-        TX90P = cdo_operator_add("etccdi_tx90p", func_selge, CMP_DATE, nullptr);
-        R99P = cdo_operator_add("etccdi_r99p", func_selge, CMP_DATE, nullptr);
-        R95P = cdo_operator_add("etccdi_r95p", func_selge, CMP_DATE, nullptr);
-        TX10P = cdo_operator_add("etccdi_tx10p", func_selle, CMP_DATE, nullptr);
-        TN90P = cdo_operator_add("etccdi_tn90p", func_selge, CMP_DATE, nullptr);
-        TN10P = cdo_operator_add("etccdi_tn10p", func_selle, CMP_DATE, nullptr);
-        cdo_operator_add("etccdi", 0, CMP_DATE, nullptr);
-      }
+    int ETCCDI_TX90P, ETCCDI_R99P, ETCCDI_R95P, ETCCDI_TX10P, ETCCDI_TN90P, ETCCDI_TN10P;
 
+    ETCCDI_TX90P = cdo_operator_add("etccdi_tx90p", func_selge, CMP_DATE, nullptr);
+    ETCCDI_R99P = cdo_operator_add("etccdi_r99p", func_selge, CMP_DATE, nullptr);
+    ETCCDI_R95P = cdo_operator_add("etccdi_r95p", func_selge, CMP_DATE, nullptr);
+    ETCCDI_TX10P = cdo_operator_add("etccdi_tx10p", func_selle, CMP_DATE, nullptr);
+    ETCCDI_TN90P = cdo_operator_add("etccdi_tn90p", func_selge, CMP_DATE, nullptr);
+    ETCCDI_TN10P = cdo_operator_add("etccdi_tn10p", func_selle, CMP_DATE, nullptr);
+    cdo_operator_add("etccdi", 0, CMP_DATE, nullptr);
+
+    
 
     request.ndates = parameter_to_int(cdo_operator_argv(0));
     request.startboot = parameter_to_int(cdo_operator_argv(1));
 
     const auto operatorID = cdo_operator_id();
-    if (operatorID == TX90P || operatorID == TN90P || operatorID == R95P || operatorID == R99P)
+    request.compare_type = cdo_operator_f2(cdo_operator_id());
+    if (cdo_operator_argc() == 4 && 'm' == cdo_operator_argv(3)[0]) { request.compare_type = CMP_MONTH; }
+
+    if (operatorID == ETCCDI_TX90P || operatorID == ETCCDI_TN90P || operatorID == ETCCDI_R95P || operatorID == ETCCDI_R99P)
       {
-        if (operatorID == TX90P || operatorID == TN90P)
+        if (operatorID == ETCCDI_TX90P || operatorID == ETCCDI_TN90P)
           {
             if (cdo_operator_argc() < 3)
               cdo_abort("Operator requires at least 3 parameter values, you provided '%d'!", cdo_operator_argc());
             request.endboot = parameter_to_int(cdo_operator_argv(2));
-            if (operatorID == TX90P)
+            if (operatorID == ETCCDI_TX90P)
               {
                 request.name = TX90P_NAME;
                 request.longname = TX90P_LONGNAME;
                 request.units = TX90P_UNITS;
                 request.func2 = FieldFunc_Avg;
               }
-            else if (operatorID == TN90P)
+            else if (operatorID == ETCCDI_TN90P)
               {
                 request.name = TN90P_NAME;
                 request.longname = TN90P_LONGNAME;
@@ -852,7 +846,7 @@ public:
             request.ndates = 1;
             request.startboot = parameter_to_int(cdo_operator_argv(0));
             request.endboot = parameter_to_int(cdo_operator_argv(1));
-            if (operatorID == R95P)
+            if (operatorID == ETCCDI_R95P)
               {
                 request.name = R95P_NAME;
                 request.longname = R95P_LONGNAME;
@@ -860,7 +854,7 @@ public:
                 request.pn = 95;
                 request.func2 = FieldFunc_Sum;
               }
-            else if (operatorID == R99P)
+            else if (operatorID == ETCCDI_R99P)
               {
                 request.name = R99P_NAME;
                 request.longname = R99P_LONGNAME;
@@ -870,12 +864,12 @@ public:
               }
           }
       }
-    else if (operatorID == TX10P || operatorID == TN10P)
+    else if (operatorID == ETCCDI_TX10P || operatorID == ETCCDI_TN10P)
       {
         if (cdo_operator_argc() < 3)
           cdo_abort("Operator requires at least 3 parameter values, you provided '%d'!", cdo_operator_argc());
         request.endboot = parameter_to_int(cdo_operator_argv(2));
-        if (operatorID == TX10P)
+        if (operatorID == ETCCDI_TX10P)
           {
             request.name = TX10P_NAME;
             request.longname = TX10P_LONGNAME;
