@@ -163,23 +163,27 @@ import_e5ml(const char *filename, std::vector<VAR> &vars)
     for (int i = 0; i < nlev; ++i) levs[i] = i + 1;
     zaxisDefLevels(zaxisIDml, levs.data());
   }
-  // read variables
 
-  auto xvals = new double[nlon];
-  auto yvals = new double[nlat];
+  // read variables
 
   int nc_var_id;
   nce(nc_inq_varid(nc_file_id, "lon", &nc_var_id));
-  nce(nc_get_var_double(nc_file_id, nc_var_id, xvals));
 
-  nce(nc_inq_varid(nc_file_id, "lat", &nc_var_id));
-  nce(nc_get_var_double(nc_file_id, nc_var_id, yvals));
+  {
+    auto xvals = new double[nlon];
+    auto yvals = new double[nlat];
 
-  gridDefXvals(gridIDgp, xvals);
-  gridDefYvals(gridIDgp, yvals);
+    nce(nc_get_var_double(nc_file_id, nc_var_id, xvals));
 
-  delete[] xvals;
-  delete[] yvals;
+    nce(nc_inq_varid(nc_file_id, "lat", &nc_var_id));
+    nce(nc_get_var_double(nc_file_id, nc_var_id, yvals));
+
+    gridDefXvals(gridIDgp, xvals);
+    gridDefYvals(gridIDgp, yvals);
+
+    delete[] xvals;
+    delete[] yvals;
+  }
 
   auto vct = new double[nvct];
 
@@ -798,7 +802,10 @@ public:
     if (operatorID == EXPORT_E5ML && process_self().m_ID != 0) cdo_abort("This operator can't be linked with other operators!");
 
     if (operatorID == IMPORT_E5ML) { im_e5ml(); }
-    else if (operatorID == EXPORT_E5ML) { ex_e5ml(); }
+    else if (operatorID == EXPORT_E5ML)
+      {
+        ex_e5ml();
+      }
   }
 
   void
