@@ -338,7 +338,7 @@ addOperators(void)
   // clang-format on
 }
 
-class ModuleExpr
+class ModuleExprf
 {
   CdoStreamID streamID1;
   CdoStreamID streamID2;
@@ -726,9 +726,9 @@ public:
 };
 
 void *
-Expr(void *process)
+Exprf(void *process)
 {
-  ModuleExpr expr;
+  ModuleExprf expr;
   expr.init(process);
   expr.run();
   expr.close();
