@@ -226,6 +226,8 @@ public:
 
     auto operatorID = cdo_operator_id();
     operfunc = cdo_operator_f1(operatorID);
+
+    auto lminmax = (operfunc == FieldFunc_Min || operfunc == FieldFunc_Max);
     needWeights = (cdo_operator_f2(operatorID) != 0);
     needCellarea = (operatorID == FLDINT);
     useWeights = true;
@@ -242,6 +244,8 @@ public:
 
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
     vlistID2 = vlistDuplicate(vlistID1);
+
+    if (!lminmax) vlist_unpack(vlistID2);
     remove_global_grid_attr(vlistID2);
 
     taxisID1 = vlistInqTaxis(vlistID1);
@@ -272,7 +276,7 @@ public:
             for (size_t i = 0; i < gridsizemax; ++i) field.weightv[i] = 1.0;
           }
       }
-    varListInit(varList1, vlistID1);
+    varList_init(varList1, vlistID1);
 
     ntsteps = vlistNtsteps(vlistID1);
 
@@ -343,6 +347,7 @@ public:
         tsID++;
       }
   }
+
   void
   close()
   {
@@ -354,11 +359,11 @@ public:
     cdo_finish();
   }
 };
+
 void *
 Fldstat(void *process)
 {
   ModuleFldstat fldstat;
-
   fldstat.init(process);
   fldstat.run();
   fldstat.close();
