@@ -132,7 +132,7 @@ fourier_intrinsic(int sign, int varID, int levelID, int nts, size_t gridsize, do
     }
 }
 
-class ModuleFurier
+class ModuleFourier
 {
   size_t nalloc = 0;
 
@@ -312,7 +312,7 @@ public:
 void *
 Fourier(void *process)
 {
-  ModuleFurier furier;
+  ModuleFourier furier;
 
   furier.init(process);
   furier.run();
