@@ -157,7 +157,7 @@ cellsearch_delete(cellsearch_type *cellsearch)
 }
 
 static long
-search_cells(cellsearch_type *cellsearch, long tgtCellIndex, long *srch_add)
+search_cells(cellsearch_type *cellsearch, long tgtCellIndex, long *srchIndices)
 {
   grid_type *srcGrid = cellsearch->srcGrid;
   grid_type *tgtGrid = cellsearch->tgtGrid;
@@ -180,7 +180,7 @@ search_cells(cellsearch_type *cellsearch, long tgtCellIndex, long *srch_add)
         {
           if ((src_cell_bound_box[srcCellIndexM4] <= bound_box_lat2) && (src_cell_bound_box[srcCellIndexM4 + 1] >= bound_box_lat1))
             {
-              srch_add[numSearchCells] = srcCellIndex;
+              srchIndices[numSearchCells] = srcCellIndex;
               numSearchCells++;
             }
         }
@@ -195,18 +195,18 @@ cell_search(int gridIDsrc, int gridIDtgt)
   grid_type *srcGrid = grid_new(gridIDsrc, "source");
   grid_type *tgtGrid = grid_new(gridIDtgt, "target");
 
-  std::vector<long> srch_add(srcGrid->size);
+  std::vector<long> srchIndices(srcGrid->size);
 
   cellsearch_type *cellsearch = cellsearch_new(srcGrid, tgtGrid);
 
   for (long tgtCellIndex = 0; tgtCellIndex < tgtGrid->size; ++tgtCellIndex)
     {
-      long numSearchCells = search_cells(cellsearch, tgtCellIndex, srch_add.data());
+      long numSearchCells = search_cells(cellsearch, tgtCellIndex, srchIndices.data());
 
       if (Options::cdoVerbose && numSearchCells > 0)
         {
           printf("tgt cell %ld: found %ld src cells\n", tgtCellIndex, numSearchCells);
-          for (long n = 0; n < numSearchCells; ++n) printf("   %ld: %ld\n", n + 1, srch_add[n]);
+          for (long n = 0; n < numSearchCells; ++n) printf("   %ld: %ld\n", n + 1, srchIndices[n]);
         }
     }
 
@@ -222,7 +222,7 @@ class ModuleGridsearch
   int gridID1;
   int gridID2;
 
-  int CSEARCH, PSEARCH;
+  int TESTCELLSEARCH, TESTPOINTSEARCH;
 
 public:
   void
@@ -230,8 +230,8 @@ public:
   {
     cdo_initialize(process);
 
-    PSEARCH = cdo_operator_add("testpointsearch", 0, 0, nullptr);
-    CSEARCH = cdo_operator_add("testcellsearch", 0, 0, nullptr);
+    TESTPOINTSEARCH = cdo_operator_add("testpointsearch", 0, 0, nullptr);
+    TESTCELLSEARCH = cdo_operator_add("testcellsearch", 0, 0, nullptr);
 
     operatorID = cdo_operator_id();
 
@@ -245,7 +245,7 @@ public:
   void
   run()
   {
-    if (operatorID == CSEARCH) cell_search(gridID1, gridID2);
+    if (operatorID == TESTCELLSEARCH) cell_search(gridID1, gridID2);
   }
 
   void
