@@ -32,8 +32,8 @@ static const int FIRST_VAR = 0;
 static double
 humidityIndex(double t, double e, double r, double missval)
 {
-  static const double tmin = 26.0;
-  static const double rmin = 40.0;
+  constexpr double tmin = 26.0;
+  constexpr double rmin = 40.0;
 
   if (t < tmin || r < rmin) return missval;
 
@@ -43,14 +43,14 @@ humidityIndex(double t, double e, double r, double missval)
 static void
 farexpr(Field &field1, const Field &field2, const Field &field3, double (*expression)(double, double, double, double))
 {
-  const auto grid1 = field1.grid;
-  const auto grid2 = field2.grid;
-  const auto grid3 = field3.grid;
-  const auto missval1 = field1.missval;
-  const auto missval2 = field2.missval;
-  const auto missval3 = field3.missval;
+  auto grid1 = field1.grid;
+  auto grid2 = field2.grid;
+  auto grid3 = field3.grid;
+  auto missval1 = field1.missval;
+  auto missval2 = field2.missval;
+  auto missval3 = field3.missval;
 
-  const auto len = gridInqSize(grid1);
+  auto len = gridInqSize(grid1);
   if (len != gridInqSize(grid2) || len != gridInqSize(grid3)) cdo_abort("Fields have different gridsize (%s)", __func__);
 
   if (field1.nmiss || field2.nmiss || field3.nmiss)
@@ -115,7 +115,7 @@ public:
     vlist_compare(vlistID1, vlistID2, CmpVlist::Dim);
     vlist_compare(vlistID1, vlistID3, CmpVlist::Dim);
 
-    const auto gridsizemax = vlistGridsizeMax(vlistID1);
+    auto gridsizemax = vlistGridsizeMax(vlistID1);
 
     field1.resize(gridsizemax);
     field2.resize(gridsizemax);
@@ -126,8 +126,8 @@ public:
                 vlistNtsteps(vlistID3));
 
     vlistID4 = vlistCreate();
-    const auto gridID = vlistInqVarGrid(vlistID1, FIRST_VAR);
-    const auto zaxisID = vlistInqVarZaxis(vlistID1, FIRST_VAR);
+    auto gridID = vlistInqVarGrid(vlistID1, FIRST_VAR);
+    auto zaxisID = vlistInqVarZaxis(vlistID1, FIRST_VAR);
     varID4 = vlistDefVar(vlistID4, gridID, zaxisID, TIME_VARYING);
 
     taxisID4 = cdo_taxis_create(TAXIS_RELATIVE);
@@ -152,11 +152,11 @@ public:
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
-        const auto nrecs2 = cdo_stream_inq_timestep(streamID2, tsID);
-        const auto nrecs3 = cdo_stream_inq_timestep(streamID3, tsID);
+        auto nrecs2 = cdo_stream_inq_timestep(streamID2, tsID);
+        auto nrecs3 = cdo_stream_inq_timestep(streamID3, tsID);
         if (nrecs2 == 0 || nrecs3 == 0) cdo_abort("Input streams have different number of timesteps!");
 
         cdo_taxis_copy_timestep(taxisID4, taxisID1);
