@@ -310,7 +310,7 @@ public:
             if (index == 0)
               {
                 if (gridtype != GRID_LONLAT && gridtype != GRID_GAUSSIAN)
-                  cdo_abort("Interpolation of %s data unsupported!", gridNamePtr(gridtype));
+                  cdo_abort("%s data unsupported!", gridNamePtr(gridtype));
 
                 gridID2 = gen_boxavg_grid(gridID1, xinc, yinc);
               }
@@ -322,7 +322,7 @@ public:
             if (index == 0)
               {
                 if (gridtype != GRID_LONLAT && gridtype != GRID_GAUSSIAN && gridtype != GRID_CURVILINEAR)
-                  cdo_abort("Interpolation of %s data unsupported!", gridNamePtr(gridtype));
+                  cdo_abort("%s data unsupported!", gridNamePtr(gridtype));
 
                 gridID2 = gen_thinout_grid(gridID1, xinc, yinc);
               }
@@ -427,7 +427,6 @@ Intgrid(void *process)
 {
 
   ModuleIntgrid intgrid;
-
   intgrid.init(process);
   intgrid.run();
   intgrid.close();
