@@ -330,20 +330,20 @@ intlevel_get_parameter(std::string &zdescription, std::string &zvarname)
             {
               if (def_zdescription) cdo_abort("Parameter level and zdescription can't be mixed!");
               levels.resize(nvalues);
-              for (int i = 0; i < nvalues; ++i) levels[i] = literal_to_double(values[i]);
+              for (int i = 0; i < nvalues; ++i) levels[i] = parameter_to_double(values[i]);
               def_level = true;
             }
-          else if (key == "zdescription")
+         else if (key == "zdescription")
             {
-              if (def_level) cdo_abort("Parameter zdescription and level can't be mixed!");
+              if (def_level) cdo_abort("Parameter file and level can't be mixed!");
               zdescription = value;
               def_zdescription = true;
             }
-          else if (key == "zvarname")
+         else if (key == "zvarname")
             {
               zvarname = value;
             }
-          else cdo_abort("Invalid parameter key >%s<!", key);
+         else cdo_abort("Invalid parameter key >%s<!", key);
           // clang-format on
         }
     }
@@ -421,203 +421,253 @@ handle_empty_zvar(size_t &wisize, int &nlevel, std::vector<double> &lev1, const
   lev1[nlev1 + 1] = lup ? 1.e33 : -1.e33;
 
   if (Options::cdoVerbose)
-    for (i = 0; i < nlev1 + 2; ++i) cdo_print("lev1 %d: %g", i, lev1[i]);
+    for (i = 0; i < nlev1 + 2; ++i) cdo_print("level_in %d: %g", i, lev1[i]);
 
   wisize = nlev2;
 }
 
-void *
-Intlevel(void *process)
+class ModuleIntlevel
 {
   int zaxisID1 = -1;
   int nlevel = 0;
 
-  cdo_initialize(process);
+  CdoStreamID streamID1;
+  CdoStreamID streamID2;
 
-  // clang-format off
-  auto INTLEVEL  = cdo_operator_add("intlevel",  0, 0, nullptr);
-  auto INTLEVELX = cdo_operator_add("intlevelx", 0, 0, nullptr);
-  // clang-format on
+  int taxisID1;
+  int taxisID2;
 
-  (void) (INTLEVEL);  // unused
-
-  auto operatorID = cdo_operator_id();
-
-  auto expol = (operatorID == INTLEVELX);
-
-  operator_input_arg("level|zdescription, [zvarname]");
+  std::vector<bool> processVars;
+  std::vector<bool> interpVars;
+  std::vector<std::vector<size_t>> varnmiss;
+  Field3DVector vardata1;
+  Field3DVector vardata2;
 
   std::vector<double> lev2;
   int zaxisID2 = CDI_UNDEFID;
   std::string zvarname;
-  auto argv = cdo_get_oper_argv();
 
-  if (isdigit((int) argv[0][0])) { lev2 = cdo_argv_to_flt(argv); }
-  else
-    {
-      std::string zdescription;
-      lev2 = intlevel_get_parameter(zdescription, zvarname);
-      if (!zdescription.empty())
-        {
-          auto zfilename = zdescription.c_str();
-          auto zfp = std::fopen(zfilename, "r");
-          if (!zfp) cdo_abort("Open failed on %s", zfilename);
-          zaxisID2 = zaxis_from_file(zfp, zfilename);
-          std::fclose(zfp);
-          if (zaxisID2 == CDI_UNDEFID) cdo_abort("Invalid zaxis description file %s!", zfilename);
-          auto nlevels = zaxisInqSize(zaxisID2);
-          lev2.resize(nlevels);
-          zaxisInqLevels(zaxisID2, lev2.data());
-        }
-    }
+  int nlev1 = 0;
+  bool zvarIsVarying = false;
 
-  const int nlev2 = lev2.size();
+  int nvars;
 
-  if (Options::cdoVerbose)
-    for (int i = 0; i < nlev2; ++i) cdo_print("lev2 %d: %g", i, lev2[i]);
+  bool expol;
 
-  auto streamID1 = cdo_open_read(0);
+  Varray<double> lev1;
+  int nlev2;
 
-  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-  auto vlistID2 = vlistDuplicate(vlistID1);
+  size_t zvarGridsize = 0;
+  int zvarID = CDI_UNDEFID;
 
-  auto taxisID1 = vlistInqTaxis(vlistID1);
-  auto taxisID2 = taxisDuplicate(taxisID1);
-  vlistDefTaxis(vlistID2, taxisID2);
+  MemType memType;
+
+  Varray<int> lev_idx;
+  Varray<float> lev_wgt;
 
   VarList varList1;
-  varListInit(varList1, vlistID1);
-  varListSetUniqueMemtype(varList1);
-  auto memType = varList1[0].memType;
-
-  auto nvars = vlistNvars(vlistID1);
-
-  // Find z-variable
-  int nlev1 = 0;
-  Varray<double> lev1;
-  int zvarID = CDI_UNDEFID;
-  bool zvarIsVarying = false;
-  size_t zvarGridsize = 0;
-  size_t wisize = 0;
-
-  if (zvarname.empty()) { handle_empty_zvar(wisize, nlevel, lev1, lev2, nlev1, nlev2, vlistID1, zaxisID2, zaxisID1); }
-  else
-    {
-      handle_zvar(zvarGridsize, wisize, nvars, zvarname, varList1, zvarID, zvarIsVarying, nlevel, lev2, nlev1, nlev2, vlistID1,
-                  zaxisID2, zaxisID1);
-    }
-
-  auto nzaxis = vlistNzaxis(vlistID1);
-  for (int index = 0; index < nzaxis; ++index)
-    {
-      auto zaxisID = vlistZaxis(vlistID1, index);
-      auto nlevels = zaxisInqSize(zaxisID);
-      if (zaxisID == zaxisID1 || nlevels == nlev1) vlistChangeZaxisIndex(vlistID2, index, zaxisID2);
-    }
-
   VarList varList2;
-  varListInit(varList2, vlistID2);
-  varListSetMemtype(varList2, memType);
 
-  Varray<int> lev_idx(wisize);
-  Varray<float> lev_wgt(wisize);
+  int INTLEVEL, INTLEVELX;
 
-  auto streamID2 = cdo_open_write(1);
-  cdo_def_vlist(streamID2, vlistID2);
+public:
+  void
+  init(void *process)
+  {
 
-  std::vector<bool> processVars(nvars);
-  std::vector<bool> interpVars(nvars);
-  std::vector<std::vector<size_t>> varnmiss(nvars);
-  Field3DVector vardata1(nvars), vardata2(nvars);
+    cdo_initialize(process);
 
-  const int maxlev = (nlev1 > nlev2) ? nlev1 : nlev2;
+    INTLEVEL = cdo_operator_add("intlevel", 0, 0, nullptr);
+    INTLEVELX = cdo_operator_add("intlevelx", 0, 0, nullptr);
 
-  for (int varID = 0; varID < nvars; ++varID)
-    {
-      auto nlevels = varList1[varID].nlevels;
+    (void) (INTLEVEL);  // unused
 
-      vardata1[varID].init(varList1[varID]);
+    auto operatorID = cdo_operator_id();
 
-      interpVars[varID] = (varList1[varID].zaxisID == zaxisID1 || nlevels == nlev1);
+    expol = (operatorID == INTLEVELX);
 
-      if (interpVars[varID])
-        {
-          varnmiss[varID].resize(maxlev, 0);
-          vardata2[varID].init(varList2[varID]);
-        }
-      else { varnmiss[varID].resize(nlevels); }
-    }
+    operator_input_arg("level|zdescription, [zvarname]");
 
-  int tsID = 0;
-  while (true)
-    {
-      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-      if (nrecs == 0) break;
+    zaxisID2 = CDI_UNDEFID;
+    auto argv = cdo_get_oper_argv();
 
-      for (int varID = 0; varID < nvars; ++varID) processVars[varID] = false;
+    if (std::isdigit((int) argv[0][0])) { lev2 = cdo_argv_to_flt(argv); }
+    else
+      {
+        std::string zdescription;
+        lev2 = intlevel_get_parameter(zdescription, zvarname);
+        if (!zdescription.empty())
+          {
+            auto zfilename = zdescription.c_str();
+            auto zfp = std::fopen(zfilename, "r");
+            if (!zfp) cdo_abort("Open failed on %s", zfilename);
+            zaxisID2 = zaxis_from_file(zfp, zfilename);
+            std::fclose(zfp);
+            if (zaxisID2 == CDI_UNDEFID) cdo_abort("Invalid zaxis description file %s!", zfilename);
+            auto nlevels = zaxisInqSize(zaxisID2);
+            lev2.resize(nlevels);
+            zaxisInqLevels(zaxisID2, lev2.data());
+          }
+      }
 
-      cdo_taxis_copy_timestep(taxisID2, taxisID1);
-      cdo_def_timestep(streamID2, tsID);
+     nlev2 = lev2.size();
 
-      for (int recID = 0; recID < nrecs; ++recID)
-        {
-          int varID, levelID;
-          cdo_inq_record(streamID1, &varID, &levelID);
-          cdo_read_record(streamID1, vardata1[varID], levelID, &varnmiss[varID][levelID]);
-          processVars[varID] = true;
-        }
+    if (Options::cdoVerbose)
+      for (int i = 0; i < nlev2; ++i) cdo_print("level out %d: %g", i, lev2[i]);
 
-      if (tsID == 0 || zvarIsVarying)
-        {
-          if (!zvarname.empty())
-            vert_gen_weights3d1d(expol, zvarGridsize, nlev1, vardata1[zvarID], nlev2, lev2, lev_idx, lev_wgt);
-          else
-            vert_gen_weights(expol, nlev1 + 2, lev1, nlev2, lev2, lev_idx, lev_wgt);
-        }
+    streamID1 = cdo_open_read(0);
 
-      for (int varID = 0; varID < nvars; ++varID)
-        {
-          if (processVars[varID] && interpVars[varID])
-            {
-              auto missval = varList1[varID].missval;
-              auto gridsize = varList1[varID].gridsize;
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID2 = vlistDuplicate(vlistID1);
 
-              if (!zvarname.empty())
-                vert_interp_lev3d(gridsize, nlev1, missval, vardata1[varID], vardata2[varID], nlev2, lev_idx, lev_wgt);
-              else
-                vert_interp_lev(gridsize, nlev1, missval, vardata1[varID], vardata2[varID], nlev2, lev_idx, lev_wgt);
+    taxisID1 = vlistInqTaxis(vlistID1);
+    taxisID2 = taxisDuplicate(taxisID1);
+    vlistDefTaxis(vlistID2, taxisID2);
 
-              for (int levelID = 0; levelID < nlev2; ++levelID)
-                {
-                  auto offset = gridsize * levelID;
-                  if (memType == MemType::Float)
-                    varnmiss[varID][levelID] = array_num_mv(gridsize, &vardata2[varID].vec_f[offset], (float) missval);
-                  else
-                    varnmiss[varID][levelID] = array_num_mv(gridsize, &vardata2[varID].vec_d[offset], missval);
-                }
-            }
-        }
+    varList_init(varList1, vlistID1);
+    varListSetUniqueMemtype(varList1);
+    memType = varList1[0].memType;
 
-      for (int varID = 0; varID < nvars; ++varID)
-        {
-          if (processVars[varID])
-            {
-              for (int levelID = 0; levelID < varList2[varID].nlevels; ++levelID)
-                {
-                  cdo_def_record(streamID2, varID, levelID);
-                  cdo_write_record(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
-                                   varnmiss[varID][levelID]);
-                }
-            }
-        }
+    nvars = vlistNvars(vlistID1);
 
-      tsID++;
-    }
+    // Find z-variable
+    size_t wisize = 0;
 
-  cdo_stream_close(streamID2);
-  cdo_stream_close(streamID1);
+    if (zvarname.empty()) { handle_empty_zvar(wisize, nlevel, lev1, lev2, nlev1, nlev2, vlistID1, zaxisID2, zaxisID1); }
+    else
+      {
+        handle_zvar(zvarGridsize, wisize, nvars, zvarname, varList1, zvarID, zvarIsVarying, nlevel, lev2, nlev1, nlev2, vlistID1,
+                    zaxisID2, zaxisID1);
+      }
 
-  cdo_finish();
+    auto nzaxis = vlistNzaxis(vlistID1);
+    for (int index = 0; index < nzaxis; ++index)
+      {
+        auto zaxisID = vlistZaxis(vlistID1, index);
+        auto nlevels = zaxisInqSize(zaxisID);
+        if (zaxisID == zaxisID1 || nlevels == nlev1) vlistChangeZaxisIndex(vlistID2, index, zaxisID2);
+      }
+
+    varList_init(varList2, vlistID2);
+    varListSetMemtype(varList2, memType);
+
+    lev_idx = Varray<int>(wisize);
+    lev_wgt = Varray<float>(wisize);
+
+    streamID2 = cdo_open_write(1);
+    cdo_def_vlist(streamID2, vlistID2);
+
+    processVars = std::vector<bool>(nvars);
+    interpVars = std::vector<bool>(nvars, false);
+    varnmiss = std::vector<std::vector<size_t>>(nvars);
+    vardata1 = Field3DVector(nvars);
+    vardata2 = Field3DVector(nvars);
+
+    const int maxlev = (nlev1 > nlev2) ? nlev1 : nlev2;
+
+    for (int varID = 0; varID < nvars; ++varID)
+      {
+        auto nlevels = varList1[varID].nlevels;
+
+        vardata1[varID].init(varList1[varID]);
+
+        interpVars[varID] = (varList1[varID].zaxisID == zaxisID1 || nlevels == nlev1);
+
+        if (interpVars[varID])
+          {
+            varnmiss[varID].resize(maxlev, 0);
+            vardata2[varID].init(varList2[varID]);
+          }
+        else { varnmiss[varID].resize(nlevels); }
+      }
+  }
+  void
+  run()
+  {
+    int tsID = 0;
+    while (true)
+      {
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        if (nrecs == 0) break;
+
+        for (int varID = 0; varID < nvars; ++varID) processVars[varID] = false;
+
+        cdo_taxis_copy_timestep(taxisID2, taxisID1);
+        cdo_def_timestep(streamID2, tsID);
+
+        for (int recID = 0; recID < nrecs; ++recID)
+          {
+            int varID, levelID;
+            cdo_inq_record(streamID1, &varID, &levelID);
+            cdo_read_record(streamID1, vardata1[varID], levelID, &varnmiss[varID][levelID]);
+            processVars[varID] = true;
+          }
+
+        if (tsID == 0 || zvarIsVarying)
+          {
+            if (!zvarname.empty())
+              vert_gen_weights3d1d(expol, zvarGridsize, nlev1, vardata1[zvarID], nlev2, lev2, lev_idx, lev_wgt);
+            else
+              vert_gen_weights(expol, nlev1 + 2, lev1, nlev2, lev2, lev_idx, lev_wgt);
+          }
+
+        for (int varID = 0; varID < nvars; ++varID)
+          {
+            if (processVars[varID] && interpVars[varID])
+              {
+                auto missval = varList1[varID].missval;
+                auto gridsize = varList1[varID].gridsize;
+
+                if (!zvarname.empty())
+                  vert_interp_lev3d(gridsize, nlev1, missval, vardata1[varID], vardata2[varID], nlev2, lev_idx, lev_wgt);
+                else
+                  vert_interp_lev(gridsize, nlev1, missval, vardata1[varID], vardata2[varID], nlev2, lev_idx, lev_wgt);
+
+                for (int levelID = 0; levelID < nlev2; ++levelID)
+                  {
+                    auto offset = gridsize * levelID;
+                    if (memType == MemType::Float)
+                      varnmiss[varID][levelID] = array_num_mv(gridsize, &vardata2[varID].vec_f[offset], (float) missval);
+                    else
+                      varnmiss[varID][levelID] = array_num_mv(gridsize, &vardata2[varID].vec_d[offset], missval);
+                  }
+              }
+          }
+
+        for (int varID = 0; varID < nvars; ++varID)
+          {
+            if (processVars[varID])
+              {
+                for (int levelID = 0; levelID < varList2[varID].nlevels; ++levelID)
+                  {
+                    cdo_def_record(streamID2, varID, levelID);
+                    cdo_write_record(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
+                                     varnmiss[varID][levelID]);
+                  }
+              }
+          }
+
+        tsID++;
+      }
+  }
+  void
+  close()
+  {
+    cdo_stream_close(streamID2);
+    cdo_stream_close(streamID1);
+
+    cdo_finish();
+  }
+};
+
+void *
+Intlevel(void *process)
+{
+  ModuleIntlevel intlevel;
+
+  intlevel.init(process);
+  intlevel.run();
+  intlevel.close();
 
   return nullptr;
 }
