@@ -49,7 +49,7 @@ intlin_year(double fac1, double fac2, size_t gridsize, const Varray<double> &arr
   return nmiss3;
 }
 
-class ModuleIntYear
+class ModuleIntyear
 {
   CdoStreamID streamID1;
   CdoStreamID streamID2;
@@ -193,7 +193,7 @@ public:
 void *
 Intyear(void *process)
 {
-  ModuleIntYear intyear;
+  ModuleIntyear intyear;
   intyear.init(process);
   intyear.run();
   intyear.close();
