@@ -55,8 +55,8 @@ CPT cpt;
 static void
 NormalizVectrs(int n_xres, int n_yres, float *pVectr)
 {
-  for (int j = 0; j < n_yres; j++)
-    for (int i = 0; i < n_xres; i++)
+  for (int j = 0; j < n_yres; ++j)
+    for (int i = 0; i < n_xres; ++i)
       {
         int index = (j * n_xres + i) << 1;
         float vcMag = (float) (std::sqrt((double) (pVectr[index] * pVectr[index] + pVectr[index + 1] * pVectr[index + 1])));
@@ -71,8 +71,8 @@ NormalizVectrs(int n_xres, int n_yres, float *pVectr)
 static void
 MakeWhiteNoise(int n_xres, int n_yres, unsigned char *pNoise)
 {
-  for (int j = 0; j < n_yres; j++)
-    for (int i = 0; i < n_xres; i++)
+  for (int j = 0; j < n_yres; ++j)
+    for (int i = 0; i < n_xres; ++i)
       {
         int r = std::rand();
         r = ((r & 0xff) + ((r & 0xff00) >> 8)) & 0xff;
@@ -84,7 +84,7 @@ MakeWhiteNoise(int n_xres, int n_yres, unsigned char *pNoise)
 void
 GenBoxFiltrLUT(int LUTsiz, float *p_LUT0, float *p_LUT1)
 {
-  for (int i = 0; i < LUTsiz; i++) p_LUT0[i] = p_LUT1[i] = i;
+  for (int i = 0; i < LUTsiz; ++i) p_LUT0[i] = p_LUT1[i] = i;
 }
 
 // write the LIC image to a PPM file
@@ -93,7 +93,7 @@ static void
 WriteImage2PPM(int n_xres, int n_yres, unsigned char *pImage, const char *f_name)
 {
   FILE *o_file;
-  if ((o_file = fopen(f_name, "w")) == nullptr)
+  if ((o_file = std::fopen(f_name, "w")) == nullptr)
     {
       printf("Can't open output file\n");
       return;
@@ -101,14 +101,14 @@ WriteImage2PPM(int n_xres, int n_yres, unsigned char *pImage, const char *f_name
 
   fprintf(o_file, "P6\n%d %d\n255\n", n_xres, n_yres);
 
-  for (int j = 0; j < n_yres; j++)
-    for (int i = 0; i < n_xres; i++)
+  for (int j = 0; j < n_yres; ++j)
+    for (int i = 0; i < n_xres; ++i)
       {
         unsigned char unchar = pImage[j * n_xres + i];
         fprintf(o_file, "%c%c%c", unchar, unchar, unchar);
       }
 
-  fclose(o_file);
+  std::fclose(o_file);
 }
 */
 
@@ -122,7 +122,7 @@ setRGBmag(png_byte *ptr, float val, float mag)
 {
   int r = 0, g = 0, b = 0, n;
 
-  for (n = 0; n < cpt.ncolors; n++)
+  for (n = 0; n < cpt.ncolors; ++n)
     if (mag > cpt.lut[n].z_low && mag <= cpt.lut[n].z_high) break;
 
   if (n == cpt.ncolors)
@@ -156,7 +156,7 @@ WriteImage2PNG(int width, int height, unsigned char *pImage, float *mag, const c
   png_bytep row = nullptr;
 
   // Open file for writing (binary mode)
-  FILE *fp = fopen(filename, "wb");
+  FILE *fp = std::fopen(filename, "wb");
   if (fp == nullptr)
     {
       fprintf(stderr, "Could not open file %s for writing\n", filename);
@@ -214,10 +214,7 @@ WriteImage2PNG(int width, int height, unsigned char *pImage, float *mag, const c
   // Write image data
   for (int y = 0; y < height; y++)
     {
-      for (int x = 0; x < width; x++)
-        {
-          setRGBmag(&(row[x * 3]), pImage[y * width + x], mag[y * width + x]);
-        }
+      for (int x = 0; x < width; x++) { setRGBmag(&(row[x * 3]), pImage[y * width + x], mag[y * width + x]); }
       png_write_row(png_ptr, row);
     }
 
@@ -225,7 +222,7 @@ WriteImage2PNG(int width, int height, unsigned char *pImage, float *mag, const c
   png_write_end(png_ptr, nullptr);
 
 finalise:
-  if (fp != nullptr) fclose(fp);
+  if (fp != nullptr) std::fclose(fp);
   if (info_ptr != nullptr) png_free_data(png_ptr, info_ptr, PNG_FREE_ALL, -1);
   if (png_ptr != nullptr) png_destroy_write_struct(&png_ptr, (png_infopp) nullptr);
   if (row != nullptr) free(row);
@@ -243,9 +240,9 @@ FlowImagingLIC(int n_xres, int n_yres, float *pVectr, unsigned char *pNoise, uns
   /// for each pixel in the 2D output LIC image///
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(pNoise, pVectr, n_xres, n_yres, pImage, p_LUT0, p_LUT1, krnlen)
+#pragma omp parallel for default(shared)
 #endif
-  for (int j = 0; j < n_yres; j++)
+  for (int j = 0; j < n_yres; ++j)
     {
       int vec_id;                       /// ID in the VECtor buffer (for the input flow field)
       int advDir;                       /// ADVection DIRection (0: positive;  1: negative)
@@ -271,7 +268,7 @@ FlowImagingLIC(int n_xres, int n_yres, float *pVectr, unsigned char *pNoise, uns
       float w_acum[2];          /// two ACcUMulated Weighting values   for the two directions, perspectively
       float *wgtLUT = nullptr;  /// WeiGhT Look Up Table pointing to the target filter LUT
       float len2ID = (DISCRETE_FILTER_SIZE - 1) / krnlen;  /// map a curve LENgth TO an ID in the LUT
-      for (int i = 0; i < n_xres; i++)
+      for (int i = 0; i < n_xres; ++i)
         {
           /// init the composite texture accumulators and the weight accumulators///
           t_acum[0] = t_acum[1] = w_acum[0] = w_acum[1] = 0.0f;
@@ -380,7 +377,7 @@ lic1(const char *obasename, int num, int n_xres, int n_yres, float *pVectr)
   int n = n_xres * n_yres;
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(mag, pVectr, n)
+#pragma omp parallel for default(shared)
 #endif
   for (int i = 0; i < n; ++i)
     mag[i] = (float) std::sqrt((double) pVectr[i * 2] * pVectr[i * 2] + (double) pVectr[i * 2 + 1] * pVectr[i * 2 + 1]);
@@ -419,122 +416,165 @@ lic1(const char *obasename, int num, int n_xres, int n_yres, float *pVectr)
   free(mag);
 }
 
-void *
-Lic(void *process)
+class ModuleLic
 {
   int nlev = 0;
   size_t nmiss;
 
-  cdo_initialize(process);
+  CdoStreamID streamID1;
+  CdoStreamID streamID2;
 
-  // clang-format off
-  // int LIC  = cdo_operator_add("lic",  0, 0, nullptr);
-  // clang-format on
-
-  // int operatorID = cdo_operator_id();
-
-  if (cdo_operator_argc() < 1 || cdo_operator_argc() > 2) operator_check_argc(1);
-  const char *cpt_file = cdo_operator_argv(0).c_str();
-  int nstart = (cdo_operator_argc() == 2) ? std::stoi(cdo_operator_argv(1)) : 0;
-  auto cpt_fp = fopen(cpt_file, "r");
-  if (cpt_fp == nullptr) cdo_abort("Open failed on color palette table %s", cpt_file);
-
-  int status = cpt_read(cpt_fp, &cpt);
-  if (status != 0) cdo_abort("Error during read of color palette table %s", cpt_file);
-
-  const auto obasename = cdo_get_stream_name(1);
-  const auto streamID1 = cdo_open_read(0);
-
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-
-  // int taxisID1 = vlistInqTaxis(vlistID1);
-
-  /* find variables */
-  const auto nvars = vlistNvars(vlistID1);
-  if (nvars != 2) cdo_abort("Need 2 input variable, found %d\n", nvars);
   int varID1 = 0;
   int varID2 = 1;
 
-  const auto ngrids = vlistNgrids(vlistID1);
-  if (ngrids != 1) cdo_abort("Need 1 grid, found %d\n", ngrids);
+  bool invertlat;
 
-  const auto gridID = vlistInqVarGrid(vlistID1, varID1);
-  // int zaxisID = vlistInqVarZaxis(vlistID1, varID1);
+  size_t nx;
+  size_t ny;
 
-  auto gridsize = vlistGridsizeMax(vlistID1);
-  Varray<double> array1(gridsize);
-  std::vector<float> varray(2 * gridsize);
+  size_t gridsize;
 
-  Varray<double> ivar1, ivar2, ovar1;
-  if (varID1 != -1 && varID2 != -1)
-    {
-      nlev = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID1));
+  int gridID;
+  int nstart;
 
-      gridsize = gridInqSize(gridID);
-      ivar1.resize(nlev * gridsize);
-      ivar2.resize(nlev * gridsize);
+  Varray<double> array1;
+  std::vector<float> varray;
 
-      gridsize = gridInqSize(gridID);
-      ovar1.resize(nlev * gridsize);
-    }
+  const char *obasename;
 
-  const auto gridtype = gridInqType(gridID);
-  if (gridtype != GRID_LONLAT && gridtype != GRID_GAUSSIAN) cdo_abort("Unsupported grid!\n");
+  Varray<double> xvals;
+  Varray<double> yvals;
 
-  const auto nx = gridInqXsize(gridID);
-  const auto ny = gridInqYsize(gridID);
+public:
+  void
+  init(void *process)
+  {
 
-  Varray<double> xvals(nx), yvals(ny);
-  gridInqYvals(gridID, yvals.data());
-  bool invertlat = (yvals[0] < yvals[ny - 1]);
+    cdo_initialize(process);
 
-  int tsID = 0;
-  while (true)
-    {
-      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-      if (nrecs == 0) break;
-      /*
-      cdo_taxis_copy_timestep(taxisID2, taxisID1);
-      cdo_def_timestep(streamID2, tsID);
-      */
-      for (int recID = 0; recID < nrecs; recID++)
-        {
-          int varID, levelID;
-          cdo_inq_record(streamID1, &varID, &levelID);
+    // clang-format off
+  // int LIC  = cdo_operator_add("lic",  0, 0, nullptr);
+    // clang-format on
 
-          if (varID == varID1 || varID == varID2)
-            {
-              cdo_read_record(streamID1, array1.data(), &nmiss);
-              if (nmiss) cdo_abort("Missing values unsupported!");
+    // int operatorID = cdo_operator_id();
 
-              gridsize = gridInqSize(gridID);
+    if (cdo_operator_argc() < 1 || cdo_operator_argc() > 2) operator_check_argc(1);
+    const char *cpt_file = cdo_operator_argv(0).c_str();
+    nstart = (cdo_operator_argc() == 2) ? std::stoi(cdo_operator_argv(1)) : 0;
+    auto cpt_fp = std::fopen(cpt_file, "r");
+    if (cpt_fp == nullptr) cdo_abort("Open failed on color palette table %s", cpt_file);
 
-              if (invertlat)
-                {
-                  for (size_t j = 0; j < ny / 2; ++j)
-                    {
-                      for (size_t i = 0; i < nx; ++i) xvals[i] = array1[j * nx + i];
-                      for (size_t i = 0; i < nx; ++i) array1[j * nx + i] = array1[(ny - j - 1) * nx + i];
-                      for (size_t i = 0; i < nx; ++i) array1[(ny - j - 1) * nx + i] = xvals[i];
-                    }
-                }
+    int status = cpt_read(cpt_fp, &cpt);
+    if (status != 0) cdo_abort("Error during read of color palette table %s", cpt_file);
 
-              if (varID == varID1)
-                for (size_t i = 0; i < gridsize; ++i) varray[i * 2] = (float) array1[i];
-              else if (varID == varID2)
-                for (size_t i = 0; i < gridsize; ++i) varray[i * 2 + 1] = (float) array1[i];
-            }
-        }
+    obasename = cdo_get_stream_name(1);
+    streamID1 = cdo_open_read(0);
 
-      lic1(obasename, nstart + tsID, nx, ny, varray.data());
+    const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
 
-      tsID++;
-    }
+    // int taxisID1 = vlistInqTaxis(vlistID1);
 
-  cdo_stream_close(streamID1);
+    /* find variables */
+    const auto nvars = vlistNvars(vlistID1);
+    if (nvars != 2) cdo_abort("Need 2 input variable, found %d\n", nvars);
 
-  cdo_finish();
+    const auto ngrids = vlistNgrids(vlistID1);
+    if (ngrids != 1) cdo_abort("Need 1 grid, found %d\n", ngrids);
 
+    gridID = vlistInqVarGrid(vlistID1, varID1);
+    // int zaxisID = vlistInqVarZaxis(vlistID1, varID1);
+
+    gridsize = vlistGridsizeMax(vlistID1);
+    array1 = Varray<double>(gridsize);
+    varray = std::vector<float>(2 * gridsize);
+
+    Varray<double> ivar1, ivar2, ovar1;
+    if (varID1 != -1 && varID2 != -1)
+      {
+        nlev = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID1));
+
+        gridsize = gridInqSize(gridID);
+        ivar1.resize(nlev * gridsize);
+        ivar2.resize(nlev * gridsize);
+
+        gridsize = gridInqSize(gridID);
+        ovar1.resize(nlev * gridsize);
+      }
+
+    const auto gridtype = gridInqType(gridID);
+    if (gridtype != GRID_LONLAT && gridtype != GRID_GAUSSIAN) cdo_abort("Unsupported grid!\n");
+
+    nx = gridInqXsize(gridID);
+    ny = gridInqYsize(gridID);
+
+    xvals = Varray<double>(nx);
+    yvals = Varray<double>(ny);
+    gridInqYvals(gridID, yvals.data());
+    invertlat = (yvals[0] < yvals[ny - 1]);
+  }
+  void
+  run()
+  {
+    int tsID = 0;
+    while (true)
+      {
+        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        if (nrecs == 0) break;
+        /*
+        cdo_taxis_copy_timestep(taxisID2, taxisID1);
+        cdo_def_timestep(streamID2, tsID);
+        */
+        for (int recID = 0; recID < nrecs; ++recID)
+          {
+            int varID, levelID;
+            cdo_inq_record(streamID1, &varID, &levelID);
+
+            if (varID == varID1 || varID == varID2)
+              {
+                cdo_read_record(streamID1, array1.data(), &nmiss);
+                if (nmiss) cdo_abort("Missing values unsupported!");
+
+                gridsize = gridInqSize(gridID);
+
+                if (invertlat)
+                  {
+                    for (size_t j = 0; j < ny / 2; ++j)
+                      {
+                        for (size_t i = 0; i < nx; ++i) xvals[i] = array1[j * nx + i];
+                        for (size_t i = 0; i < nx; ++i) array1[j * nx + i] = array1[(ny - j - 1) * nx + i];
+                        for (size_t i = 0; i < nx; ++i) array1[(ny - j - 1) * nx + i] = xvals[i];
+                      }
+                  }
+
+                if (varID == varID1)
+                  for (size_t i = 0; i < gridsize; ++i) varray[i * 2] = (float) array1[i];
+                else if (varID == varID2)
+                  for (size_t i = 0; i < gridsize; ++i) varray[i * 2 + 1] = (float) array1[i];
+              }
+          }
+
+        lic1(obasename, nstart + tsID, nx, ny, varray.data());
+
+        tsID++;
+      }
+  }
+  void
+  close()
+  {
+
+    cdo_stream_close(streamID1);
+
+    cdo_finish();
+  }
+};
+
+void *
+Lic(void *process)
+{
+  ModuleLic lic;
+  lic.init(process);
+  lic.run();
+  lic.close();
   return nullptr;
 }
 
