@@ -354,8 +354,8 @@ maggraph(const char *plotfile, const std::string &varname, const std::string &va
           fprintf(stderr, "\n");
         }
 
-      strcpy(min_date_time_str, date_time_str[0][0]);
-      strcpy(max_date_time_str, date_time_str[0][ntime_steps - 1]);
+      std::strcpy(min_date_time_str, date_time_str[0][0]);
+      std::strcpy(max_date_time_str, date_time_str[0][ntime_steps - 1]);
     }
   else
     {
@@ -423,8 +423,8 @@ maggraph(const char *plotfile, const std::string &varname, const std::string &va
             }
         }
 
-      strcpy(min_date_time_str, date_time_str[min_index][0]);
-      strcpy(max_date_time_str, date_time_str[max_index][nts[max_index] - 1]);
+      std::strcpy(min_date_time_str, date_time_str[min_index][0]);
+      std::strcpy(max_date_time_str, date_time_str[max_index][nts[max_index] - 1]);
       if (DBG) fprintf(stderr, "%s %s\n", min_date_time_str, max_date_time_str);
     }
 
@@ -756,121 +756,151 @@ VerifyGraphParameters(int num_param, std::vector<std::string> &param_names)
 }
 #endif
 
-void *
-Maggraph(void *process)
+class ModuleMaggraph
 {
-  cdo_initialize(process);
 
-#ifdef HAVE_LIBMAGICS
   std::string varname, units;
   int gridID;
   int vlistID0 = -1;
+  int nfiles = 0;
 
-  int nparam = cdo_operator_argc();
-  auto pnames = cdo_get_oper_argv();
+  const char *ofilename;
 
-  if (nparam) VerifyGraphParameters(nparam, pnames);
+  int nparam;
+  std::vector<std::string> pnames;
 
-  int nfiles = cdo_stream_cnt() - 1;
-  const char *ofilename = cdo_get_stream_name(nfiles);
+public:
+  void
+  init(void *process)
+  {
+    cdo_initialize(process);
 
-  if (DBG)
-    {
-      fprintf(stderr, " Num of files %d\n", nfiles);
-      fprintf(stderr, " files %s\n", ofilename);
-    }
+#ifdef HAVE_LIBMAGICS
 
-  std::vector<std::vector<double>> datatab(nfiles);
-  std::vector<std::vector<CdiDateTime>> vDateTimes(nfiles);
-  std::vector<long> nts(nfiles, 0);
+    nparam = cdo_operator_argc();
+    pnames = cdo_get_oper_argv();
 
-  for (int fileID = 0; fileID < nfiles; ++fileID)
-    {
-      if (DBG) fprintf(stderr, " file %d is %s\n", fileID, cdo_get_stream_name(fileID));
+    if (nparam) VerifyGraphParameters(nparam, pnames);
 
-      auto streamID = cdo_open_read(fileID);
-      auto vlistID = cdo_stream_inq_vlist(streamID);
-      auto taxisID = vlistInqTaxis(vlistID);
+    nfiles = cdo_stream_cnt() - 1;
+    ofilename = cdo_get_stream_name(nfiles);
 
-      units = cdo::inq_var_units(vlistID, 0);
-      if (DBG) fprintf(stderr, " units=%s\n", units.c_str());
-      if (fileID == 0)
-        {
-          varname = cdo::inq_var_name(vlistID, 0);
+    if (DBG)
+      {
+        fprintf(stderr, " Num of files %d\n", nfiles);
+        fprintf(stderr, " files %s\n", ofilename);
+      }
+#endif
+  }
 
-          gridID = vlistInqVarGrid(vlistID, 0);
-          auto zaxisID = vlistInqVarZaxis(vlistID, 0);
-          auto nvars = vlistNvars(vlistID);
+  void
+  run()
+  {
+#ifdef HAVE_LIBMAGICS
+    std::vector<std::vector<double>> datatab(nfiles);
+    std::vector<std::vector<CdiDateTime>> vDateTimes(nfiles);
+    std::vector<long> nts(nfiles, 0);
 
-          if (nvars > 1) cdo_abort("Input stream has more than on variable!");
-          if (gridInqSize(gridID) != 1) cdo_abort("Variable has more than one grid point!");
-          if (zaxisInqSize(zaxisID) != 1) cdo_abort("Variable has more than one level!");
+    for (int fileID = 0; fileID < nfiles; ++fileID)
+      {
+        if (DBG) fprintf(stderr, " file %d is %s\n", fileID, cdo_get_stream_name(fileID));
 
-          vlistID0 = vlistDuplicate(vlistID);
-        }
-      else { vlist_compare(vlistID0, vlistID, CMP_ALL); }
+        auto streamID = cdo_open_read(fileID);
+        auto vlistID = cdo_stream_inq_vlist(streamID);
+        auto taxisID = vlistInqTaxis(vlistID);
 
-      int tsID = 0;
-      size_t numTsAlloc = 0;
-      while (true)
-        {
-          auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
-          if (nrecs == 0) break;
+        units = cdo::inq_var_units(vlistID, 0);
+        if (DBG) fprintf(stderr, " units=%s\n", units.c_str());
+        if (fileID == 0)
+          {
+            varname = cdo::inq_var_name(vlistID, 0);
 
-          if (nrecs != 1) cdo_abort("Input stream has more than one point in time!");
+            gridID = vlistInqVarGrid(vlistID, 0);
+            auto zaxisID = vlistInqVarZaxis(vlistID, 0);
+            auto nvars = vlistNvars(vlistID);
 
-          if ((size_t) tsID >= numTsAlloc)
-            {
-              constexpr size_t NALLOC_INC = 1024;
-              numTsAlloc += NALLOC_INC;
-              datatab[fileID].resize(numTsAlloc);
-              vDateTimes[fileID].resize(numTsAlloc);
-            }
+            if (nvars > 1) cdo_abort("Input stream has more than on variable!");
+            if (gridInqSize(gridID) != 1) cdo_abort("Variable has more than one grid point!");
+            if (zaxisInqSize(zaxisID) != 1) cdo_abort("Variable has more than one level!");
 
-          nts[fileID]++;
+            vlistID0 = vlistDuplicate(vlistID);
+          }
+        else { vlist_compare(vlistID0, vlistID, CmpVlist::All); }
 
-          int varID, levelID;
-          cdo_inq_record(streamID, &varID, &levelID);
-          size_t nmiss;
-          double val;
-          cdo_read_record(streamID, &val, &nmiss);
-          datatab[fileID][tsID] = val;
-          vDateTimes[fileID][tsID] = taxisInqVdatetime(taxisID);
+        int tsID = 0;
+        size_t numTsAlloc = 0;
+        while (true)
+          {
+            auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
+            if (nrecs == 0) break;
 
-          tsID++;
-        }
+            if (nrecs != 1) cdo_abort("Input stream has more than one point in time!");
 
-      cdo_stream_close(streamID);
-    }
+            if ((size_t) tsID >= numTsAlloc)
+              {
+                constexpr size_t NALLOC_INC = 1024;
+                numTsAlloc += NALLOC_INC;
+                datatab[fileID].resize(numTsAlloc);
+                vDateTimes[fileID].resize(numTsAlloc);
+              }
 
-  // HARDCODED THE FILE NAME .. TO BE SENT AS COMMAND LINE ARGUMENT FOR THE MAGICS OPERATOR
-  // init_XML_template_parser( Filename );
-  // updatemagics_and_results_nodes( );
+            nts[fileID]++;
 
-  init_MAGICS();
+            int varID, levelID;
+            cdo_inq_record(streamID, &varID, &levelID);
+            size_t nmiss;
+            double val;
+            cdo_read_record(streamID, &val, &nmiss);
+            datatab[fileID][tsID] = val;
+            vDateTimes[fileID][tsID] = taxisInqVdatetime(taxisID);
 
-  cdo_print("Creating PLOT for %s", varname);
-  if (DBG)
-    {
-      fprintf(stderr, "Num params %d\n", nparam);
-      for (int i = 0; i < nparam; ++i) fprintf(stderr, "Param %s\n", pnames[i].c_str());
-    }
+            tsID++;
+          }
 
-  maggraph(ofilename, varname, units, nfiles, nts, vDateTimes, datatab, nparam, pnames);
+        cdo_stream_close(streamID);
+      }
 
-  // quit_XML_template_parser( );
+    // HARDCODED THE FILE NAME .. TO BE SENT AS COMMAND LINE ARGUMENT FOR THE MAGICS OPERATOR
+    // init_XML_template_parser( Filename );
+    // updatemagics_and_results_nodes( );
 
-  quit_MAGICS();
+    init_MAGICS();
 
-  if (vlistID0 != -1) vlistDestroy(vlistID0);
+    cdo_print("Creating PLOT for %s", varname);
+    if (DBG)
+      {
+        fprintf(stderr, "Num params %d\n", nparam);
+        for (int i = 0; i < nparam; ++i) fprintf(stderr, "Param %s\n", pnames[i].c_str());
+      }
+
+    maggraph(ofilename, varname, units, nfiles, nts, vDateTimes, datatab, nparam, pnames);
+
+    // quit_XML_template_parser( );
 
 #else
 
-  cdo_abort("MAGICS support not compiled in!");
-
+    cdo_abort("MAGICS support not compiled in!");
 #endif
+  }
 
-  cdo_finish();
+  void
+  close()
+  {
+#ifdef HAVE_LIBMAGICS
+    quit_MAGICS();
+    if (vlistID0 != -1) vlistDestroy(vlistID0);
+#endif
+    cdo_finish();
+  }
+};
+
+void *
+Maggraph(void *process)
+{
+  ModuleMaggraph maggraph;
+  maggraph.init(process);
+  maggraph.run();
+  maggraph.close();
 
   return nullptr;
 }
