@@ -220,7 +220,7 @@ get_processVars(int vlistID1, int gridID)
   return processVars;
 }
 
-class ModuleMaskBox
+class ModuleMaskbox
 {
 private:
   CdoStreamID streamID1;
@@ -243,7 +243,8 @@ public:
     // clang-format off
     auto MASKLONLATBOX = cdo_operator_add("masklonlatbox", 0, 0, "western and eastern longitude and southern and northern latitude");
     auto MASKINDEXBOX  = cdo_operator_add("maskindexbox",  0, 0, "index of first and last longitude and index of first and last latitude");
-    auto MASKREGION    = cdo_operator_add("maskregion",    0, 0, "the path to region file");
+    auto MASKREGION    = cdo_operator_add("maskregion",    0, 0, "DCW region or the path to region file");
+    auto MASKCIRCLE    = cdo_operator_add("maskcircle",    0, 0, "Longitude, latitude of the center and radius of the circle");
     // clang-format on
 
     auto operatorID = cdo_operator_id();
@@ -326,6 +327,25 @@ public:
 
         if (gridID0 != gridID) gridDestroy(gridID);
       }
+    else if (operatorID == MASKCIRCLE)
+      {
+        /*
+        CirclePoint cpoint;
+
+        selcircle_get_parameter(cpoint);
+        if (cpoint.radius < 0.0 || cpoint.radius > 180.0) cdo_abort("radius=%g out of bounds (0-180 deg)!", cpoint.radius);
+
+        auto gridsizemax = vlistGridsizeMax(vlistID1);
+        if (gridsizemax < cpoint.maxpoints) cpoint.maxpoints = gridsizemax;
+        if (Options::cdoVerbose)
+          cdo_print("lon = %g, lat = %g, radius = %gdeg(%gkm)", cpoint.lon, cpoint.lat, cpoint.radius,
+                    radiusDegToKm(cpoint.radius));
+
+        cpoint.radius *= DEG2RAD;
+        cpoint.lon *= DEG2RAD;
+        cpoint.lat *= DEG2RAD;
+        */
+      }
 
     varList_init(varList1, vlistID1);
 
@@ -390,7 +410,7 @@ public:
 void *
 Maskbox(void *process)
 {
-  ModuleMaskBox maskbox;
+  ModuleMaskbox maskbox;
   maskbox.init(process);
   maskbox.run();
   maskbox.close();
