@@ -152,7 +152,7 @@ set_parameter(void)
   if (Options::cdoVerbose) print_parameter();
 }
 
-class ModuleNCLwind
+class ModuleNCL_wind
 {
 
   CdoStreamID streamID1;
@@ -368,7 +368,7 @@ void *
 NCL_wind(void *process)
 
 {
-  ModuleNCLwind ncl_wind;
+  ModuleNCL_wind ncl_wind;
 
   ncl_wind.init(process);
   ncl_wind.run();
