@@ -8,8 +8,10 @@
 /*
    This module contains the following operators:
 
-      Interpolate remapcon        First order conservative remapping
-      Interpolate remapcon2       Second order conservative remapping
+      Interpolate remapcon        YAC first order conservative remapping
+      Interpolate remapycon2      YAC second order conservative remapping
+      Interpolate remapscon       SCRIP first order conservative remapping
+      Interpolate remapscon2      SCRIP second order conservative remapping
       Interpolate remapbil        Bilinear interpolation
       Interpolate remapbic        Bicubic interpolation
       Interpolate remapdis        Distance-weighted averaging
@@ -36,7 +38,7 @@ maptype_to_operfunc(const RemapSwitches &remapSwitches)
   int operfunc = -1;
 
   if (remapSwitches.mapType == RemapMethod::CONSERV_SCRIP)
-    operfunc = (remapSwitches.remapOrder == 2) ? REMAPCON2 : REMAPSCON;
+    operfunc = (remapSwitches.remapOrder == 2) ? REMAPSCON2 : REMAPSCON;
   else if (remapSwitches.mapType == RemapMethod::CONSERV)
     operfunc = (remapSwitches.submapType == SubmapType::LAF) ? REMAPLAF : ((remapSwitches.remapOrder == 2) ? REMAPYCON2 : REMAPCON);
   else if (remapSwitches.mapType == RemapMethod::BILINEAR)
@@ -215,7 +217,7 @@ remap_field(const RemapSwitches &remapSwitches, RemapType &remap, const Field &f
   // clang-format off
   if      (mapType == RemapMethod::BILINEAR) remap_bilinear(remap.search, field1, field2);
   else if (mapType == RemapMethod::BICUBIC)  remap_bicubic(remap.search, field1, field2);
-  else if (mapType == RemapMethod::DISTWGT)  remap_dist_wgt(numNeighbors, remap.search, field1, field2);
+  else if (mapType == RemapMethod::DISTWGT)  remap_distwgt(numNeighbors, remap.search, field1, field2);
   else if (mapType == RemapMethod::CONSERV)  remap_conserv(remap.vars.normOpt, remap.search, field1, field2);
   // clang-format on
 }
@@ -226,8 +228,6 @@ remap_read_weights(const std::string &remapWeightsFile, int gridID1, int gridID2
 {
   auto remapSwitches = remap_read_data_scrip(remapWeightsFile, gridID1, gridID2, remap0.srcGrid, remap0.tgtGrid, remap0.vars);
 
-  if (remap0.vars.linksPerValue == 0) remap_linksPerValue(remap0.vars);
-
   auto gridsize = remap0.srcGrid.size;
   remap0.gridID = gridID1;
   remap0.gridsize = gridInqSize(gridID1);
@@ -294,6 +294,14 @@ print_node_info(int gridID2, const RemapVars &rv, const RemapGrid &srcGrid)
     }
 }
 
+void
+obsolete_operator(const std::string &operatorOld, const std::string &operatorNew)
+{
+  std::string outStr = "The operator " + operatorOld + " is deprecated and will be removed in the next CDO release.";
+  if (operatorNew.size()) outStr += " Use the operator " + operatorNew + " instead of " + operatorOld + "!";
+  cdo_warning("%s", outStr);
+}
+
 static void
 add_operators(void)
 {
@@ -302,7 +310,7 @@ add_operators(void)
   cdo_operator_add("remapcon",     REMAPCON,     0, nullptr);
   cdo_operator_add("remapycon2test",REMAPYCON2,  0, nullptr);
   cdo_operator_add("remapscon",    REMAPSCON,    0, nullptr);
-  cdo_operator_add("remapcon2",    REMAPCON2,    0, nullptr);
+  cdo_operator_add("remapscon2",   REMAPSCON2,   0, nullptr);
   cdo_operator_add("remapbil",     REMAPBIL,     0, nullptr);
   cdo_operator_add("remapbic",     REMAPBIC,     0, nullptr);
   cdo_operator_add("remapdis",     REMAPDIS,     0, nullptr);
@@ -316,7 +324,6 @@ class ModuleRemapgrid
 {
   RemapSwitches remapSwitches;
   bool remap_genweights = Options::REMAP_genweights;
-  int remapIndex = -1;
   int numRemaps = 0;
   int numNeighbors = 0;
   std::string remapWeightsFile;
@@ -362,6 +369,9 @@ public:
 
     auto operatorID = cdo_operator_id();
     operfunc = cdo_operator_f1(operatorID);
+
+    if (operfunc == REMAPSCON) obsolete_operator("remapscon", "remapcon");
+
     auto writeRemapWeightsOnly = false;
     doRemap = (operfunc == REMAP);
 
@@ -422,9 +432,9 @@ public:
 
     maxRemaps = remapParams.maxRemaps;
     if (maxRemaps == -1) maxRemaps = set_maxremaps(vlistID1);
-    if (maxRemaps < 1) cdo_abort("max_remaps out of range (>0)!");
+    if (maxRemaps < 1) cdo_abort("maxRemaps out of range (>0)!");
 
-    remaps = std::vector<RemapType>(maxRemaps);
+    remaps.resize(maxRemaps);
 
     if (doRemap) remap_genweights = true;
 
@@ -437,8 +447,6 @@ public:
         auto gridID1 = vlistGrid(vlistID1, gridIndex1);
         remapSwitches = remap_read_weights(remapWeightsFile, gridID1, gridID2, remaps[0], extrapolateIsSet, remapExtrapolate);
         operfunc = maptype_to_operfunc(remapSwitches);
-
-        if (remapParams.test) remap_vars_reorder(remaps[0].vars);
       }
     else
       {
@@ -520,6 +528,7 @@ public:
 
                 remap_set_mask(var.gridsize, field1, nmiss1, var.missval, imask);
 
+                int remapIndex = -1;
                 for (remapIndex = numRemaps - 1; remapIndex >= 0; remapIndex--)
                   {
                     auto &remap = remaps[remapIndex];
@@ -572,7 +581,6 @@ public:
                         remap_set_int(REMAP_NUM_SRCH_BINS, numSearchBins);
 
                         remap.vars.normOpt = normOpt;
-                        remap.vars.pinit = false;
 
                         if ((mapType == RemapMethod::BILINEAR || mapType == RemapMethod::BICUBIC)
                             && (var.gridType == GRID_GME || var.gridType == GRID_UNSTRUCTURED))
@@ -616,8 +624,6 @@ public:
                           }
 
                         remap_gen_weights(remapParams.sortMode, remapSwitches, remap);
-
-                        if (remapParams.test) remap_vars_reorder(remap.vars);
                       }
                   }
 
@@ -660,7 +666,7 @@ public:
                     remap_field(remapSwitches, remap, field1, field2);
                   }
 
-                if (operfunc == REMAPSCON || operfunc == REMAPCON2 || operfunc == REMAPCON || operfunc == REMAPYCON2)
+                if (operfunc == REMAPSCON || operfunc == REMAPSCON2 || operfunc == REMAPCON || operfunc == REMAPYCON2)
                   {
                     // used only to check the result of remapcon
                     if (0) remap_normalize_field(remap.vars.normOpt, field2, remap.tgtGrid);
@@ -692,11 +698,10 @@ public:
   void
   close()
   {
-
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
 
-    for (remapIndex = 0; remapIndex < numRemaps; remapIndex++)
+    for (int remapIndex = 0; remapIndex < numRemaps; remapIndex++)
       {
         auto &remap = remaps[remapIndex];
         remap_vars_free(remap.vars);
