@@ -76,7 +76,7 @@ runpctl(double pn, int ndates, Field &field1, const FieldVector3D &vars1, int va
     field1.nmiss = runpctl(pn, ndates, field1.gridsize, field1.vec_d, field1.missval, vars1, varID, levelID, field1.memType);
 }
 
-class ModuleRunPctl
+class ModuleRunpctl
 {
   CdoStreamID streamID1;
   CdoStreamID streamID2;
@@ -232,7 +232,7 @@ public:
 void *
 Runpctl(void *process)
 {
-  ModuleRunPctl pctl;
+  ModuleRunpctl pctl;
   pctl.init(process);
   pctl.run();
   pctl.close();
