@@ -28,7 +28,7 @@
 #include "field_functions.h"
 
 static void
-addOperators(void)
+add_operators(void)
 {
   // clang-format off
   cdo_operator_add("runrange", FieldFunc_Range, 0, nullptr);
@@ -61,7 +61,6 @@ class ModuleRunstat
   FieldVector3D vars1;
   FieldVector3D vars2;
   FieldVector3D samp1;
-  std::vector<bool> imask;
 
   int ndates;
   bool lrange;
@@ -87,7 +86,7 @@ public:
         if (envval == 1) runstat_nomiss = true;
       }
 
-    addOperators();
+    add_operators();
 
     auto operatorID = cdo_operator_id();
     operfunc = cdo_operator_f1(operatorID);  // used in omp loop
@@ -148,14 +147,12 @@ public:
         fields_from_vlist(vlistID1, vars1[its], FIELD_VEC | VARS_MEMTYPE);
         if (lvars2) fields_from_vlist(vlistID1, vars2[its], FIELD_VEC);
       }
-
-    auto gridsizemax = vlistGridsizeMax(vlistID1);
-    imask = std::vector<bool>(gridsizemax);
   }
+
   void
   run()
   {
-
+    std::vector<short> imask;
     auto field2_stdvar_func = lstd ? field2_std : field2_var;
     auto fieldc_stdvar_func = lstd ? fieldc_std : fieldc_var;
 
@@ -200,12 +197,13 @@ public:
 
             if (!runstat_nomiss)
               {
+                imask.resize(fieldsize);
                 auto missval = rvars1.missval;
 
                 if (rvars1.memType == MemType::Float)
-                  for (size_t i = 0; i < fieldsize; ++i) imask[i] = !DBL_IS_EQUAL(rvars1.vec_f[i], missval);
+                  for (size_t i = 0; i < fieldsize; ++i) imask[i] = !dbl_is_equal(rvars1.vec_f[i], missval);
                 else
-                  for (size_t i = 0; i < fieldsize; ++i) imask[i] = !DBL_IS_EQUAL(rvars1.vec_d[i], missval);
+                  for (size_t i = 0; i < fieldsize; ++i) imask[i] = !dbl_is_equal(rvars1.vec_d[i], missval);
 
                 for (size_t i = 0; i < fieldsize; ++i) samp1[numSteps][varID][levelID].vec_d[i] = (double) imask[i];
 
