@@ -35,8 +35,6 @@ class ModuleSeascount
 
   int maxrecs;
 
-  SeasonStart seasonStart;
-
   VarList varList1;
   Field field;
   std::vector<RecordInfo> recList;
@@ -52,12 +50,10 @@ public:
 
     operator_check_argc(0);
 
-    seasonStart = get_season_start();
-
     streamID1 = cdo_open_read(0);
 
-    const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-    const auto vlistID2 = vlistDuplicate(vlistID1);
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID2 = vlistDuplicate(vlistID1);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
@@ -76,6 +72,8 @@ public:
   void
   run()
   {
+    auto seasonStart = get_season_start();
+
     int tsID = 0;
     int otsID = 0;
     while (true)
@@ -88,13 +86,13 @@ public:
             nrecs = cdo_stream_inq_timestep(streamID1, tsID);
             if (nrecs == 0) break;
 
-            const auto vDateTime = taxisInqVdatetime(taxisID1);
+            auto vDateTime = taxisInqVdatetime(taxisID1);
 
-            const auto month = decode_month(vDateTime.date);
+            auto month = decode_month(vDateTime.date);
             auto newmon = month;
             if (seasonStart == SeasonStart::DEC && newmon == 12) newmon = 0;
 
-            const auto seas = month_to_season(month);
+            auto seas = month_to_season(month);
 
             if (numSets == 0)
               {
@@ -120,7 +118,7 @@ public:
 
                 if (tsID == 0) recList[recID].set(varID, levelID);
 
-                const auto fieldsize = vars1[varID][levelID].size;
+                auto fieldsize = vars1[varID][levelID].size;
 
                 if (numSets == 0)
                   {
