@@ -49,7 +49,6 @@ class ModuleSeaspctl
   std::vector<RecordInfo> recList;
   HistogramSet hset;
   FieldVector constFields;
-  SeasonStart seasonStart;
 
 public:
   void
@@ -62,8 +61,6 @@ public:
     operator_input_arg("percentile number");
     pn = parameter_to_double(cdo_operator_argv(0));
 
-    seasonStart = get_season_start();
-
     streamID1 = cdo_open_read(0);
     streamID2 = cdo_open_read(1);
     streamID3 = cdo_open_read(2);
@@ -114,6 +111,8 @@ public:
   void
   run()
   {
+    auto seasonStart = get_season_start();
+
     int tsID = 0;
     int otsID = 0;
     while (true)
@@ -229,7 +228,6 @@ public:
   void
   close()
   {
-
     cdo_stream_close(streamID4);
     cdo_stream_close(streamID3);
     cdo_stream_close(streamID2);
