@@ -30,7 +30,7 @@
 #include "field_functions.h"
 
 static void
-addOperators(void)
+add_operators(void)
 {
   // clang-format off
   cdo_operator_add("seasrange", FieldFunc_Range, 0, nullptr);
@@ -71,7 +71,6 @@ class ModuleSeasstat
   VarList varList;
   FieldVector2D samp1, vars1, vars2;
   std::vector<RecordInfo> recList;
-  SeasonStart seasonStart;
 
   bool lrange;
   bool lmean;
@@ -79,7 +78,6 @@ class ModuleSeasstat
   bool lvarstd;
   bool lvars2;
   int divisor;
-  const char **seasonNames;
 
 public:
   void
@@ -87,7 +85,7 @@ public:
   {
     cdo_initialize(process);
 
-    addOperators();
+    add_operators();
 
     auto operatorID = cdo_operator_id();
     operfunc = cdo_operator_f1(operatorID);
@@ -102,9 +100,6 @@ public:
     lvars2 = (lvarstd || lrange);
     divisor = (operfunc == FieldFunc_Std1 || operfunc == FieldFunc_Var1);
 
-    seasonStart = get_season_start();
-    seasonNames = get_season_name();
-
     streamID1 = cdo_open_read(0);
 
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
@@ -139,6 +134,8 @@ public:
   void
   run()
   {
+    auto seasonStart = get_season_start();
+    auto seasonNames = get_season_name();
 
     auto field2_stdvar_func = lstd ? field2_std : field2_var;
     auto fieldc_stdvar_func = lstd ? fieldc_std : fieldc_var;
