@@ -149,7 +149,7 @@ int getNumberOfDeleteSelectionTuples();
 
 int multiSelectionParser(const char *filenameOrString);
 
-class ModuleSelMulti
+class ModuleSelmulti
 {
   CdoStreamID streamID1;
   CdoStreamID streamID2;
@@ -526,7 +526,7 @@ public:
 void *
 Selmulti(void *process)
 {
-  ModuleSelMulti selmulti;
+  ModuleSelmulti selmulti;
   selmulti.init(process);
   selmulti.run();
   selmulti.close();
