@@ -12,7 +12,7 @@
 #include "param_conversion.h"
 #include "cdi_lockedIO.h"
 
-class ModuleSelOperator
+class ModuleSeloperator
 {
 
   CdoStreamID streamID1;
@@ -141,7 +141,7 @@ public:
 void *
 Seloperator(void *process)
 {
-  ModuleSelOperator seloperator;
+  ModuleSeloperator seloperator;
   seloperator.init(process);
   seloperator.run();
   seloperator.close();
