@@ -151,7 +151,7 @@ apply_parameterList(pt_mode_t ptmode, PMList &pmlist, int nvars, int vlistID2, s
     }
 }
 
-class ModuleSetparttab
+class ModuleSetpartab
 {
   int tableID = -1;
   int tableformat = 0;
@@ -462,7 +462,7 @@ public:
 void *
 Setpartab(void *process)
 {
-  ModuleSetparttab setpartab;
+  ModuleSetpartab setpartab;
   setpartab.init(process);
   setpartab.run();
   setpartab.close();
