@@ -25,7 +25,7 @@ getkeyval_dp(const std::string &p_keyval, const char *p_key, double *val)
   auto keyval = p_keyval.c_str();
   auto keylen = strlen(p_key);
 
-  if (strncmp(keyval, p_key, keylen) == 0)
+  if (std::strncmp(keyval, p_key, keylen) == 0)
     {
       auto pkv = keyval + keylen;
       if (pkv[0] == '=' && pkv[1] != 0)
