@@ -129,7 +129,7 @@ check_varname_and_print(const VarList &varList, int vlistID, int nvars, char *ch
   if (!lfound && checkvarname) cdo_abort("Could not find variable %s!", checkvarname);
 }
 
-class ModuleShowAttribute
+class ModuleShowattribute
 {
   int delim = '@';
   int SHOWATTRIBUTE, SHOWATTSVAR;
@@ -236,7 +236,7 @@ public:
 void *
 Showattribute(void *process)
 {
-  ModuleShowAttribute showattribute;
+  ModuleShowattribute showattribute;
   showattribute.init(process);
   showattribute.run();
   showattribute.close();
