@@ -224,7 +224,7 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    varListInit(varList, vlistID1);
+    varList_init(varList, vlistID1);
 
     vars1 = FieldVector(nvars);
     vars2 = FieldVector(nvars);
