@@ -113,7 +113,6 @@ public:
   void
   init(void *process)
   {
-
     cdo_initialize(process);
 
     setParameter();
@@ -123,6 +122,7 @@ public:
     auto operatorID = cdo_operator_id();
     operfunc = cdo_operator_f1(operatorID);
 
+    auto lminmax = (operfunc == FieldFunc_Min || operfunc == FieldFunc_Max);
     lrange = (operfunc == FieldFunc_Range);
     lmean = (operfunc == FieldFunc_Mean || operfunc == FieldFunc_Avg);
     lstd = (operfunc == FieldFunc_Std || operfunc == FieldFunc_Std1);
@@ -135,6 +135,8 @@ public:
     vlistID1 = cdo_stream_inq_vlist(streamID1);
     auto vlistID2 = vlistDuplicate(vlistID1);
 
+    if (!lminmax) vlist_unpack(vlistID2);
+
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
     if (taxisHasBounds(taxisID2)) taxisDeleteBounds(taxisID2);
@@ -146,10 +148,11 @@ public:
     maxrecs = vlistNrecs(vlistID1);
     recList = std::vector<RecordInfo>(maxrecs);
 
-    varListInit(varList, vlistID1);
+    varList_init(varList, vlistID1);
 
     if ((operfunc == FieldFunc_Min) || (operfunc == FieldFunc_Max)) VARS_MEMTYPE = FIELD_NAT;
   }
+
   void
   run()
   {
@@ -304,6 +307,7 @@ public:
           otsID++;
         }
   }
+
   void
   close()
   {
@@ -313,6 +317,7 @@ public:
     cdo_finish();
   }
 };
+
 void *
 Ydaystat(void *process)
 {
@@ -320,5 +325,6 @@ Ydaystat(void *process)
   ydaystat.init(process);
   ydaystat.run();
   ydaystat.close();
+
   return nullptr;
 }
