@@ -100,8 +100,10 @@ public:
     auto vlistID3 = cdo_stream_inq_vlist(streamID3);
     auto vlistID4 = vlistDuplicate(vlistID1);
 
-    vlist_compare(vlistID1, vlistID2, CMP_ALL);
-    vlist_compare(vlistID1, vlistID3, CMP_ALL);
+    vlist_unpack(vlistID4);
+
+    vlist_compare(vlistID1, vlistID2, CmpVlist::All);
+    vlist_compare(vlistID1, vlistID3, CmpVlist::All);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = vlistInqTaxis(vlistID2);
@@ -125,13 +127,14 @@ public:
 
     constFields = FieldVector(maxrecs);
 
-    varListInit(varList1, vlistID1);
+    varList_init(varList1, vlistID1);
 
     cdiDateTimes = std::vector<CdiDateTime>(ndates + 1);
 
     vars1 = FieldVector3D(ndates + 1);
     for (int its = 0; its < ndates; its++) fields_from_vlist(vlistID1, vars1[its], FIELD_VEC | FIELD_NAT);
   }
+
   void
   run()
   {
@@ -372,6 +375,7 @@ public:
           otsID++;
         }
   }
+
   void
   close()
   {
