@@ -22,7 +22,7 @@
 #include "printinfo.h"
 #include "field_functions.h"
 
-class YearMonStat
+class ModuleYearMonStat
 {
 
 private:
@@ -77,6 +77,8 @@ public:
     vlistID1 = cdo_stream_inq_vlist(streamID1);
     vlistID2 = vlistDuplicate(vlistID1);
 
+    vlist_unpack(vlistID2);
+
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
     taxisWithBounds(taxisID2);
@@ -95,7 +97,7 @@ public:
     dtlist.set_stat(timestatDate);
     dtlist.set_calendar(calendar);
 
-    varListInit(varList, vlistID1);
+    varList_init(varList, vlistID1);
 
     fields_from_vlist(vlistID1, samp1);
     fields_from_vlist(vlistID1, vars1, FIELD_VEC);
@@ -234,9 +236,8 @@ public:
 void *
 Yearmonstat(void *process)
 {
-  YearMonStat yearmonstat;
+  ModuleYearMonStat yearmonstat;
   yearmonstat.init(process);
-
   yearmonstat.run();
   yearmonstat.close();
 
