@@ -93,7 +93,7 @@ AddQuaSum(double *dest, const double *restrict src, int len)
 static void
 VarQuaSum(double *Variance, const double *restrict Sum, int len, int n)
 {
-  const double rn1 = 1.0 / (n - 1);
+  double rn1 = 1.0 / (n - 1);
 
   for (int i = 0; i < len; ++i) Variance[i] = (Variance[i] - Sum[i] * Sum[i] * n) * rn1;
 
@@ -172,7 +172,7 @@ after_gp2sp(const AfterControl &globs, struct Variable *vars, int ccode)
 
       if (var->fourier == nullptr)
         {
-          const auto fieldSize = globs.DimFC * var->hlev;
+          auto fieldSize = globs.DimFC * var->hlev;
           var->fourier = alloc_dp(fieldSize, "gp2sp.fourier");
           after_GP2FC(var->hybrid, var->fourier, globs.Latitudes, globs.Longitudes, var->hlev, globs.Fouriers);
         }
@@ -229,15 +229,15 @@ sh2rh(int AnalysisData, double *sphum, double *rhum, double *t, int lev, int dim
   /* ***************************************************** */
   constexpr double RGAMW = (C_RCW - C_RCPV) / C_RV;
   constexpr double RBETW = C_RLVTT / C_RV + RGAMW * C_RTT;
-  const double RALPW = std::log(C_RESTT) + RBETW / C_RTT + RGAMW * std::log(C_RTT);
+  double RALPW = std::log(C_RESTT) + RBETW / C_RTT + RGAMW * std::log(C_RTT);
 
   /* ***************************************************** */
   /* Define constants for calculation in presence of  ice  */
   /* ***************************************************** */
   /*
-  const double RGAMS = (C_RCS - C_RCPV) / C_RV;
-  const double RBETS = C_RLSTT / C_RV + RGAMS * C_RTT;
-  const double RALPS = std::log(C_RESTT) + RBETS / C_RTT + RGAMS * std::log(C_RTT);
+  double RGAMS = (C_RCS - C_RCPV) / C_RV;
+  double RBETS = C_RLSTT / C_RV + RGAMS * C_RTT;
+  double RALPS = std::log(C_RESTT) + RBETS / C_RTT + RGAMS * std::log(C_RTT);
   */
   const double *fullp = AnalysisData ? level : fullpresshybrid;
 
@@ -248,7 +248,7 @@ sh2rh(int AnalysisData, double *sphum, double *rhum, double *t, int lev, int dim
   /***************************************************/
   constexpr double RGAM = RGAMW;
   constexpr double RBET = RBETW;
-  const double RALP = RALPW;
+  double RALP = RALPW;
   for (int lp = 0; lp < lev; lp++)
     {
       for (int i = 0; i < dimgpout; ++i)
@@ -281,14 +281,14 @@ rh2sh(double *sphum, double *rhum, double *t, int lev, int dimgpout, const doubl
   /* ***************************************************** */
   constexpr double RGAMW = (C_RCW - C_RCPV) / C_RV;
   constexpr double RBETW = C_RLVTT / C_RV + RGAMW * C_RTT;
-  const double RALPW = std::log(C_RESTT) + RBETW / C_RTT + RGAMW * std::log(C_RTT);
+  double RALPW = std::log(C_RESTT) + RBETW / C_RTT + RGAMW * std::log(C_RTT);
 
   /* ***************************************************** */
   /* Define constants for calculation in presence of  ice  */
   /* ***************************************************** */
-  // const double RGAMS = (C_RCS - C_RCPV) / C_RV;
-  // const double RBETS = C_RLSTT / C_RV + RGAMS * C_RTT;
-  // const double RALPS = std::log(C_RESTT) + RBETS / C_RTT + RGAMS * std::log(C_RTT);
+  // double RGAMS = (C_RCS - C_RCPV) / C_RV;
+  // double RBETS = C_RLSTT / C_RV + RGAMS * C_RTT;
+  // double RALPS = std::log(C_RESTT) + RBETS / C_RTT + RGAMS * std::log(C_RTT);
 
   /***************************************************/
   /* Diagnostics of saturation water vapour pressure */
@@ -298,7 +298,7 @@ rh2sh(double *sphum, double *rhum, double *t, int lev, int dimgpout, const doubl
 
   constexpr double RGAM = RGAMW;
   constexpr double RBET = RBETW;
-  const double RALP = RALPW;
+  double RALP = RALPW;
   for (int lp = 0; lp < lev; lp++)
     {
       for (int i = 0; i < dimgpout; ++i)
@@ -319,7 +319,7 @@ rh2sh(double *sphum, double *rhum, double *t, int lev, int dimgpout, const doubl
 void
 after_FCrh2FCsh(const AfterControl &globs, struct Variable *vars)
 {
-  const auto fieldSize = globs.DimGP * globs.NumLevelRequest;
+  auto fieldSize = globs.DimGP * globs.NumLevelRequest;
 
   if (vars[RHUMIDITY].grid == nullptr) vars[RHUMIDITY].grid = alloc_dp(fieldSize, "vars[RHUMIDITY].grid");
   if (vars[TEMPERATURE].grid == nullptr) vars[TEMPERATURE].grid = alloc_dp(fieldSize, "vars[TEMPERATURE].grid");
@@ -346,7 +346,7 @@ after_SPuv2SPdv(const AfterControl &globs, struct Variable *vars)
 
   Div = DivOut = vars[DIVERGENCE].spectral;
   Vor = VorOut = vars[VORTICITY].spectral;
-  const auto fieldSize = globs.DimFC * globs.NumLevelRequest;
+  auto fieldSize = globs.DimFC * globs.NumLevelRequest;
 
   if (vars[U_WIND].fourier == nullptr) vars[U_WIND].fourier = alloc_dp(fieldSize, "vars[U_WIND].fourier");
   if (vars[V_WIND].fourier == nullptr) vars[V_WIND].fourier = alloc_dp(fieldSize, "vars[V_WIND].fourier");
@@ -375,7 +375,7 @@ after_SPuv2SPdv(const AfterControl &globs, struct Variable *vars)
 void
 after_FCsh2FCrh(const AfterControl &globs, struct Variable *vars)
 {
-  const auto fieldSize = globs.DimGP * globs.NumLevelRequest;
+  auto fieldSize = globs.DimGP * globs.NumLevelRequest;
 
   if (vars[RHUMIDITY].grid == nullptr) vars[RHUMIDITY].grid = alloc_dp(fieldSize, "vars[RHUMIDITY].grid");
   if (vars[TEMPERATURE].grid == nullptr) vars[TEMPERATURE].grid = alloc_dp(fieldSize, "vars[TEMPERATURE].grid");
@@ -516,10 +516,10 @@ after_processPL(AfterControl &globs, struct Variable *vars)
           {
             if (!vars[code].spectral) afterAbort("Code %d not available on spectral space!", code);
 
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimSP;
+                auto offset = k * globs.DimSP;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].spectral + offset, 0);
               }
@@ -541,7 +541,7 @@ after_processPL(AfterControl &globs, struct Variable *vars)
           {
             if (vars[code].fourier == nullptr)
               {
-                const auto fieldSize = vars[code].plev * globs.DimFC;
+                auto fieldSize = vars[code].plev * globs.DimFC;
                 vars[code].fourier = alloc_dp(fieldSize, FieldName(code, "fourier"));
               }
             sp2fc(vars[code].spectral, vars[code].fourier, globs.poli, vars[code].plev, globs.Latitudes, globs.Fouriers,
@@ -592,10 +592,10 @@ after_processPL(AfterControl &globs, struct Variable *vars)
           {
             if (!vars[code].fourier) afterAbort("Code %d not available on fourier space!", code);
 
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimFC;
+                auto offset = k * globs.DimFC;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].fourier + offset, 0);
               }
@@ -616,10 +616,10 @@ after_processPL(AfterControl &globs, struct Variable *vars)
           {
             if (!vars[code].fourier) afterAbort("Code %d not available on zonal mean!", code);
 
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimFC;
+                auto offset = k * globs.DimFC;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].fourier + offset, 0);
               }
@@ -646,7 +646,7 @@ after_processPL(AfterControl &globs, struct Variable *vars)
           {
             if (vars[code].grid == nullptr)
               {
-                const auto fieldSize = vars[code].plev * globs.DimGP;
+                auto fieldSize = vars[code].plev * globs.DimGP;
                 vars[code].grid = alloc_dp(fieldSize, FieldName(code, "grid"));
               }
 
@@ -692,7 +692,7 @@ after_processPL(AfterControl &globs, struct Variable *vars)
     for (int code = 0; code < MaxCodes; ++code)
       if (vars[code].needed && vars[code].grid)
         {
-          const auto fieldSize = globs.DimGP * vars[code].plev;
+          auto fieldSize = globs.DimGP * vars[code].plev;
           if (vars[code].mean == nullptr) vars[code].mean = alloc_dp(fieldSize, FieldName(code, "mean"));
 
           if (globs.MeanCount == 1)
@@ -719,7 +719,7 @@ after_processPL(AfterControl &globs, struct Variable *vars)
     for (int code = 0; code < MaxCodes; ++code)
       if (vars[code].needed && vars[code].mean)
         {
-          const auto fieldSize = globs.DimGP * vars[code].plev;
+          auto fieldSize = globs.DimGP * vars[code].plev;
           if (vars[code].variance == nullptr) vars[code].variance = alloc_dp(fieldSize, FieldName(code, "var"));
           if (globs.MeanCount == 1)
             IniQuaSum(vars[code].variance, vars[code].grid, fieldSize);
@@ -744,10 +744,10 @@ after_processPL(AfterControl &globs, struct Variable *vars)
       for (int code = 0; code < MaxCodes; ++code)
         if (vars[code].selected)
           {
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimGP;
+                auto offset = k * globs.DimGP;
                 if (globs.Mean != 2)
                   {
                     streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
@@ -775,10 +775,10 @@ after_processPL(AfterControl &globs, struct Variable *vars)
       for (int code = 0; code < MaxCodes; ++code)
         if (vars[code].selected)
           {
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimGP;
+                auto offset = k * globs.DimGP;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].grid + offset, vars[code].nmiss);
               }
@@ -795,7 +795,7 @@ theta(double *pthetaf, double *pthetah, double *ph, double *ps, double *tf, doub
   double *thetah = pthetah;
   double *thetaf = pthetaf;
 
-  const double kappa = PlanetRD / C_RCPD;
+  double kappa = PlanetRD / C_RCPD;
 
   for (int h = 0; h < dimgp; h++) thetah[h] = 0.0;
   thetah += dimgp;
@@ -874,7 +874,7 @@ Omega(double *omega_in, double *divergence, double *u_wind, double *v_wind, doub
           Cterm = vct[j + 1] * vct[nlev + j + 1] - vct[j] * vct[nlev + j + 2];
           for (int i = 0; i < dimgp; ++i)
             {
-              if (IS_NOT_EQUAL(Cterm, 0.0))
+              if (is_not_equal(Cterm, 0.0))
                 Pterm = Cterm / (halfp[i + dimgp] - halfp[i]) * std::log(halfp[i + dimgp] / halfp[i]);
               else
                 Pterm = 0.0;
@@ -897,8 +897,8 @@ geopot_height_halflevel(double *gheight, const double *const ta_fl, const double
   // hus_fl:  specific humidity on full levels
   // p_hl:    pressure on half levels
 
-  const double z2log2 = 2.0 * std::log(2.0);
-  const double vtmp = (C_RV / PlanetRD) - 1.0;
+  double z2log2 = 2.0 * std::log(2.0);
+  double vtmp = (C_RV / PlanetRD) - 1.0;
 
   if (hus_fl)  // Humidity is present
     {
@@ -931,7 +931,7 @@ geopot_height_halflevel(double *gheight, const double *const ta_fl, const double
       for (long i = 0; i < ngp; ++i) gheight[i] = gheight[i + ngp] + PlanetRD * ta_fl[i] * z2log2;
     }
 
-  const double zrg = 1.0 / PlanetGrav;
+  double zrg = 1.0 / PlanetGrav;
   for (long i = 0; i < ngp * (nlev + 1); ++i) gheight[i] *= zrg;
 }
 
@@ -946,8 +946,8 @@ geopot_height_fulllevel(double *gheight, const double *const ta_fl, const double
   // hus_fl:  specific humidity on full levels
   // p_hl:    pressure on half levels
 
-  const double zlog2 = std::log(2.0);
-  const double vtmp = (C_RV / PlanetRD) - 1.0;
+  double zlog2 = std::log(2.0);
+  double vtmp = (C_RV / PlanetRD) - 1.0;
 
   if (hus_fl)  // Humidity is present
     {
@@ -1002,7 +1002,7 @@ geopot_height_fulllevel(double *gheight, const double *const ta_fl, const double
         }
     }
 
-  const double zrg = 1.0 / PlanetGrav;
+  double zrg = 1.0 / PlanetGrav;
   for (long i = 0; i < ngp * (nlev + 1); ++i) gheight[i] *= zrg;
 }
 
@@ -1021,10 +1021,10 @@ LayerWater(double *ww, double *ll, double pmax, double pmin, int DimGP, int Half
   for (k = 0; k < HalfLevels; ++k) pph[k] = vct[k] + vct[k + HalfLevels] * SCALESLP;
   for (k = 0; k < HalfLevels; ++k)
     if (pph[k] > pmax) break;
-  const auto MaxLev = k - 1;
+  auto MaxLev = k - 1;
   for (k = HalfLevels - 1; k >= 0; k--)
     if (pph[k] < pmin) break;
-  const auto MinLev = k;
+  auto MinLev = k;
 
   varray_fill(DimGP, ll, 0.0);
 
@@ -1049,10 +1049,10 @@ LayerCloud(double *cc, double *ll, double pmax, double pmin, int DimGP, int Half
   for (k = 0; k < HalfLevels; ++k) pph[k] = vct[k] + vct[k + HalfLevels] * SCALESLP;
   for (k = 0; k < HalfLevels; ++k)
     if (pph[k] > pmax) break;
-  const auto MaxLev = k - 1;
+  auto MaxLev = k - 1;
   for (k = HalfLevels - 1; k >= 0; k--)
     if (pph[k] < pmin) break;
-  const auto MinLev = k;
+  auto MinLev = k;
 
   for (int i = 0; i < DimGP; ++i) ll[i] = 1. - cc[i + MaxLev * DimGP];
 
@@ -1506,10 +1506,10 @@ after_processML(AfterControl &globs, struct Variable *vars)
           {
             if (!vars[code].spectral) afterAbort("Code %d not available on spectral space!", code);
 
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimSP;
+                auto offset = k * globs.DimSP;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].spectral + offset, 0);
               }
@@ -1530,7 +1530,7 @@ after_processML(AfterControl &globs, struct Variable *vars)
           {
             if (vars[code].fourier == nullptr)
               {
-                const auto fieldSize = vars[code].hlev * globs.DimFC;
+                auto fieldSize = vars[code].hlev * globs.DimFC;
                 vars[code].fourier = alloc_dp(fieldSize, FieldName(code, "fourier"));
                 sp2fc(vars[code].spectral, vars[code].fourier, globs.poli, vars[code].hlev, globs.Latitudes, globs.Fouriers,
                       globs.Truncation);
@@ -1577,10 +1577,10 @@ after_processML(AfterControl &globs, struct Variable *vars)
           {
             if (!vars[code].fourier) afterAbort("Code %d not available on fourier space!", code);
 
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimFC;
+                auto offset = k * globs.DimFC;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].fourier + offset, 0);
               }
@@ -1601,10 +1601,10 @@ after_processML(AfterControl &globs, struct Variable *vars)
           {
             if (!vars[code].fourier) afterAbort("Code %d not available on zonal mean!", code);
 
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimFC;
+                auto offset = k * globs.DimFC;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].fourier + offset, 0);
               }
@@ -1625,7 +1625,7 @@ after_processML(AfterControl &globs, struct Variable *vars)
           {
             if (vars[code].hybrid == nullptr)
               {
-                const auto fieldSize = globs.DimGP * vars[code].hlev;
+                auto fieldSize = globs.DimGP * vars[code].hlev;
                 vars[code].hybrid = alloc_dp(fieldSize, FieldName(code, "hybrid"));
                 after_FC2GP(vars[code].fourier, vars[code].hybrid, globs.Latitudes, globs.Longitudes, vars[code].hlev,
                             globs.Fouriers);
@@ -1685,7 +1685,7 @@ after_processML(AfterControl &globs, struct Variable *vars)
             {
               if (vars[code].selected && vars[code].hybrid)
                 {
-                  const auto fieldSize = globs.DimGP * vars[code].hlev;
+                  auto fieldSize = globs.DimGP * vars[code].hlev;
 
                   if (vars[code].mean == nullptr) vars[code].mean = alloc_dp(fieldSize, FieldName(code, "mean"));
 
@@ -1729,10 +1729,10 @@ after_processML(AfterControl &globs, struct Variable *vars)
               {
                 if (vars[code].hybrid == nullptr) afterAbort("Internal problem. Code %d not allocated!", code);
 
-                const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+                int nlevels = zaxisInqSize(vars[code].ozaxisID);
                 for (int k = 0; k < nlevels; ++k)
                   {
-                    const auto offset = k * globs.DimGP;
+                    auto offset = k * globs.DimGP;
                     if (globs.Mean != 2)
                       {
                         streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
@@ -1764,7 +1764,7 @@ after_processML(AfterControl &globs, struct Variable *vars)
       if (globs.unitsel)
         {
           if (globs.p_of_height == nullptr) globs.p_of_height = alloc_dp(globs.NumLevelRequest, "p_of_height");
-          height_to_pressure(globs.p_of_height, globs.LevelRequest, globs.NumLevelRequest);
+          height_to_pressure(globs.LevelRequest, globs.p_of_height, globs.NumLevelRequest);
           pressureLevel = globs.p_of_height;
         }
       else
@@ -1796,7 +1796,7 @@ after_processML(AfterControl &globs, struct Variable *vars)
               {
                 if (vars[code].grid == nullptr)
                   {
-                    const auto fieldSize = globs.DimGP * globs.NumLevelRequest;
+                    auto fieldSize = globs.DimGP * globs.NumLevelRequest;
                     vars[code].grid = alloc_dp(fieldSize, FieldName(code, "grid"));
                   }
 
@@ -1844,12 +1844,12 @@ after_processML(AfterControl &globs, struct Variable *vars)
       for (int code = 0; code < MaxCodes; ++code)
         if (vars[code].selected && vars[code].grid)
           {
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
                 if (globs.Mean != 2)
                   {
-                    const auto offset = k * globs.DimGP;
+                    auto offset = k * globs.DimGP;
                     streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                     streamWriteRecord(globs.ostreamID, vars[code].grid + offset, vars[code].nmiss);
                   }
@@ -1868,7 +1868,7 @@ after_processML(AfterControl &globs, struct Variable *vars)
     for (int code = 0; code < MaxCodes; ++code)
       if (vars[code].needed && vars[code].grid)
         {
-          const auto fieldSize = globs.DimGP * vars[code].plev;
+          auto fieldSize = globs.DimGP * vars[code].plev;
 
           if (vars[code].mean == nullptr) vars[code].mean = alloc_dp(fieldSize, FieldName(code, "mean"));
 
@@ -1896,7 +1896,7 @@ after_processML(AfterControl &globs, struct Variable *vars)
     for (int code = 0; code < MaxCodes; ++code)
       if (vars[code].needed && vars[code].mean)
         {
-          const auto fieldSize = globs.DimGP * vars[code].plev;
+          auto fieldSize = globs.DimGP * vars[code].plev;
 
           if (vars[code].variance == nullptr) vars[code].variance = alloc_dp(fieldSize, FieldName(code, "var"));
 
@@ -1923,10 +1923,10 @@ after_processML(AfterControl &globs, struct Variable *vars)
       for (int code = 0; code < MaxCodes; ++code)
         if (vars[code].selected && vars[code].mean)
           {
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimGP;
+                auto offset = k * globs.DimGP;
                 if (globs.Mean != 2)
                   {
                     streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
@@ -1972,7 +1972,7 @@ after_processML(AfterControl &globs, struct Variable *vars)
 
             if (vars[code].fourier == nullptr)
               {
-                const auto fieldSize = globs.DimFC * vars[code].plev;
+                auto fieldSize = globs.DimFC * vars[code].plev;
                 vars[code].fourier = alloc_dp(fieldSize, FieldName(code, "fourier"));
               }
 
@@ -1996,10 +1996,10 @@ after_processML(AfterControl &globs, struct Variable *vars)
           {
             if (!vars[code].fourier) afterAbort("Code %d not available on fourier space!", code);
 
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimFC;
+                auto offset = k * globs.DimFC;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].fourier + offset, vars[code].nmiss);
               }
@@ -2020,10 +2020,10 @@ after_processML(AfterControl &globs, struct Variable *vars)
           {
             if (!vars[code].fourier) afterAbort("Code %d not available on zonal mean!", code);
 
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimFC;
+                auto offset = k * globs.DimFC;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].fourier + offset, vars[code].nmiss);
               }
@@ -2049,7 +2049,7 @@ after_processML(AfterControl &globs, struct Variable *vars)
           {
             if (vars[code].spectral == nullptr)
               {
-                const auto fieldSize = vars[code].plev * globs.DimSP;
+                auto fieldSize = vars[code].plev * globs.DimSP;
                 vars[code].spectral = alloc_dp(fieldSize, FieldName(code, "spectral"));
               }
 
@@ -2102,10 +2102,10 @@ after_processML(AfterControl &globs, struct Variable *vars)
       for (int code = 0; code < MaxCodes; ++code)
         if (vars[code].selected && vars[code].spectral)
           {
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimSP;
+                auto offset = k * globs.DimSP;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].spectral + offset, 0);
               }
@@ -2126,7 +2126,7 @@ after_processML(AfterControl &globs, struct Variable *vars)
           {
             if (vars[code].fourier == nullptr)
               {
-                const auto fieldSize = vars[code].plev * globs.DimFC;
+                auto fieldSize = vars[code].plev * globs.DimFC;
                 vars[code].fourier = alloc_dp(fieldSize, FieldName(code, "fourier"));
               }
             sp2fc(vars[code].spectral, vars[code].fourier, globs.poli, vars[code].plev, globs.Latitudes, globs.Fouriers,
@@ -2151,10 +2151,10 @@ after_processML(AfterControl &globs, struct Variable *vars)
           {
             if (!vars[code].fourier) afterAbort("Code %d not available on fourier space!", code);
 
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimFC;
+                auto offset = k * globs.DimFC;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].fourier + offset, 0);
               }
@@ -2175,10 +2175,10 @@ after_processML(AfterControl &globs, struct Variable *vars)
           {
             if (!vars[code].fourier) afterAbort("Code %d not available on zonal mean!", code);
 
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimFC;
+                auto offset = k * globs.DimFC;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].fourier + offset, vars[code].nmiss);
               }
@@ -2197,7 +2197,7 @@ after_processML(AfterControl &globs, struct Variable *vars)
       for (int code = 0; code < MaxCodes; ++code)
         if (vars[code].needed && vars[code].fourier)
           {
-            const auto fieldSize = vars[code].plev * globs.DimGP;
+            auto fieldSize = vars[code].plev * globs.DimGP;
             if (vars[code].grid == nullptr) vars[code].grid = alloc_dp(fieldSize, FieldName(code, "grid"));
 
             after_FC2GP(vars[code].fourier, vars[code].grid, globs.Latitudes, globs.Longitudes, vars[code].plev, globs.Fouriers);
@@ -2215,10 +2215,10 @@ after_processML(AfterControl &globs, struct Variable *vars)
       for (int code = 0; code < MaxCodes; ++code)
         if (vars[code].selected)
           {
-            const int nlevels = zaxisInqSize(vars[code].ozaxisID);
+            int nlevels = zaxisInqSize(vars[code].ozaxisID);
             for (int k = 0; k < nlevels; ++k)
               {
-                const auto offset = k * globs.DimGP;
+                auto offset = k * globs.DimGP;
                 streamDefRecord(globs.ostreamID, vars[code].ovarID, k);
                 streamWriteRecord(globs.ostreamID, vars[code].grid + offset, vars[code].nmiss);
               }
@@ -2254,14 +2254,14 @@ after_AnalysisAddRecord(const AfterControl *globs, struct Variable *vars, int co
         {
           if (code != U_WIND && code != V_WIND)
             {
-              const auto fieldSize = globs->Dim3SP;
+              auto fieldSize = globs->Dim3SP;
               if (vars[code].spectral0 == nullptr) vars[code].spectral0 = alloc_dp(fieldSize, FieldName(code, "spectral"));
               truncation = gridInqTrunc(gridID);
               sp2sp(globs->Field, truncation, vars[code].spectral0 + levelID * globs->DimSP, globs->Truncation);
             }
           else
             {
-              const auto fieldSize = globs->Dim3SP;
+              auto fieldSize = globs->Dim3SP;
               if (vars[code].spectral0 == nullptr) vars[code].spectral0 = alloc_dp(fieldSize, FieldName(code, "spectral"));
               array_copy(globs->DimSP, globs->Field, vars[code].spectral0 + levelID * globs->DimSP);
             }
@@ -2274,7 +2274,7 @@ after_AnalysisAddRecord(const AfterControl *globs, struct Variable *vars, int co
       if (nlevel > 1 && leveltype == ZAXIS_PRESSURE)
         {
           vars[code].sfit = true;
-          const auto fieldSize = globs->Dim3GP;
+          auto fieldSize = globs->Dim3GP;
           vars[code].hlev = globs->NumLevelRequest;
           vars[code].plev = globs->NumLevelRequest;
           if (vars[code].grid0 == nullptr) vars[code].grid0 = alloc_dp(fieldSize, FieldName(code, "grid0"));
@@ -2283,7 +2283,7 @@ after_AnalysisAddRecord(const AfterControl *globs, struct Variable *vars, int co
       else
         {
           vars[code].sfit = false;
-          const auto fieldSize = globs->DimGP;
+          auto fieldSize = globs->DimGP;
           vars[code].hlev = 1;
           vars[code].plev = 1;
           if (vars[code].grid0 == nullptr) vars[code].grid0 = alloc_dp(fieldSize, FieldName(code, "grid0"));
@@ -2299,7 +2299,7 @@ after_AnalysisAddRecord(const AfterControl *globs, struct Variable *vars, int co
             }
 
           for (size_t i = 0; i < gridSize; ++i)
-            if (IS_NOT_EQUAL(globs->Field[i], vars[code].missval)) vars[code].samp[i + dataOffset]++;
+            if (is_not_equal(globs->Field[i], vars[code].missval)) vars[code].samp[i + dataOffset]++;
         }
     }
 }
@@ -2307,11 +2307,11 @@ after_AnalysisAddRecord(const AfterControl *globs, struct Variable *vars, int co
 double *
 after_get_dataptr(struct Variable *vars, int code, int gridID, int zaxisID, int levelID)
 {
-  const auto gridtype = gridInqType(gridID);
-  const auto nlevel = zaxisInqSize(zaxisID);
-  const auto gridSize = gridInqSize(gridID);
-  const auto dataSize = gridSize * nlevel;
-  const auto dataOffset = gridSize * levelID;
+  auto gridtype = gridInqType(gridID);
+  auto nlevel = zaxisInqSize(zaxisID);
+  auto gridSize = gridInqSize(gridID);
+  auto dataSize = gridSize * nlevel;
+  auto dataOffset = gridSize * levelID;
 
   double *dataptr = nullptr;
 
@@ -2334,12 +2334,12 @@ after_get_dataptr(struct Variable *vars, int code, int gridID, int zaxisID, int
 void
 after_EchamAddRecord(const AfterControl *globs, struct Variable *vars, int code, int gridID, int zaxisID, int levelID, size_t nmiss)
 {
-  const auto gridtype = gridInqType(gridID);
-  const auto leveltype = zaxisInqType(zaxisID);
-  const auto nlevel = zaxisInqSize(zaxisID);
-  const auto gridSize = gridInqSize(gridID);
-  const auto dataSize = gridSize * nlevel;
-  const auto dataOffset = gridSize * levelID;
+  auto gridtype = gridInqType(gridID);
+  auto leveltype = zaxisInqType(zaxisID);
+  auto nlevel = zaxisInqSize(zaxisID);
+  auto gridSize = gridInqSize(gridID);
+  auto dataSize = gridSize * nlevel;
+  auto dataOffset = gridSize * levelID;
 
   vars[code].nmiss0 += nmiss;
 
@@ -2374,7 +2374,7 @@ after_EchamAddRecord(const AfterControl *globs, struct Variable *vars, int code,
 
           double *dataptr = vars[code].hybrid0 + dataOffset;
           for (size_t i = 0; i < gridSize; ++i)
-            if (IS_NOT_EQUAL(dataptr[i], vars[code].missval)) vars[code].samp[i + dataOffset]++;
+            if (is_not_equal(dataptr[i], vars[code].missval)) vars[code].samp[i + dataOffset]++;
         }
     }
 }
