@@ -763,10 +763,10 @@ print_system_info()
   fprintf(stderr, "STD ANSI C          = %d\n", __STDC__);
 #endif
 #ifdef __STD_VERSION__
-  fprintf(stderr, "STD VERSION         = %ld\n", __STD_VERSION__);
+  fprintf(stderr, "STD VERSION         = %ld\n", (long)__STD_VERSION__);
 #endif
 #ifdef __STDC_VERSION__
-  fprintf(stderr, "STDC VERSION        = %ld\n", __STDC_VERSION__);
+  fprintf(stderr, "STDC VERSION        = %ld\n", (long)__STDC_VERSION__);
 #endif
 #ifdef __STD_HOSTED__
   fprintf(stderr, "STD HOSTED          = %d\n", __STD_HOSTED__);
@@ -1304,7 +1304,7 @@ setup_cli_options()
       ->describe_argument("grid")
       ->add_effect([&](const std::string &argument) { cdo_set_grids(argument.c_str()); })
       ->add_help("Set default grid name or file. Available grids: ",
-                 "F<XXX>, t<RES>, tl<RES>, r<NX>x<NY>, global_<DXY>, zonal_<DY>, gme<NI>, lon=<LON>/lat=<LAT>");
+                 "F<XXX>, t<RES>, tl<RES>, r<NX>x<NY>, global_<DXY>, zonal_<DY>, gme<NI>, lon=<LON>/lat=<LAT>, hpz<ZOOM>");
 
   CLIOptions::option("institution", "i")
       ->describe_argument("institute_name")
@@ -1451,6 +1451,11 @@ setup_cli_options()
       ->add_help("Enables multithreaded I/O.")
       ->set_category("Multi Threading");
 
+  CLIOptions::option("shuffle")
+      ->add_effect([&]() { Options::cdoShuffle = true; })
+      ->set_category("Compression")
+      ->add_help("Specify shuffling of variable data bytes before compression (NetCDF)");
+
   CLIOptions::option("compress", "Z")
       ->add_effect([&]() { Options::cdoCompress = true; })
       ->set_category("Compression")
@@ -1459,7 +1464,7 @@ setup_cli_options()
   CLIOptions::option("filter", "F")
       ->describe_argument("filterId,params")
       ->add_effect([&](const std::string &argument) { define_filter(argument); })
-      ->set_category("Fromat Specific")
+      ->set_category("Compression")
       ->add_help("NetCDF4/HDF5 filter description.");
 
   CLIOptions::option("compression_type", "z")
@@ -1488,11 +1493,13 @@ setup_cli_options()
       ->add_help("Explanation and Examples for subgrouping operators with [ ] syntax")
       ->add_effect([&]() { cdo_display_syntax_help(Parser::subgroup_help, stderr); })
       ->set_category("Help");
+
   CLIOptions::option("apply")
       ->aborts_program(true)
       ->add_help("Explanation and Examples for -apply syntax")
       ->add_effect([&]() { cdo_display_syntax_help(Parser::apply_help, stderr); })
       ->set_category("Help");
+
   CLIOptions::option("sortparam")->add_effect([]() { cdiDefGlobal("SORTPARAM", true); });
 
 #ifdef HIRLAM_EXTENSIONS
