@@ -223,6 +223,7 @@ CLIOptions::option(const std::string &p_name, const std::string &p_shortForm)
     }
   return optionRegistry.back();
 }
+
 std::string
 CLIOptions::print_envvar_help()
 {
@@ -241,8 +242,9 @@ CLIOptions::print_envvar_help()
     }
   return helpString.str();
 }
+
 std::string
-CLIOptions::print_options_help(const std::string p_category)
+CLIOptions::print_options_help(const std::string &p_category)
 {
   std::stringstream help;
   for (auto &iter : optionMap)
