@@ -193,7 +193,7 @@ public:
   static cdo_option_2 *option_from_envvar(const std::string &p_envvarName);
 
   static void print_available_options();
-  static std::string print_options_help(std::string p_category = DEFAULT_CATEGORY);
+  static std::string print_options_help(const std::string &p_category = DEFAULT_CATEGORY);
   static std::string print_envvar_help();
   static void print_registry(const std::vector<std::shared_ptr<cdo_option_2>> &p_registry);
 };
