@@ -4,7 +4,7 @@
 #include "mpmo_color.h"
 
 InternalCdoSyntaxError::InternalCdoSyntaxError(std::vector<std::string>::const_iterator p_iter, const std::string &p_msg,
-                                               std::string p_file, std::string p_line)
+                                               const std::string &p_file, const std::string &p_line)
     : CdoException(p_msg, p_file, p_line), iter(p_iter)
 {
 }
