@@ -76,7 +76,7 @@ compare_lat_reg2d(size_t ysize, int gridID1, int gridID2)
       auto ny2 = gridInqYvals(gridID2, &yvals2[0]);
       if (ny1 == 0 || ny2 == 0) return;
 
-      if (IS_EQUAL(yvals1[0], yvals2[ysize - 1]) && IS_EQUAL(yvals1[ysize - 1], yvals2[0]))
+      if (is_equal(yvals1[0], yvals2[ysize - 1]) && is_equal(yvals1[ysize - 1], yvals2[0]))
         {
           if (yvals1[0] > yvals2[0])
             cdo_abort("Latitude orientation differ! First grid: N->S; second grid: S->N");
@@ -167,7 +167,10 @@ cdo_compare_grids(int gridID1, int gridID2)
           else
             cdo_warning("xsize of input grids differ!");
         }
-      else if (gridType1 == GRID_CURVILINEAR || gridType2 == GRID_UNSTRUCTURED) { compare_grid_unstructured(gridID1, gridID2); }
+      else if (gridType1 == GRID_CURVILINEAR || gridType2 == GRID_UNSTRUCTURED)
+        {
+          compare_grid_unstructured(gridID1, gridID2);
+        }
     }
   else if (gridInqSize(gridID1) > 1)
     {
@@ -175,8 +178,8 @@ cdo_compare_grids(int gridID1, int gridID2)
     }
 }
 
-static int
-zaxisCheckLevels(int zaxisID1, int zaxisID2)
+int
+zaxis_check_levels(int zaxisID1, int zaxisID2)
 {
   if (zaxisID1 != zaxisID2)
     {
@@ -190,7 +193,7 @@ zaxisCheckLevels(int zaxisID1, int zaxisID2)
 
       auto ldiffer = false;
       for (int i = 0; i < nlev1; ++i)
-        if (IS_NOT_EQUAL(lev1[i], lev2[i]))
+        if (is_not_equal(lev1[i], lev2[i]))
           {
             ldiffer = true;
             break;
@@ -199,7 +202,7 @@ zaxisCheckLevels(int zaxisID1, int zaxisID2)
         {
           ldiffer = false;
           for (int i = 0; i < nlev1; ++i)
-            if (IS_NOT_EQUAL(lev1[i], lev2[nlev1 - 1 - i]))
+            if (is_not_equal(lev1[i], lev2[nlev1 - 1 - i]))
               {
                 ldiffer = true;
                 break;
@@ -217,126 +220,10 @@ zaxisCheckLevels(int zaxisID1, int zaxisID2)
   return 0;
 }
 
-static void
-vlistCheckNames(int vlistID1, int vlistID2)
-{
-  auto nvars = vlistNvars(vlistID1);
-
-  std::vector<std::string> names1(nvars);
-  std::vector<std::string> names2(nvars);
-  for (int varID = 0; varID < nvars; ++varID) names1[varID] = cdo::inq_var_name(vlistID1, varID);
-  for (int varID = 0; varID < nvars; ++varID) names2[varID] = cdo::inq_var_name(vlistID2, varID);
-
-  std::sort(names1.begin(), names1.end());
-  std::sort(names2.begin(), names2.end());
-
-  int varID;
-  for (varID = 0; varID < nvars; ++varID)
-    if (names1[varID] != names2[varID]) break;
-
-  if (varID == nvars) cdo_print("Use CDO option --sortname to sort the parameter by name (NetCDF only)!");
-}
-
-static void
-vlistPrintMissingVars(int vlistID1, int vlistID2)
-{
-  auto nvars1 = vlistNvars(vlistID1);
-  auto nvars2 = vlistNvars(vlistID2);
-
-  std::vector<std::string> names1(nvars1);
-  std::vector<std::string> names2(nvars2);
-  for (int varID1 = 0; varID1 < nvars1; ++varID1) names1[varID1] = cdo::inq_var_name(vlistID1, varID1);
-  for (int varID2 = 0; varID2 < nvars2; ++varID2) names2[varID2] = cdo::inq_var_name(vlistID2, varID2);
-
-  if (nvars1 > nvars2)
-    {
-      for (int varID1 = 0; varID1 < nvars1; ++varID1)
-        {
-          int varID2;
-          for (varID2 = 0; varID2 < nvars2; ++varID2)
-            {
-              if (names1[varID1] == names2[varID2]) break;
-            }
-          if (varID2 == nvars2) cdo_print("Variable %s not found in second input stream!", names1[varID1]);
-        }
-    }
-  else
-    {
-      for (int varID2 = 0; varID2 < nvars2; ++varID2)
-        {
-          int varID1;
-          for (varID1 = 0; varID1 < nvars1; ++varID1)
-            {
-              if (names1[varID1] == names2[varID2]) break;
-            }
-          if (varID1 == nvars1) cdo_print("Variable %s not found in first input stream!", names2[varID2]);
-        }
-    }
-}
-
-void
-vlist_compare(int vlistID1, int vlistID2, int flag)
-{
-  auto lchecknames = false;
-
-  auto nvars = vlistNvars(vlistID1);
-
-  if (nvars != vlistNvars(vlistID2))
-    {
-      vlistPrintMissingVars(vlistID1, vlistID2);
-      cdo_abort("Input streams have different number of variables per timestep!");
-    }
-
-  if (vlistNrecs(vlistID1) != vlistNrecs(vlistID2))
-    cdo_abort("Input streams have different number of %s per timestep!", (nvars == 1) ? "layers" : "records");
-
-  for (int varID = 0; varID < nvars; ++varID)
-    {
-      if (nvars > 1)
-        {
-          if (flag & CMP_NAME)
-            {
-              auto name1 = string_to_lower(cdo::inq_var_name(vlistID1, varID));
-              auto name2 = string_to_lower(cdo::inq_var_name(vlistID2, varID));
-              if (name1 != name2)
-                {
-                  cdo_warning("Input streams have different parameter names!");
-                  lchecknames = true;
-                  flag -= CMP_NAME;
-                  //    break;
-                }
-            }
-        }
-
-      if (flag & CMP_GRIDSIZE)
-        {
-          if (gridInqSize(vlistInqVarGrid(vlistID1, varID)) != gridInqSize(vlistInqVarGrid(vlistID2, varID)))
-            {
-              cdo_abort("Grid size of the input field '%s' do not match!", cdo::inq_var_name(vlistID1, varID));
-            }
-        }
-
-      if (flag & CMP_NLEVEL)
-        {
-          auto zaxisID1 = vlistInqVarZaxis(vlistID1, varID);
-          auto zaxisID2 = vlistInqVarZaxis(vlistID2, varID);
-          if (zaxisCheckLevels(zaxisID1, zaxisID2) != 0) break;
-        }
-    }
-
-  if (flag & CMP_GRID)
-    {
-      auto gridID1 = vlistInqVarGrid(vlistID1, 0);
-      auto gridID2 = vlistInqVarGrid(vlistID2, 0);
-      if (gridID1 != gridID2) cdo_compare_grids(gridID1, gridID2);
-    }
-
-  if (lchecknames) vlistCheckNames(vlistID1, vlistID2);
-}
-
 int
-vlist_compare_x(int vlistID1, int vlistID2, int flag)
+vlist_compare_x(int vlistID1, int vlistID2, CmpVlist cmpFlag)
 {
+  auto flag = static_cast<int>(cmpFlag);
   auto nvars = vlistNvars(vlistID1);
   auto nvars2 = vlistNvars(vlistID2);
   auto nlevels2 = zaxisInqSize(vlistInqVarZaxis(vlistID2, 0));
@@ -345,20 +232,20 @@ vlist_compare_x(int vlistID1, int vlistID2, int flag)
 
   for (int varID = 0; varID < nvars; ++varID)
     {
-      if (flag & CMP_GRIDSIZE)
+      if (flag & static_cast<int>(CmpVlist::GridSize))
         {
           if (gridInqSize(vlistInqVarGrid(vlistID1, varID)) != gridInqSize(vlistInqVarGrid(vlistID2, 0)))
             cdo_abort("Grid size of the input fields do not match!");
         }
 
-      if (flag & CMP_NLEVEL)
+      if (flag & static_cast<int>(CmpVlist::NumLevels))
         {
           if ((zaxisInqSize(vlistInqVarZaxis(vlistID1, varID)) != nlevels2) && nlevels2 > 1)
             cdo_abort("Number of levels of the input fields do not match!");
         }
     }
 
-  if (flag & CMP_GRID)
+  if (flag & static_cast<int>(CmpVlist::Grid))
     {
       auto gridID1 = vlistInqVarGrid(vlistID1, 0);
       auto gridID2 = vlistInqVarGrid(vlistID2, 0);
@@ -368,97 +255,6 @@ vlist_compare_x(int vlistID1, int vlistID2, int flag)
   return nlevels2;
 }
 
-void
-vlist_map(int vlistID1, int vlistID2, int flag, int mapflag, std::map<int, int> &mapOfVarIDs)
-{
-  auto nvars1 = vlistNvars(vlistID1);
-  auto nvars2 = vlistNvars(vlistID2);
-
-  std::vector<std::string> names1(nvars1);
-  std::vector<std::string> names2(nvars2);
-  for (int varID1 = 0; varID1 < nvars1; ++varID1) names1[varID1] = cdo::inq_var_name(vlistID1, varID1);
-  for (int varID2 = 0; varID2 < nvars2; ++varID2) names2[varID2] = cdo::inq_var_name(vlistID2, varID2);
-
-  if (mapflag == 2)
-    {
-      for (int varID2 = 0; varID2 < nvars2; ++varID2)
-        {
-          int varID1;
-          for (varID1 = 0; varID1 < nvars1; ++varID1)
-            {
-              if (names1[varID1] == names2[varID2]) break;
-            }
-          if (varID1 == nvars1) { cdo_abort("Variable %s not found in first input stream!", names2[varID2]); }
-          else { mapOfVarIDs[varID1] = varID2; }
-        }
-    }
-  else
-    {
-      for (int varID1 = 0; varID1 < nvars1; ++varID1)
-        {
-          int varID2;
-          for (varID2 = 0; varID2 < nvars2; ++varID2)
-            {
-              if (names1[varID1] == names2[varID2]) break;
-            }
-          if (varID2 == nvars2)
-            {
-              if (mapflag == 3) continue;
-              cdo_abort("Variable %s not found in second input stream!", names1[varID1]);
-            }
-          else { mapOfVarIDs[varID1] = varID2; }
-        }
-    }
-
-  if (mapOfVarIDs.empty()) cdo_abort("No variable found that occurs in both streams!");
-
-  if (Options::cdoVerbose)
-    for (int varID1 = 0; varID1 < nvars1; ++varID1)
-      {
-        const auto &it = mapOfVarIDs.find(varID1);
-        if (it != mapOfVarIDs.end())
-          cdo_print("Variable %d:%s mapped to %d:%s", varID1, names1[varID1], it->second, names2[it->second]);
-      }
-
-  if (mapOfVarIDs.size() > 1)
-    {
-      auto varID2 = mapOfVarIDs.begin()->second;
-      for (auto it = ++mapOfVarIDs.begin(); it != mapOfVarIDs.end(); ++it)
-        {
-          if (it->second < varID2)
-            cdo_abort("Variable names must be sorted, use CDO option --sortname to sort the parameter by name (NetCDF only)!");
-
-          varID2 = it->second;
-        }
-    }
-
-  for (auto it = mapOfVarIDs.begin(); it != mapOfVarIDs.end(); ++it)
-    {
-      auto varID1 = it->first;
-      auto varID2 = it->second;
-
-      if (flag & CMP_GRIDSIZE)
-        {
-          if (gridInqSize(vlistInqVarGrid(vlistID1, varID1)) != gridInqSize(vlistInqVarGrid(vlistID2, varID2)))
-            cdo_abort("Grid size of the input fields do not match!");
-        }
-
-      if (flag & CMP_NLEVEL)
-        {
-          auto zaxisID1 = vlistInqVarZaxis(vlistID1, varID1);
-          auto zaxisID2 = vlistInqVarZaxis(vlistID2, varID2);
-          if (zaxisCheckLevels(zaxisID1, zaxisID2) != 0) break;
-        }
-
-      if (flag & CMP_GRID && varID1 == mapOfVarIDs.begin()->first)
-        {
-          auto gridID1 = vlistInqVarGrid(vlistID1, varID1);
-          auto gridID2 = vlistInqVarGrid(vlistID2, varID2);
-          if (gridID1 != gridID2) cdo_compare_grids(gridID1, gridID2);
-        }
-    }
-}
-
 bool
 vlist_is_szipped(int vlistID)
 {
@@ -671,24 +467,6 @@ vlist_change_hybrid_zaxis(int vlistID1, int vlistID2, int zaxisID1, int zaxisID2
     }
 }
 
-int
-vlist_get_psvarid(int vlistID, int zaxisID)
-{
-  auto psname = cdo::inq_key_string(zaxisID, CDI_GLOBAL, CDI_KEY_PSNAME);
-  if (psname.size())
-    {
-      auto nvars = vlistNvars(vlistID);
-      for (int varID = 0; varID < nvars; ++varID)
-        {
-          auto name = cdo::inq_var_name(vlistID, varID);
-          if (name == psname) return varID;
-        }
-      if (Options::cdoVerbose) cdo_warning("Surface pressure variable not found - %s", psname);
-    }
-
-  return -1;
-}
-
 int
 vlist_get_first_spectral_grid(int vlistID)
 {
@@ -745,3 +523,22 @@ cdo_check_missval(double missval, const std::string &varname)
         }
     }
 }
+
+void
+vlist_unpack(int vlistID)
+{
+  auto numVars = vlistNvars(vlistID);
+  for (int varID = 0; varID < numVars; ++varID)
+    {
+      double addoffset = 0.0, scalefactor = 1.0;
+      auto haveAddoffset = (cdiInqKeyFloat(vlistID, varID, CDI_KEY_ADDOFFSET, &addoffset) == CDI_NOERR);
+      auto haveScalefactor = (cdiInqKeyFloat(vlistID, varID, CDI_KEY_SCALEFACTOR, &scalefactor) == CDI_NOERR);
+      if (haveAddoffset || haveScalefactor)
+        {
+          auto datatype = vlistInqVarDatatype(vlistID, varID);
+          if (datatype != CDI_DATATYPE_FLT64) vlistDefVarDatatype(vlistID, varID, CDI_DATATYPE_FLT32);
+          if (haveAddoffset) cdiDeleteKey(vlistID, varID, CDI_KEY_ADDOFFSET);
+          if (haveScalefactor) cdiDeleteKey(vlistID, varID, CDI_KEY_SCALEFACTOR);
+        }
+    }
+}
