@@ -241,8 +241,8 @@ dcw_get_region(const DCW_Lists &dcw_lists, const std::vector<std::string> &codeL
       auto ks = (code.size() > 2) ? dcw_find_state(code, dcw_lists.states) : dcw_find_country(code, dcw_lists.countries);
       if (ks == -1)
         {
-          printf("No country code matching <%s>, skipped!\n", code.c_str());
-          continue;
+          fprintf(stderr, "No country code matching <%s>!\n", code.c_str());
+          return 3;
         }
 
       // auto &country = dcw_lists.countries[ks];
@@ -386,8 +386,8 @@ dcw_get_lonlat(const DCW_Lists &dcw_lists, const std::vector<std::string> &codeL
       auto ks = (code.size() > 2) ? dcw_find_state(code, dcw_lists.states) : dcw_find_country(code, dcw_lists.countries);
       if (ks == -1)
         {
-          printf("No country code matching <%s>, skipped!\n", code.c_str());
-          continue;
+          fprintf(stderr, "No country code matching <%s>!\n", code.c_str());
+          return 3;
         }
 
       // auto &country = dcw_lists.countries[ks];
@@ -435,8 +435,8 @@ dcw_print_lonlat(const DCW_Lists &dcw_lists, const std::vector<std::string> &cod
       auto ks = (code.size() > 2) ? dcw_find_state(code, dcw_lists.states) : dcw_find_country(code, dcw_lists.countries);
       if (ks == -1)
         {
-          printf("No country code matching <%s>, skipped!\n", code.c_str());
-          continue;
+          printf("No country code matching <%s>!\n", code.c_str());
+          return 3;
         }
 
       auto &country = dcw_lists.countries[ks];
@@ -640,7 +640,7 @@ int main(void)
   codeList = dcw_expand_code_list(dcw_lists, codeList);
 
   Region region;
-  if (dcw_get_region(dcw_lists, codeList, region)) fprintf(stderr, "dcw_get_region failed!\n");
+  if (dcw_get_region(dcw_lists, codeList, region)) fprintf(stderr, "dcw_get_region() failed!\n");
 
   printf("#   West=%g  East=%g  South=%g  North=%g\n", region.west, region.east, region.south, region.north);
   printf("#\n");
