@@ -54,14 +54,12 @@ init_field(Field &field, int gridID, double missval, size_t gridsize, double val
 void
 eca1(const ECA_REQUEST_1 &request)
 {
-  auto operatorID = cdo_operator_id();
-
   CdiDateTime ovDateTime{};
   CdiDateTime inDateTime21{};
   int itsID;
   int otsID;
 
-  auto compareDate = cdo_operator_f2(operatorID);
+  auto compareDate = request.compare_type;
 
   auto istreamID = cdo_open_read(0);
 
@@ -91,7 +89,7 @@ eca1(const ECA_REQUEST_1 &request)
       if (IS_SET(request.var2.units)) cdiDefKeyString(ovlistID, varID, CDI_KEY_UNITS, request.var2.units);
     }
 
-  if (cdo_operator_f2(operatorID) == 16) vlistDefNtsteps(ovlistID, 1);
+  if (request.compare_type == 16) vlistDefNtsteps(ovlistID, 1);
 
   auto itaxisID = vlistInqTaxis(ivlistID);
   auto otaxisID = cdo_taxis_create(TAXIS_RELATIVE);
@@ -325,7 +323,7 @@ eca1(const ECA_REQUEST_1 &request)
         {
           int year, month, day;
           cdiDate_decode(inDateTime21.date, &year, &month, &day);
-          define_mid_of_time(cdo_operator_f2(operatorID), otaxisID, year, month, 12);
+          define_mid_of_time(request.compare_type, otaxisID, year, month, 12);
           cdo_def_timestep(ostreamID, otsID);
         }
 
@@ -367,15 +365,13 @@ eca1(const ECA_REQUEST_1 &request)
 void
 eca2(const ECA_REQUEST_2 &request)
 {
-  auto operatorID = cdo_operator_id();
-
   CdiDateTime ovDateTime{};
   CdiDateTime inDateTime21{};
   int varID;
   int itsID;
   int otsID;
 
-  auto compareDate = cdo_operator_f2(operatorID);
+  auto compareDate = request.compare_type;
 
   auto istreamID1 = cdo_open_read(0);
   auto istreamID2 = cdo_open_read(1);
@@ -410,7 +406,7 @@ eca2(const ECA_REQUEST_2 &request)
       if (IS_SET(request.var2.units)) cdiDefKeyString(ovlistID, varID, CDI_KEY_UNITS, request.var2.units);
     }
 
-  if (cdo_operator_f2(operatorID) == 16) vlistDefNtsteps(ovlistID, 1);
+  if (request.compare_type == 16) vlistDefNtsteps(ovlistID, 1);
 
   auto itaxisID1 = vlistInqTaxis(ivlistID1);
   auto otaxisID = cdo_taxis_create(TAXIS_RELATIVE);
@@ -673,7 +669,7 @@ eca2(const ECA_REQUEST_2 &request)
         {
           int year, month, day;
           cdiDate_decode(inDateTime21.date, &year, &month, &day);
-          define_mid_of_time(cdo_operator_f2(operatorID), otaxisID, year, month, 12);
+          define_mid_of_time(request.compare_type, otaxisID, year, month, 12);
           cdo_def_timestep(ostreamID, otsID);
         }
 
@@ -719,15 +715,13 @@ eca2(const ECA_REQUEST_2 &request)
 void
 eca3(const ECA_REQUEST_3 &request)
 {
-  auto operatorID = cdo_operator_id();
-
   CdiDateTime ovDateTime{};
   CdiDateTime inDateTime21{};
   int varID;
   int itsID;
   int otsID;
 
-  auto compareDate = cdo_operator_f2(operatorID);
+  auto compareDate = request.compare_type;
 
   auto istreamID1 = cdo_open_read(0);
   auto istreamID2 = cdo_open_read(1);
@@ -750,7 +744,7 @@ eca3(const ECA_REQUEST_3 &request)
   if (IS_SET(request.longname)) cdiDefKeyString(ovlistID, varID, CDI_KEY_LONGNAME, request.longname);
   if (IS_SET(request.units)) cdiDefKeyString(ovlistID, varID, CDI_KEY_UNITS, request.units);
 
-  if (cdo_operator_f2(operatorID) == 16) vlistDefNtsteps(ovlistID, 1);
+  if (request.compare_type == 16) vlistDefNtsteps(ovlistID, 1);
 
   auto itaxisID1 = vlistInqTaxis(ivlistID1);
   auto itaxisID2 = vlistInqTaxis(ivlistID2);
@@ -863,7 +857,7 @@ eca3(const ECA_REQUEST_3 &request)
         {
           int year, month, day;
           cdiDate_decode(inDateTime21.date, &year, &month, &day);
-          define_mid_of_time(cdo_operator_f2(operatorID), otaxisID, year, month, 12);
+          define_mid_of_time(request.compare_type, otaxisID, year, month, 12);
           cdo_def_timestep(ostreamID, otsID);
         }
 
@@ -900,8 +894,6 @@ fldhvs(const FieldVector &fieldVector, const size_t nlevels)
 void
 eca4(const ECA_REQUEST_4 &request)
 {
-  auto operatorID = cdo_operator_id();
-
   int yearcnt = 0;
   int varID;
   bool resetAtJan = false, resetAtJul = false;
@@ -910,7 +902,7 @@ eca4(const ECA_REQUEST_4 &request)
   CdiDateTime inDateTime21{};
   int64_t ivdate = 0, ovdate = 0;
 
-  auto compareDate = cdo_operator_f2(operatorID);
+  auto compareDate = request.compare_type;
 
   auto istreamID1 = cdo_open_read(0);
   auto istreamID2 = cdo_open_read(1);
@@ -942,7 +934,7 @@ eca4(const ECA_REQUEST_4 &request)
   if (IS_SET(request.longname2)) cdiDefKeyString(ovlistID, ovarID2, CDI_KEY_LONGNAME, request.longname2);
   if (IS_SET(request.units2)) cdiDefKeyString(ovlistID, ovarID2, CDI_KEY_UNITS, request.units2);
 
-  if (cdo_operator_f2(operatorID) == 16) vlistDefNtsteps(ovlistID, 1);
+  if (request.compare_type == 16) vlistDefNtsteps(ovlistID, 1);
 
   auto itaxisID = vlistInqTaxis(ivlistID1);
   auto otaxisID = cdo_taxis_create(TAXIS_RELATIVE);
