@@ -865,7 +865,7 @@ ex_fun_var(int init, int funcID, nodeType *p1)
 }
 
 static nodeType *
-func_con_con(int init, int funcID, const nodeType *p1, const nodeType *p2)
+func_con_con(int funcID, nodeType *p1, nodeType *p2)
 {
   auto &funcEntry = funcSymbolTable[funcID];
   auto functype = funcEntry.type;
@@ -876,14 +876,11 @@ func_con_con(int init, int funcID, const nodeType *p1, const nodeType *p2)
   p->type = NodeEnum::typeCon;
   p->isTmpObj = true;
 
-  if (!init)
-    {
-      auto cval1 = p1->con().value;
-      auto cval2 = p2->con().value;
+  auto exprfunc = (double (*)(double, double)) funcEntry.func;
+  p->v = conNodeType(exprfunc(p1->con().value, p2->con().value));
 
-      auto exprfunc = (double (*)(double, double)) funcEntry.func;
-      p->v = conNodeType(exprfunc(cval1, cval2));
-    }
+  if (p1->isTmpObj) node_delete(p1);
+  if (p2->isTmpObj) node_delete(p2);
 
   return p;
 }
@@ -1124,7 +1121,7 @@ ex_fun2(int init, int funcID, nodeType *p1, nodeType *p2)
   else if (p1->type == NodeEnum::typeCon && p2->type == NodeEnum::typeCon)
     {
       if (Options::cdoVerbose) cdo_print("\t%s\tfunc\t%s (%g, %g)", ExIn[init], funcEntry.name, p1->con().value, p2->con().value);
-      return func_con_con(init, funcID, p1, p2);
+      return func_con_con(funcID, p1, p2);
     }
   else
     cdo_abort("Internal problem!");
