@@ -70,10 +70,9 @@
 #line 5 "expr_yacc.y"
 
 // clang-format off
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <stdarg.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
 
 #include "expr.h"
 #include "expr_yacc.hh" // expr_yacc.h (y.tab.h) is produced from expr_yacc.y by parser generator
@@ -93,7 +92,7 @@ nodeType *expr_opr(int oper, int nops, ...);
 
 void free_node(nodeType *p);
 
-#line 97 "expr_yacc.cc"
+#line 96 "expr_yacc.cc"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -548,10 +547,10 @@ static const yytype_int8 yytranslate[] =
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int8 yyrline[] =
 {
-       0,    58,    58,    62,    63,    67,    68,    69,    70,    71,
-      72,    73,    74,    78,    79,    83,    84,    85,    86,    87,
-      88,    89,    90,    91,    92,    93,    94,    95,    96,    97,
-      98,    99,   100,   101,   102,   103,   104,   105,   106,   109
+       0,    57,    57,    61,    62,    66,    67,    68,    69,    70,
+      71,    72,    73,    77,    78,    82,    83,    84,    85,    86,
+      87,    88,    89,    90,    91,    92,    93,    94,    95,    96,
+      97,    98,    99,   100,   101,   102,   103,   104,   105,   108
 };
 #endif
 
@@ -1471,229 +1470,229 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* program: function  */
-#line 58 "expr_yacc.y"
+#line 57 "expr_yacc.y"
                                   { return 0; }
-#line 1477 "expr_yacc.cc"
+#line 1476 "expr_yacc.cc"
     break;
 
   case 3: /* function: function stmt  */
-#line 62 "expr_yacc.y"
+#line 61 "expr_yacc.y"
                                   { expr_run((yyvsp[0].nPtr), parseArg); free_node((yyvsp[0].nPtr)); }
-#line 1483 "expr_yacc.cc"
+#line 1482 "expr_yacc.cc"
     break;
 
   case 5: /* stmt: ';'  */
-#line 67 "expr_yacc.y"
+#line 66 "expr_yacc.y"
                                    { (yyval.nPtr) = expr_opr(';', 2, NULL, NULL); }
-#line 1489 "expr_yacc.cc"
+#line 1488 "expr_yacc.cc"
     break;
 
   case 6: /* stmt: expr ';'  */
-#line 68 "expr_yacc.y"
+#line 67 "expr_yacc.y"
                                    { (yyval.nPtr) = (yyvsp[-1].nPtr); }
-#line 1495 "expr_yacc.cc"
+#line 1494 "expr_yacc.cc"
     break;
 
   case 7: /* stmt: VARIABLE '=' expr ';'  */
-#line 69 "expr_yacc.y"
+#line 68 "expr_yacc.y"
                                    { (yyval.nPtr) = expr_opr('=', 2, expr_var((yyvsp[-3].varnm)), (yyvsp[-1].nPtr)); }
-#line 1501 "expr_yacc.cc"
+#line 1500 "expr_yacc.cc"
     break;
 
   case 8: /* stmt: VARIABLE '=' ternary ';'  */
-#line 70 "expr_yacc.y"
+#line 69 "expr_yacc.y"
                                    { (yyval.nPtr) = expr_opr('=', 2, expr_var((yyvsp[-3].varnm)), (yyvsp[-1].nPtr)); }
-#line 1507 "expr_yacc.cc"
+#line 1506 "expr_yacc.cc"
     break;
 
   case 9: /* stmt: VARIABLE ';'  */
-#line 71 "expr_yacc.y"
+#line 70 "expr_yacc.y"
                                    { (yyval.nPtr) = expr_opr('=', 2, expr_var((yyvsp[-1].varnm)), expr_var((yyvsp[-1].varnm))); }
-#line 1513 "expr_yacc.cc"
+#line 1512 "expr_yacc.cc"
     break;
 
   case 10: /* stmt: REMOVE VARIABLE ')' ';'  */
-#line 72 "expr_yacc.y"
+#line 71 "expr_yacc.y"
                                    { (yyval.nPtr) = expr_cmd("remove", (yyvsp[-2].varnm)); }
-#line 1519 "expr_yacc.cc"
+#line 1518 "expr_yacc.cc"
     break;
 
   case 11: /* stmt: PRINT VARIABLE ')' ';'  */
-#line 73 "expr_yacc.y"
+#line 72 "expr_yacc.y"
                                    { (yyval.nPtr) = expr_cmd("print", (yyvsp[-2].varnm)); }
-#line 1525 "expr_yacc.cc"
+#line 1524 "expr_yacc.cc"
     break;
 
   case 12: /* stmt: '{' stmt_list '}'  */
-#line 74 "expr_yacc.y"
+#line 73 "expr_yacc.y"
                                    { (yyval.nPtr) = (yyvsp[-1].nPtr); }
-#line 1531 "expr_yacc.cc"
+#line 1530 "expr_yacc.cc"
     break;
 
   case 13: /* stmt_list: stmt  */
-#line 78 "expr_yacc.y"
+#line 77 "expr_yacc.y"
                                   { (yyval.nPtr) = (yyvsp[0].nPtr); }
-#line 1537 "expr_yacc.cc"
+#line 1536 "expr_yacc.cc"
     break;
 
   case 14: /* stmt_list: stmt_list stmt  */
-#line 79 "expr_yacc.y"
+#line 78 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr(';', 2, (yyvsp[-1].nPtr), (yyvsp[0].nPtr)); }
-#line 1543 "expr_yacc.cc"
+#line 1542 "expr_yacc.cc"
     break;
 
   case 15: /* expr: CONSTANT  */
-#line 83 "expr_yacc.y"
+#line 82 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_con((yyvsp[0].cvalue)); }
-#line 1549 "expr_yacc.cc"
+#line 1548 "expr_yacc.cc"
     break;
 
   case 16: /* expr: VARIABLE  */
-#line 84 "expr_yacc.y"
+#line 83 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_var((yyvsp[0].varnm)); }
-#line 1555 "expr_yacc.cc"
+#line 1554 "expr_yacc.cc"
     break;
 
   case 17: /* expr: '-' expr  */
-#line 85 "expr_yacc.y"
+#line 84 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr(UMINUS,  1, (yyvsp[0].nPtr)); }
-#line 1561 "expr_yacc.cc"
+#line 1560 "expr_yacc.cc"
     break;
 
   case 18: /* expr: NOT expr  */
-#line 86 "expr_yacc.y"
+#line 85 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr(NOT,     1, (yyvsp[0].nPtr)); }
-#line 1567 "expr_yacc.cc"
+#line 1566 "expr_yacc.cc"
     break;
 
   case 19: /* expr: expr '+' expr  */
-#line 87 "expr_yacc.y"
+#line 86 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr('+', 2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1573 "expr_yacc.cc"
+#line 1572 "expr_yacc.cc"
     break;
 
   case 20: /* expr: expr '-' expr  */
-#line 88 "expr_yacc.y"
+#line 87 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr('-', 2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1579 "expr_yacc.cc"
+#line 1578 "expr_yacc.cc"
     break;
 
   case 21: /* expr: expr '*' expr  */
-#line 89 "expr_yacc.y"
+#line 88 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr('*', 2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1585 "expr_yacc.cc"
+#line 1584 "expr_yacc.cc"
     break;
 
   case 22: /* expr: expr '/' expr  */
-#line 90 "expr_yacc.y"
+#line 89 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr('/', 2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1591 "expr_yacc.cc"
+#line 1590 "expr_yacc.cc"
     break;
 
   case 23: /* expr: expr LT expr  */
-#line 91 "expr_yacc.y"
+#line 90 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr(LT,  2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1597 "expr_yacc.cc"
+#line 1596 "expr_yacc.cc"
     break;
 
   case 24: /* expr: expr GT expr  */
-#line 92 "expr_yacc.y"
+#line 91 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr(GT,  2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1603 "expr_yacc.cc"
+#line 1602 "expr_yacc.cc"
     break;
 
   case 25: /* expr: expr '^' expr  */
-#line 93 "expr_yacc.y"
+#line 92 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr('^', 2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1609 "expr_yacc.cc"
+#line 1608 "expr_yacc.cc"
     break;
 
   case 26: /* expr: expr GE expr  */
-#line 94 "expr_yacc.y"
+#line 93 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr(GE,  2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1615 "expr_yacc.cc"
+#line 1614 "expr_yacc.cc"
     break;
 
   case 27: /* expr: expr LE expr  */
-#line 95 "expr_yacc.y"
+#line 94 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr(LE,  2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1621 "expr_yacc.cc"
+#line 1620 "expr_yacc.cc"
     break;
 
   case 28: /* expr: expr NE expr  */
-#line 96 "expr_yacc.y"
+#line 95 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr(NE,  2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1627 "expr_yacc.cc"
+#line 1626 "expr_yacc.cc"
     break;
 
   case 29: /* expr: expr EQ expr  */
-#line 97 "expr_yacc.y"
+#line 96 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr(EQ,  2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1633 "expr_yacc.cc"
+#line 1632 "expr_yacc.cc"
     break;
 
   case 30: /* expr: expr LEG expr  */
-#line 98 "expr_yacc.y"
+#line 97 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr(LEG, 2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1639 "expr_yacc.cc"
+#line 1638 "expr_yacc.cc"
     break;
 
   case 31: /* expr: expr AND expr  */
-#line 99 "expr_yacc.y"
+#line 98 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr(AND, 2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1645 "expr_yacc.cc"
+#line 1644 "expr_yacc.cc"
     break;
 
   case 32: /* expr: expr OR expr  */
-#line 100 "expr_yacc.y"
+#line 99 "expr_yacc.y"
                                   { (yyval.nPtr) = expr_opr(OR,  2, (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1651 "expr_yacc.cc"
+#line 1650 "expr_yacc.cc"
     break;
 
   case 33: /* expr: '(' expr ')'  */
-#line 101 "expr_yacc.y"
+#line 100 "expr_yacc.y"
                                   { (yyval.nPtr) = (yyvsp[-1].nPtr); }
-#line 1657 "expr_yacc.cc"
+#line 1656 "expr_yacc.cc"
     break;
 
   case 34: /* expr: '(' ternary ')'  */
-#line 102 "expr_yacc.y"
+#line 101 "expr_yacc.y"
                                   { (yyval.nPtr) = (yyvsp[-1].nPtr); }
-#line 1663 "expr_yacc.cc"
+#line 1662 "expr_yacc.cc"
     break;
 
   case 35: /* expr: FUNCTION '(' expr ',' expr ',' expr ')'  */
-#line 103 "expr_yacc.y"
+#line 102 "expr_yacc.y"
                                                     { (yyval.nPtr) = expr_fun((yyvsp[-7].fname), 3, (yyvsp[-5].nPtr), (yyvsp[-3].nPtr), (yyvsp[-1].nPtr)); }
-#line 1669 "expr_yacc.cc"
+#line 1668 "expr_yacc.cc"
     break;
 
   case 36: /* expr: FUNCTION '(' expr ',' expr ')'  */
-#line 104 "expr_yacc.y"
+#line 103 "expr_yacc.y"
                                                     { (yyval.nPtr) = expr_fun((yyvsp[-5].fname), 2, (yyvsp[-3].nPtr), (yyvsp[-1].nPtr)); }
-#line 1675 "expr_yacc.cc"
+#line 1674 "expr_yacc.cc"
     break;
 
   case 37: /* expr: FUNCTION '(' expr ')'  */
-#line 105 "expr_yacc.y"
+#line 104 "expr_yacc.y"
                                                     { (yyval.nPtr) = expr_fun((yyvsp[-3].fname), 1, (yyvsp[-1].nPtr)); }
-#line 1681 "expr_yacc.cc"
+#line 1680 "expr_yacc.cc"
     break;
 
   case 38: /* expr: FUNCTION '(' ')'  */
-#line 106 "expr_yacc.y"
+#line 105 "expr_yacc.y"
                                                     { (yyval.nPtr) = expr_fun((yyvsp[-2].fname), 1, NULL); }
-#line 1687 "expr_yacc.cc"
+#line 1686 "expr_yacc.cc"
     break;
 
   case 39: /* ternary: expr QUESTION expr COLON expr  */
-#line 109 "expr_yacc.y"
+#line 108 "expr_yacc.y"
                                           { (yyval.nPtr) = expr_opr('?', 3, (yyvsp[-4].nPtr), (yyvsp[-2].nPtr), (yyvsp[0].nPtr)); }
-#line 1693 "expr_yacc.cc"
+#line 1692 "expr_yacc.cc"
     break;
 
 
-#line 1697 "expr_yacc.cc"
+#line 1696 "expr_yacc.cc"
 
       default: break;
     }
@@ -1917,93 +1916,72 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 112 "expr_yacc.y"
+#line 111 "expr_yacc.y"
 
 
-#define SIZEOF_NODETYPE ((char *)&p->u.con - (char *)p)
-
 nodeType *expr_con(double value)
 {
-  nodeType *p = NULL;
-  // allocate node
-  size_t nodeSize = SIZEOF_NODETYPE + sizeof(conNodeType);
-  p = (nodeType*) calloc(1, nodeSize);
-  if (p == NULL) yyerror(ParseParamType{}, NULL, "Out of memory");
+  auto p = new nodeType;
+  if (p == nullptr) yyerror(ParseParamType{}, nullptr, "Out of memory");
 
-  // copy information
   p->type = NodeEnum::typeCon;
-  p->u.con.value = value;
-    
+  p->v = conNodeType(value);
+   
   return p;
 }
 
 nodeType *expr_var(char *name)
 {
-  nodeType *p = NULL;
-  // allocate node
-  size_t nodeSize = SIZEOF_NODETYPE + sizeof(varNodeType);
-  p = (nodeType*) calloc(1, nodeSize);
-  if (p == NULL) yyerror(ParseParamType{}, NULL, "Out of memory");
+  auto p = new nodeType;
+  if (p == nullptr) yyerror(ParseParamType{}, nullptr, "Out of memory");
 
-  // copy information
   p->type = NodeEnum::typeVar;
-  p->u.var.name = strdup(name);
+  p->v = varNodeType(name);
+
+  free(name);
 
   return p;
 }
 
 nodeType *expr_cmd(const char *cmdName, char *varName)
 {
-  nodeType *p = NULL;
-  // allocate node
-  size_t nodeSize = SIZEOF_NODETYPE + sizeof(cmdNodeType);
-  p = (nodeType*) calloc(1, nodeSize);
-  if (p == NULL) yyerror(ParseParamType{}, NULL, "Out of memory");
+  auto p = new nodeType;
+  if (p == nullptr) yyerror(ParseParamType{}, nullptr, "Out of memory");
 
-  // copy information
   p->type = NodeEnum::typeCmd;
-  p->u.cmd.cmdName = strdup(cmdName);
-  p->u.cmd.varName = strdup(varName);
+  p->v = cmdNodeType(cmdName, varName);
 
   return p;
 }
 
 nodeType *expr_fun(char *fname, int nops, ...)
 {
-  nodeType *p = NULL;
-  // allocate node
-  size_t nodeSize = SIZEOF_NODETYPE + sizeof(funNodeType) + (nops - 1)*sizeof(nodeType*);
-  p = (nodeType*) calloc(1, nodeSize);
-  if (p == NULL) yyerror(ParseParamType{}, NULL, "Out of memory");
+  auto p = new nodeType;
+  if (p == nullptr) yyerror(ParseParamType{}, nullptr, "Out of memory");
 
-  // copy information
   p->type = NodeEnum::typeFun;
-  p->u.fun.name = strdup(fname);
-  p->u.fun.nops = nops;
-  va_list ap;
-  va_start(ap, nops);
-  for (int i = 0; i < nops; i++) p->u.fun.op[i] = va_arg(ap, nodeType*);
-  va_end(ap);
+
+  va_list args;
+  va_start(args, nops);
+  p->v = funNodeType(fname, nops, args);
+  va_end(args);
+
+  if (fname) free(fname);
 
   return p;
 }
 
 nodeType *expr_opr(int oper, int nops, ...)
 {
-  nodeType *p = NULL;
-  // allocate node
-  size_t nodeSize = SIZEOF_NODETYPE + sizeof(oprNodeType) + (nops - 1)*sizeof(nodeType*);
-  p = (nodeType*) calloc(1, nodeSize);
-  if (p == NULL) yyerror(ParseParamType{}, NULL, "Out of memory");
+  auto p = new nodeType;
+  if (p == nullptr) yyerror(ParseParamType{}, nullptr, "Out of memory");
 
-  // copy information
   p->type = NodeEnum::typeOpr;
-  p->u.opr.oper = oper;
-  p->u.opr.nops = nops;
-  va_list ap;
-  va_start(ap, nops);
-  for (int i = 0; i < nops; i++) p->u.opr.op[i] = va_arg(ap, nodeType*);
-  va_end(ap);
+
+  va_list args;
+  va_start(args, nops);
+  p->v = oprNodeType(oper, nops, args);
+  va_end(args);
 
   return p;
 }
@@ -2014,14 +1992,14 @@ void free_node(nodeType *p)
 
   if (p->type == NodeEnum::typeFun)
     {
-      for (int i = 0; i < p->u.fun.nops; i++) free_node(p->u.fun.op[i]);
+      for (int i = 0; i < p->fun().nops; i++) free_node(p->fun().op[i]);
     }
   else if (p->type == NodeEnum::typeOpr)
     {
-      for (int i = 0; i < p->u.opr.nops; i++) free_node(p->u.opr.op[i]);
+      for (int i = 0; i < p->opr().nops; i++) free_node(p->opr().op[i]);
     }
   
-  free(p);
+  delete p;
 }
 
 int CDO_parser_errorno = 0;
@@ -2031,7 +2009,8 @@ void yyerror(const ParseParamType &parseArg, void *scanner, const char *errstr)
   fprintf(stderr, "%s!\n", errstr);
   CDO_parser_errorno = -1;
 }
-/*
+
+#ifdef TEST_EXPR
 int main(void)
 {
   static char fexpr[] = "nvar = q*(geosp+234.56); xx = geosp+999-log(aps);";
@@ -2054,7 +2033,7 @@ int main(void)
   yyparse(parseArg, scanner);
 
   for (int i = 0; i < parseArg.nvars1; i++)
-    printf("vars %d %s\n", i, parseArg.var[i]);
+    printf("var %d %s\n", i, parseArg.params[i].name);
 
   yy_scan_string(fexpr, scanner);
 
@@ -2063,10 +2042,10 @@ int main(void)
   yyparse(parseArg, scanner);
 
   for (int i = 0; i < parseArg.nvars1; i++)
-    printf("vars %d %s\n", i, parseArg.var[i]);
+    printf("var %d %s\n", i, parseArg.params[i].name);
 
   return 0;
 }
-*/
+#endif
 
 // clang-format on
