@@ -388,7 +388,7 @@ var_to_std(double rvar, double missval)
 {
   if (dbl_is_equal(rvar, missval) || rvar < 0) return missval;
 
-  return IS_NOT_EQUAL(rvar, 0) ? std::sqrt(rvar) : 0;
+  return is_not_equal(rvar, 0) ? std::sqrt(rvar) : 0;
 }
 
 double
