@@ -68,7 +68,8 @@ zonal_kernel_1(const Field &field1, Field &field2, funcTypeNmissMV funcNmissMV)
       size_t offset = isReducedGrid ? cumreducedPoints[j] : j * nx;
       copy_latitude_row(offset, nx, field1, v);
 
-      auto result = funcNmissMV(nx, v, nmiss, missval);
+      auto numMissval = nx - varray_count(nx, v, nmiss, missval);
+      auto result = funcNmissMV(nx, v, numMissval, missval);
       if (dbl_is_equal(result, missval)) rnmiss++;
       field2.vec_d[j] = result;
     }
