@@ -9,6 +9,7 @@
 #include <vector>
 
 #include <cdi.h>
+#include "cdo_cdi_wrapper.h"
 #include <mpim_grid.h>
 #include "gridreference.h"
 #include "cdo_output.h"
@@ -20,7 +21,7 @@
 static void
 lonlat_to_xyz(double lon, double lat, double *xyz)
 {
-  const auto coslat = std::cos(lat);
+  auto coslat = std::cos(lat);
   xyz[0] = coslat * std::cos(lon);
   xyz[1] = coslat * std::sin(lon);
   xyz[2] = std::sin(lat);
@@ -255,8 +256,8 @@ mod_huiliers_area2(int num_corners, double *cell_corner_lon, double *cell_corner
 static void
 getLonLatCorner(size_t nx, size_t idx, const double *grid_corner_lon, const double *grid_corner_lat, double *lons, double *lats)
 {
-  const auto j = idx / nx;
-  const auto i = idx - j * nx;
+  auto j = idx / nx;
+  auto i = idx - j * nx;
 
   lons[0] = grid_corner_lon[2 * i];
   lons[1] = grid_corner_lon[2 * i + 1];
@@ -280,12 +281,12 @@ getLonLatCorner(size_t nx, size_t idx, const double *grid_corner_lon, const doub
 }
 
 static int
-gridGenAreaReg2D(const int gridID, double *area, bool lweights)
+gen_gridcellarea_reg2d(int gridID, double *area, bool lweights)
 {
   // lweights = true : area used only to calculate weights
 
   int status = 0;
-  char unitstr[CDI_MAX_NAME];
+  std::string unitstr;
   auto gridsize = gridInqSize(gridID);
   auto nlon = gridInqXsize(gridID);
   auto nlat = gridInqYsize(gridID);
@@ -303,8 +304,7 @@ gridGenAreaReg2D(const int gridID, double *area, bool lweights)
   if (gridInqXbounds(gridID, nullptr))
     {
       gridInqXbounds(gridID, grid_corner_lon.data());
-      int length = CDI_MAX_NAME;
-      cdiInqKeyString(gridID, CDI_XAXIS, CDI_KEY_UNITS, unitstr, &length);
+      unitstr = cdo::inq_key_string(gridID, CDI_XAXIS, CDI_KEY_UNITS);
     }
   else if (nlon == 1)
     {
@@ -312,24 +312,23 @@ gridGenAreaReg2D(const int gridID, double *area, bool lweights)
         {
           grid_corner_lon[0] = 0;
           grid_corner_lon[1] = .01;
-          strcpy(unitstr, "radian");
+          unitstr = "radian";
         }
-      else return 1;
+      else
+        return 1;
     }
   else
     {
       std::vector<double> grid_center_lon(nlon);
       gridInqXvals(gridID, grid_center_lon.data());
       grid_gen_bounds(nlon, grid_center_lon, grid_corner_lon);
-      int length = CDI_MAX_NAME;
-      cdiInqKeyString(gridID, CDI_XAXIS, CDI_KEY_UNITS, unitstr, &length);
+      unitstr = cdo::inq_key_string(gridID, CDI_XAXIS, CDI_KEY_UNITS);
     }
 
   if (gridInqYbounds(gridID, nullptr))
     {
       gridInqYbounds(gridID, grid_corner_lat.data());
-      int length = CDI_MAX_NAME;
-      cdiInqKeyString(gridID, CDI_YAXIS, CDI_KEY_UNITS, unitstr, &length);
+      unitstr = cdo::inq_key_string(gridID, CDI_YAXIS, CDI_KEY_UNITS);
     }
   else if (nlat == 1)
     {
@@ -337,9 +336,10 @@ gridGenAreaReg2D(const int gridID, double *area, bool lweights)
         {
           grid_corner_lat[0] = 0;
           grid_corner_lat[1] = .01;
-          strcpy(unitstr, "radian");
+          unitstr = "radian";
         }
-      else return 1;
+      else
+        return 1;
     }
   else
     {
@@ -347,15 +347,14 @@ gridGenAreaReg2D(const int gridID, double *area, bool lweights)
       gridInqYvals(gridID, grid_center_lat.data());
       grid_gen_bounds(nlat, grid_center_lat, grid_corner_lat);
       grid_check_lat_borders(nlat * 2, grid_corner_lat.data());
-      int length = CDI_MAX_NAME;
-      cdiInqKeyString(gridID, CDI_YAXIS, CDI_KEY_UNITS, unitstr, &length);
+      unitstr = cdo::inq_key_string(gridID, CDI_YAXIS, CDI_KEY_UNITS);
     }
 
-  grid_to_radian(unitstr, nlon * 2, grid_corner_lon.data(), "grid cell corner longitudes");
-  grid_to_radian(unitstr, nlat * 2, grid_corner_lat.data(), "grid cell corner latitudes");
+  if (string_to_LonLatUnits(unitstr, "grid cell corner longitudes") == LonLatUnits::Deg) grid_to_radian(grid_corner_lon);
+  if (string_to_LonLatUnits(unitstr, "grid cell corner latitudes") == LonLatUnits::Deg) grid_to_radian(grid_corner_lat);
 
   constexpr int nv = 4;
-  std::atomic<size_t> atomicCount{0};
+  std::atomic<size_t> atomicCount{ 0 };
 
   progress::init();
 
@@ -365,7 +364,7 @@ gridGenAreaReg2D(const int gridID, double *area, bool lweights)
   for (size_t i = 0; i < gridsize; ++i)
     {
       atomicCount++;
-      if (cdo_omp_get_thread_num() == 0) progress::update(0, 1, (double)atomicCount / gridsize);
+      if (cdo_omp_get_thread_num() == 0) progress::update(0, 1, (double) atomicCount / gridsize);
 
       double lons[4], lats[4];
       getLonLatCorner(nlon, i, grid_corner_lon.data(), grid_corner_lat.data(), lons, lats);
@@ -378,17 +377,17 @@ gridGenAreaReg2D(const int gridID, double *area, bool lweights)
 }
 
 int
-gridGenAreaReg2Dweights(const int gridID, double *area)
+gridGenAreaReg2Dweights(int gridID, double *area)
 {
   bool lweights = true;
-  return gridGenAreaReg2D(gridID, area, lweights);
+  return gen_gridcellarea_reg2d(gridID, area, lweights);
 }
 
 static int
-gridGenAreaUnstruct(int gridID, double *area)
+gen_gridcellarea_unstruct(int gridID, double *area)
 {
   int status = 0;
-  bool lgriddestroy = false;
+  auto lgriddestroy = false;
 
   auto gridsize = gridInqSize(gridID);
   auto gridtype = gridInqType(gridID);
@@ -398,18 +397,18 @@ gridGenAreaUnstruct(int gridID, double *area)
       if (gridtype == GRID_GME || gridtype == GRID_GAUSSIAN_REDUCED)
         {
           lgriddestroy = true;
-          gridID = gridToUnstructured(gridID, 1);
+          gridID = gridToUnstructured(gridID, NeedCorners::Yes);
         }
       else
         {
           lgriddestroy = true;
-          gridID = gridToCurvilinear(gridID, 1);
+          gridID = gridToCurvilinear(gridID, NeedCorners::Yes);
         }
     }
 
   if (gridtype == GRID_UNSTRUCTURED && !gridHasCoordinates(gridID))
     {
-      const auto reference = dereferenceGrid(gridID);
+      auto reference = dereferenceGrid(gridID);
       if (reference.exists)
         {
           if (!reference.isValid)
@@ -449,15 +448,15 @@ gridGenAreaUnstruct(int gridID, double *area)
   gridInqXbounds(gridID, grid_corner_lon.data());
   gridInqYbounds(gridID, grid_corner_lat.data());
 
-  cdo_grid_to_radian(gridID, CDI_XAXIS, gridsize, grid_center_lon.data(), "grid1 center longitudes");
-  cdo_grid_to_radian(gridID, CDI_XAXIS, gridsize * nv, grid_corner_lon.data(), "grid1 corner longitudes");
+  cdo_grid_to_radian(gridID, CDI_XAXIS, grid_center_lon, "grid1 center longitudes");
+  cdo_grid_to_radian(gridID, CDI_XAXIS, grid_corner_lon, "grid1 corner longitudes");
 
-  cdo_grid_to_radian(gridID, CDI_YAXIS, gridsize, grid_center_lat.data(), "grid1 center latitudes");
-  cdo_grid_to_radian(gridID, CDI_YAXIS, gridsize * nv, grid_corner_lat.data(), "grid1 corner latitudes");
+  cdo_grid_to_radian(gridID, CDI_YAXIS, grid_center_lat, "grid1 center latitudes");
+  cdo_grid_to_radian(gridID, CDI_YAXIS, grid_corner_lat, "grid1 corner latitudes");
 
   if (lgriddestroy) gridDestroy(gridID);
 
-  std::atomic<size_t> atomicCount{0};
+  std::atomic<size_t> atomicCount{ 0 };
 
   progress::init();
 
@@ -467,7 +466,7 @@ gridGenAreaUnstruct(int gridID, double *area)
   for (size_t i = 0; i < gridsize; ++i)
     {
       atomicCount++;
-      if (cdo_omp_get_thread_num() == 0) progress::update(0, 1, (double)atomicCount / gridsize);
+      if (cdo_omp_get_thread_num() == 0) progress::update(0, 1, (double) atomicCount / gridsize);
 
       if (nv <= 4)
         area[i] = mod_huiliers_area(nv, &grid_corner_lon[i * nv], &grid_corner_lat[i * nv]);
@@ -482,22 +481,35 @@ gridGenAreaUnstruct(int gridID, double *area)
 }
 
 int
-gridGenArea(const int gridID, double *area)
+gen_gridcellarea_healpix(int gridID, double *area)
+{
+  auto gridsize = gridInqSize(gridID);
+  auto cellarea = 4.0 * M_PI / gridsize;
+  for (size_t i = 0; i < gridsize; ++i) { area[i] = cellarea; }
+  return 0;
+}
+
+int
+gridGenArea(int gridID, double *area)
 {
   int status = 0;
 
-  const auto gridsize = gridInqSize(gridID);
-  const auto gridtype = gridInqType(gridID);
+  auto gridsize = gridInqSize(gridID);
+  auto gridtype = gridInqType(gridID);
 
   if (gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN)
     {
       bool lweights = false;
-      status = gridGenAreaReg2D(gridID, area, lweights);
+      status = gen_gridcellarea_reg2d(gridID, area, lweights);
     }
-  else if (gridProjIsSupported(gridID) || gridtype == GRID_GME || gridtype == GRID_CURVILINEAR
-           || gridtype == GRID_UNSTRUCTURED|| gridtype == GRID_GAUSSIAN_REDUCED)
+  else if (is_healpix_grid(gridID))
     {
-      status = gridGenAreaUnstruct(gridID, area);
+      status = gen_gridcellarea_healpix(gridID, area);
+    }
+  else if (gridProjIsSupported(gridID) || gridtype == GRID_GME || gridtype == GRID_CURVILINEAR || gridtype == GRID_UNSTRUCTURED
+           || gridtype == GRID_GAUSSIAN_REDUCED)
+    {
+      status = gen_gridcellarea_unstruct(gridID, area);
     }
   else
     {
