@@ -227,7 +227,7 @@ generate_grid_dcw(GridDesciption &grid, const std::string &gridname, double inc)
   codeList = dcw_expand_code_list(dcw_lists, codeList);
 
   Region region;
-  if (dcw_get_region(dcw_lists, codeList, region)) cdo_abort("dcw_get_region failed!");
+  if (dcw_get_region(dcw_lists, codeList, region)) cdo_abort("dcw_get_region() failed!");
 
   // printf("lon1, lon2, lat1, lat2 %g %g %g %g\n", region.west, region.east, region.south, region.north);
   auto lon1 = std::round(region.west / inc - 0.5) * inc;
