@@ -223,7 +223,7 @@ intlinarr2(T missval, int lonIsCircular, size_t nxm, size_t nym, const Varray<T>
 #endif
   for (size_t i = 0; i < gridsize2; ++i)
     {
-      size_t src_add[4];  // address for the four source points
+      size_t srcIndices[4];  // address for the four source points
 
       varray2[i] = missval;
 
@@ -237,14 +237,14 @@ intlinarr2(T missval, int lonIsCircular, size_t nxm, size_t nym, const Varray<T>
         {
           size_t iix = ii;
           if (lonIsCircular && iix == (nxm - 1)) iix = 0;
-          src_add[0] = (jj - 1) * nlon1 + (ii - 1);
-          src_add[1] = (jj - 1) * nlon1 + (iix);
-          src_add[2] = (jj) *nlon1 + (ii - 1);
-          src_add[3] = (jj) *nlon1 + (iix);
+          srcIndices[0] = (jj - 1) * nlon1 + (ii - 1);
+          srcIndices[1] = (jj - 1) * nlon1 + (iix);
+          srcIndices[2] = (jj) *nlon1 + (ii - 1);
+          srcIndices[3] = (jj) *nlon1 + (iix);
 
           // Check to see if points are missing values
           for (int n = 0; n < 4; ++n)
-            if (!grid1_mask[src_add[n]]) lfound = 0;
+            if (!grid1_mask[srcIndices[n]]) lfound = 0;
         }
 
       if (lfound)
@@ -259,7 +259,7 @@ intlinarr2(T missval, int lonIsCircular, size_t nxm, size_t nym, const Varray<T>
           // tgt_add, plon, plat, wgts[0], wgts[1], wgts[2], wgts[3], iw, jw);
 
           double fwsum = 0.0;
-          for (int n = 0; n < 4; ++n) fwsum += varray1[src_add[n]] * wgts[n];
+          for (int n = 0; n < 4; ++n) fwsum += varray1[srcIndices[n]] * wgts[n];
           varray2[i] = fwsum;
         }
     }
