@@ -185,26 +185,26 @@ static int point_in_cell_unstruct_triangle(
     cross_edges[2][1] * cross_edges[2][1] +
     cross_edges[2][2] * cross_edges[2][2]};
 
-  normalise_vector(&(cross_edges[0][0]));
-  normalise_vector(&(cross_edges[1][0]));
-  normalise_vector(&(cross_edges[2][0]));
-
-  double sin_point_edge[3] = {
-    cross_edges[0][0] * point_coords[0] +
-    cross_edges[0][1] * point_coords[1] +
-    cross_edges[0][2] * point_coords[2],
-    cross_edges[1][0] * point_coords[0] +
-    cross_edges[1][1] * point_coords[1] +
-    cross_edges[1][2] * point_coords[2],
-    cross_edges[2][0] * point_coords[0] +
-    cross_edges[2][1] * point_coords[1] +
-    cross_edges[2][2] * point_coords[2]};
-
   // if all edges of the triangle have a length of at least yac_angle_tol
   if ((sq_sin_edge[0] > (yac_angle_tol * yac_angle_tol)) &&
       (sq_sin_edge[1] > (yac_angle_tol * yac_angle_tol)) &&
       (sq_sin_edge[2] > (yac_angle_tol * yac_angle_tol))) {
 
+    normalise_vector(&(cross_edges[0][0]));
+    normalise_vector(&(cross_edges[1][0]));
+    normalise_vector(&(cross_edges[2][0]));
+
+    double sin_point_edge[3] = {
+      cross_edges[0][0] * point_coords[0] +
+      cross_edges[0][1] * point_coords[1] +
+      cross_edges[0][2] * point_coords[2],
+      cross_edges[1][0] * point_coords[0] +
+      cross_edges[1][1] * point_coords[1] +
+      cross_edges[1][2] * point_coords[2],
+      cross_edges[2][0] * point_coords[0] +
+      cross_edges[2][1] * point_coords[1] +
+      cross_edges[2][2] * point_coords[2]};
+
     int cell_corner_order =
       cross_edges[0][0] * c[0] + cross_edges[0][1] * c[1] + cross_edges[0][2] * c[2] >= 0;
 
@@ -227,24 +227,39 @@ static int point_in_cell_unstruct_triangle(
         compare_angles(get_vector_angle_2(a, point_coords), SIN_COS_TOL) <= 0;
     // -> triangle is an edge
     else {
+
+      normalise_vector(&(cross_edges[1][0]));
+      double sin_point_edge_1 =
+        cross_edges[1][0] * point_coords[0] +
+        cross_edges[1][1] * point_coords[1] +
+        cross_edges[1][2] * point_coords[2];
+
       struct sin_cos_angle edge_angle =
         sum_angles_no_check(get_vector_angle_2(a, c), SIN_COS_TOL);
       struct sin_cos_angle ap_angle = get_vector_angle_2(a, point_coords);
       struct sin_cos_angle cp_angle = get_vector_angle_2(c, point_coords);
       // point is on the plane of the edge and between b and c
-      return (fabs(sin_point_edge[1]) <= yac_angle_tol) &&
+      return (fabs(sin_point_edge_1) <= yac_angle_tol) &&
              (compare_angles(ap_angle, edge_angle) <= 0) &&
              (compare_angles(cp_angle, edge_angle) <= 0);
     }
 
   // -> triangle is an edge
   } else {
+
+    normalise_vector(&(cross_edges[0][0]));
+
+    double sin_point_edge_0 =
+      cross_edges[0][0] * point_coords[0] +
+      cross_edges[0][1] * point_coords[1] +
+      cross_edges[0][2] * point_coords[2];
+
     struct sin_cos_angle edge_angle =
       sum_angles_no_check(get_vector_angle_2(a, b), SIN_COS_TOL);
     struct sin_cos_angle ap_angle = get_vector_angle_2(a, point_coords);
     struct sin_cos_angle bp_angle = get_vector_angle_2(b, point_coords);
     // point is on the plane of the edge and between b and c
-    return (fabs(sin_point_edge[0]) <= yac_angle_tol) &&
+    return (fabs(sin_point_edge_0) <= yac_angle_tol) &&
            (compare_angles(ap_angle, edge_angle) <= 0) &&
            (compare_angles(bp_angle, edge_angle) <= 0);
   }
@@ -392,17 +407,17 @@ static int point_in_cell_unstruct_quad(
     cross[2][0]*cross[2][0]+cross[2][1]*cross[2][1]+cross[2][2]*cross[2][2],
     cross[3][0]*cross[3][0]+cross[3][1]*cross[3][1]+cross[3][2]*cross[3][2]};
 
-  normalise_vector(&(cross[0][0]));
-  normalise_vector(&(cross[1][0]));
-  normalise_vector(&(cross[2][0]));
-  normalise_vector(&(cross[3][0]));
-
   // if all edges of the quad have a length of at least yac_angle_tol
   if ((sq_sin_edge[0] > (yac_angle_tol * yac_angle_tol)) &&
       (sq_sin_edge[1] > (yac_angle_tol * yac_angle_tol)) &&
       (sq_sin_edge[2] > (yac_angle_tol * yac_angle_tol)) &&
       (sq_sin_edge[3] > (yac_angle_tol * yac_angle_tol))) {
 
+    normalise_vector(&(cross[0][0]));
+    normalise_vector(&(cross[1][0]));
+    normalise_vector(&(cross[2][0]));
+    normalise_vector(&(cross[3][0]));
+
     int tmp = dotproduct(c, cross[0]) >= 0.0;
     tmp += dotproduct(d, cross[0]) >= 0.0;
     tmp += dotproduct(a, cross[1]) >= 0.0;
@@ -516,6 +531,11 @@ int yac_point_in_cell2 (double point_coords[3], struct grid_cell cell,
    if (!yac_point_in_bounding_circle_vec(point_coords, &bnd_circle))
       return 1 == 0;
 
+   // check if the point matches any of cell corners
+   for (size_t i = 0; i < cell.num_corners; ++i)
+     if (points_are_identically(point_coords, cell.coordinates_xyz[i]))
+       return 1;
+
    if ((cell.num_corners == 3) &&
        (cell.edge_type[0] == GREAT_CIRCLE_EDGE) &&
        (cell.edge_type[1] == GREAT_CIRCLE_EDGE) &&
