@@ -32,7 +32,7 @@ ModListOptions::parse_request(const std::string &requestString)
   if (requestString.size() > 0)
     {
       all = false;
-      for (size_t i = 0; i < splitString.size(); ++i)
+      for (size_t i = 0, n = splitString.size(); i < n; ++i)
         {
           auto it = find_module(splitString[i]);
           if (it != get_modules().end())
