@@ -28,7 +28,7 @@ parameter_to_word(const char *cstring)
 
   for (size_t i = 0; i < len; ++i)
     {
-      const int c = cstring[i];
+      int c = cstring[i];
       if (iscntrl(c) || isblank(c)) cdo_abort("Word parameter >%s< contains invalid character at position %zu!", cstring, i + 1);
     }
 
@@ -131,7 +131,7 @@ parameter_to_word(const std::string &string)
 
   for (size_t i = 0; i < len; ++i)
     {
-      const int c = string[i];
+      int c = string[i];
       if (iscntrl(c) || isblank(c)) cdo_abort("Word parameter >%s< contains invalid character at position %zu!", string, i + 1);
     }
 
@@ -191,13 +191,13 @@ radius_str_to_deg(const std::string &string)
 
   if (*endptr != 0)
     {
-      if (strncmp(endptr, "km", 2) == 0)
+      if (std::strncmp(endptr, "km", 2) == 0)
         radius = 360 * ((radius * 1000) / (2 * PlanetRadius * M_PI));
-      else if (strncmp(endptr, "m", 1) == 0)
+      else if (std::strncmp(endptr, "m", 1) == 0)
         radius = 360 * ((radius) / (2 * PlanetRadius * M_PI));
-      else if (strncmp(endptr, "deg", 3) == 0)
+      else if (std::strncmp(endptr, "deg", 3) == 0)
         ;
-      else if (strncmp(endptr, "rad", 3) == 0)
+      else if (std::strncmp(endptr, "rad", 3) == 0)
         radius *= RAD2DEG;
       else
         cdo_abort("Float parameter >%s< contains invalid character at position %d!", string, (int) (endptr - string.c_str() + 1));
@@ -264,8 +264,8 @@ season_to_months(const char *season, int *imonths)
       free(season_u);
       if (sstr != nullptr)
         {
-          const size_t ks = (size_t) (sstr - smons);
-          const size_t ke = ks + len;
+          size_t ks = (size_t) (sstr - smons);
+          size_t ke = ks + len;
           for (size_t k = ks; k < ke; ++k) imonths[imons[k]]++;
         }
       else
@@ -276,7 +276,7 @@ season_to_months(const char *season, int *imonths)
 }
 
 double
-date_str_to_double(const char *datestr, const int opt)
+date_str_to_double(const char *datestr, int opt)
 {
   int year = 1, month = 1, day = 1, hour = 0, minute = 0, second = 0;
   double fval = 0.0;
@@ -285,8 +285,8 @@ date_str_to_double(const char *datestr, const int opt)
 
   for (size_t i = 0; i < len; ++i)
     {
-      const int c = datestr[i];
-      if (!(isdigit(c) || c == '-' || c == ':' || c == '.' || c == 'T'))
+      int c = datestr[i];
+      if (!(std::isdigit(c) || c == '-' || c == ':' || c == '.' || c == 'T'))
         cdo_abort("Date string >%s< contains invalid character at position %zu!", datestr, i + 1);
     }
 
@@ -303,7 +303,7 @@ date_str_to_double(const char *datestr, const int opt)
       auto status = std::sscanf(datestr, "%d-%d-%dT%d:%d:%d", &year, &month, &day, &hour, &minute, &second);
       if (status != 6) cdo_abort("Invalid date string >%s<!", datestr);
       fval = cdiEncodeTime(hour, minute, second);
-      if (std::fabs(fval) > 0) fval /= 1000000;
+      if (std::fabs(fval) > 0.0) fval /= 1000000;
       fval += cdiEncodeDate(year, month, day);
     }
   else
@@ -311,7 +311,7 @@ date_str_to_double(const char *datestr, const int opt)
       auto status = std::sscanf(datestr, "%d-%d-%d", &year, &month, &day);
       if (status != 3) cdo_abort("Invalid date string >%s<!", datestr);
       fval = cdiEncodeTime(hour, minute, second);
-      if (std::fabs(fval) > 0) fval /= 1000000;
+      if (std::fabs(fval) > 0.0) fval /= 1000000;
       fval += cdiEncodeDate(year, month, day);
     }
 
@@ -352,7 +352,7 @@ cdo_argv_to_flt(const std::vector<std::string> &argv)
       auto len = (int) argument.size();
       int i;
       for (i = 0; i < len; ++i)
-        if (argument[i] != '/' && argument[i] != '-' && !isdigit(argument[i])) break;
+        if (argument[i] != '/' && argument[i] != '-' && !std::isdigit(argument[i])) break;
 
       if (i != len) { v.push_back(parameter_to_double(argument)); }
       else
