@@ -79,7 +79,7 @@ append(std::shared_ptr<T> &parent, std::shared_ptr<T> &child)
 
 // Factory Funcs!
 std::string
-err_msg_oper_not_found(std::string name)
+err_msg_oper_not_found(const std::string &name)
 {
   auto similarOperators = find_similar_operators(name);
   if (similarOperators.size()) similarOperators = "\nSimilar operators: " + similarOperators;
@@ -247,6 +247,7 @@ handle_node(Parser &parser, ARGV_ITERATOR &cur_arg)
       std::shared_ptr<Node> &parent = parser.top();
       debug_parser("adding %s as leaf to %s", node->oper, parent->oper);
       Util::append(parent, node);
+      if(parent->is_done()) parser.pop();
     }
   else
     {
