@@ -26,6 +26,8 @@
 #include "cdo_options.h"
 #include "cdo_default_values.h"
 #include "process.h"
+#include "cdo_output.h"
+#include "factory.h"
 
 thread_local Process *localProcess;
 static int NumProcessActive = 0;
@@ -51,7 +53,7 @@ process_self(void)
 void
 process_def_var_num(int nvars)
 {
-  localProcess->nvars += nvars;
+  localProcess->m_nvars += nvars;
 }
 
 /* cdoStreamInqTimeStep(...)
@@ -372,6 +374,8 @@ extern "C" size_t getPeakRSS();
 void
 cdo_finish(void)
 {
+  assert(((void) "Internal error: module not initialized!", (localProcess != nullptr)));
+
   Debug(PROCESS_INT, "Finishing process: %d", localProcess->m_ID);
 
 #ifdef HAVE_LIBPTHREAD
@@ -393,12 +397,6 @@ cdo_stream_close(CdoStreamID pstreamPtr)
   pstreamPtr->close();
 }
 
-void
-cdo_close_streams()
-{
-  localProcess->close_streams();
-}
-
 /******************************************************************/
 /* Functions that only work on streamID's and do not need process */
 /******************************************************************/
