@@ -161,7 +161,7 @@ void remap_search_init(RemapMethod mapType, RemapSearch &search, RemapGrid &srcG
 void remap_search_free(RemapSearch &search);
 
 void remap_search_points(RemapSearch &rsearch, const LonLatPoint &llpoint, knnWeightsType &knnWeights);
-int remap_search_square(RemapSearch &rsearch, const LonLatPoint &llpoint, size_t (&src_add)[4], double (&srcLats)[4],
+int remap_search_square(RemapSearch &rsearch, const LonLatPoint &llpoint, size_t (&srcIndices)[4], double (&srcLats)[4],
                         double (&srcLons)[4]);
 size_t remap_search_cells(RemapSearch &rsearch, bool isReg2dCell, GridCell &gridCell, Varray<size_t> &srchAddr);
 
@@ -173,7 +173,7 @@ void remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv);
 
 void remap_bilinear(RemapSearch &rsearch, const Field &field1, Field &field2);
 void remap_bicubic(RemapSearch &rsearch, const Field &field1, Field &field2);
-void remap_dist_wgt(size_t numNeighbors, RemapSearch &rsearch, const Field &field1, Field &field2);
+void remap_distwgt(size_t numNeighbors, RemapSearch &rsearch, const Field &field1, Field &field2);
 void remap_conserv(NormOpt normOpt, RemapSearch &rsearch, const Field &field1, Field &field2);
 
 void remap_stat(int remapOrder, RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv, const Field &field1, const Field &field2);
@@ -182,8 +182,8 @@ template <typename T>
 void remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<T> &array, RemapGradients &gradients);
 void remap_gradients(RemapGrid &grid, const Field &field, RemapGradients &gradients);
 
-void sort_add(size_t numLinks, size_t num_wts, size_t *add1, size_t *add2, double *weights);
-void sort_iter(size_t numLinks, size_t num_wts, size_t *add1, size_t *add2, double *weights, int parent);
+void sort_add(size_t numLinks, size_t numWeights, size_t *add1, size_t *add2, double *weights);
+void sort_iter(size_t numLinks, size_t numWeights, size_t *add1, size_t *add2, double *weights, int parent);
 
 void remap_write_data_scrip(const char *weightsfile, const RemapSwitches &remapSwitches, RemapGrid &srcGrid, RemapGrid &tgtGrid,
                             RemapVars &rv);
@@ -192,18 +192,18 @@ RemapSwitches remap_read_data_scrip(const std::string &weightsfile, int gridID1,
 
 void calc_lat_bins(GridSearchBins &searchBins);
 size_t get_srch_cells(size_t tgtCellIndex, GridSearchBins &tgtBins, GridSearchBins &srcBins, float *tgt_cell_bound_box,
-                      Varray<size_t> &srch_add);
+                      Varray<size_t> &srchIndices);
 
-int grid_search_square_reg_2d_NN(size_t nx, size_t ny, size_t *nbr_add, double *nbr_dist, double plat, double plon,
+int grid_search_square_reg_2d_NN(size_t nx, size_t ny, size_t *nbrIndices, double *nbrDistance, double plat, double plon,
                                  const Varray<double> &src_center_lat, const Varray<double> &src_center_lon);
 
-int grid_search_square_reg_2d(RemapGrid *srcGrid, size_t (&src_add)[4], double (&srcLats)[4], double (&srcLons)[4], double plat,
+int grid_search_square_reg_2d(RemapGrid *srcGrid, size_t (&srcIndices)[4], double (&srcLats)[4], double (&srcLons)[4], double plat,
                               double plon);
 
-bool point_in_quad(bool isCyclic, size_t nx, size_t ny, size_t i, size_t j, size_t adds[4], double lons[4], double lats[4],
+bool point_in_quad(bool isCyclic, size_t nx, size_t ny, size_t i, size_t j, size_t indices[4], double lons[4], double lats[4],
                    double plon, double plat, const double *centerLon, const double *centerLat);
 
-int grid_search_square_curv_2d_scrip(RemapGrid *srcGrid, size_t (&src_add)[4], double (&srcLats)[4], double (&srcLons)[4],
+int grid_search_square_curv_2d_scrip(RemapGrid *srcGrid, size_t (&srcIndices)[4], double (&srcLats)[4], double (&srcLons)[4],
                                      double plat, double plon, GridSearchBins &srcBins);
 
 std::pair<double, double> remap_find_weights(const LonLatPoint &llpoint, const double (&srcLons)[4], const double (&srcLats)[4]);
