@@ -170,7 +170,7 @@ remap_bilinear_weights_regular(RemapSearch &rsearch, const Varray<short> &srcGri
   double srcLats[4];  //  latitudes  of four bilinear corners
   double srcLons[4];  //  longitudes of four bilinear corners
   double weights[4];  //  bilinear weights for four corners
-  size_t indices[4];  //  address for the four source points
+  size_t indices[4];  //  indices for the four source points
 
   // Find nearest square of grid points on source grid
   auto searchResult = remap_search_square(rsearch, llpoint, indices, srcLats, srcLons);
@@ -220,7 +220,7 @@ remap_bilinear_weights_healpix(const RemapSearch &rsearch, const Varray<short> &
   auto order = rsearch.srcGrid->order;
 
   double weights[4];  //  bilinear weights for four corners
-  size_t indices[4];  //  address for the four source points
+  size_t indices[4];  //  indices for the four source points
 
   hp_bilinear_interpolate_weights(llpoint.lon, llpoint.lat, indices, weights, nside, order);
 
@@ -239,7 +239,7 @@ remap_bilinear_weights_healpix(const RemapSearch &rsearch, const Varray<short> &
 void
 remap_bilinear_weights(RemapSearch &rsearch, RemapVars &rv)
 {
-  auto srcGrid = rsearch.srcGrid;
+  const auto srcGrid = rsearch.srcGrid;
   auto tgtGrid = rsearch.tgtGrid;
 
   auto isHealpixGrid = (srcGrid->type == RemapGridType::HealPix);
@@ -289,6 +289,8 @@ remap_bilinear_weights(RemapSearch &rsearch, RemapVars &rv)
 
   weight_links_to_remap_links(0, tgtGridSize, weightLinks, rv);
 
+  rv.linksPerValue = 4;
+
   if (Options::cdoVerbose) cdo_print("%s: %.2f seconds", __func__, timer.elapsed());
 }  // remap_bilinear_weights
 
@@ -310,7 +312,7 @@ remap_bilinear_regular(RemapSearch &rsearch, const Varray<T> &srcArray, const Va
   double srcLats[4];  //  latitudes  of four bilinear corners
   double srcLons[4];  //  longitudes of four bilinear corners
   double weights[4];  //  bilinear weights for four corners
-  size_t indices[4];  //  address for the four source points
+  size_t indices[4];  //  indices for the four source points
 
   // Find nearest square of grid points on source grid
   auto searchResult = remap_search_square(rsearch, llpoint, indices, srcLats, srcLons);
@@ -360,7 +362,7 @@ remap_bilinear_healpix(const RemapSearch &rsearch, const Varray<T> &srcArray, co
   auto order = rsearch.srcGrid->order;
 
   double weights[4];  //  bilinear weights for four corners
-  size_t indices[4];  //  address for the four source points
+  size_t indices[4];  //  indices for the four source points
 
   hp_bilinear_interpolate_weights(llpoint.lon, llpoint.lat, indices, weights, nside, order);
 
@@ -379,7 +381,7 @@ template <typename T>
 static void
 remap_bilinear(RemapSearch &rsearch, const Varray<T> &srcArray, Varray<T> &tgtArray, T missval, size_t nmiss)
 {
-  auto srcGrid = rsearch.srcGrid;
+  const auto srcGrid = rsearch.srcGrid;
   auto tgtGrid = rsearch.tgtGrid;
 
   auto isHealpixGrid = (srcGrid->type == RemapGridType::HealPix);
