@@ -6,7 +6,7 @@
 */
 
 #include "process_int.h"
-#include "cdo_wtime.h"
+#include "cdo_timer.h"
 #include "remap.h"
 #include "remap_store_link_cnsrv.h"
 #include "cdo_options.h"
@@ -996,14 +996,14 @@ correct_pole(RemapGrid *srcGrid, RemapGrid *tgtGrid, RemapVars &rv, std::vector<
      grid.  If missing from both, do complete weight calculation.
   */
   long n;
-  long num_wts;
+  long numWeights;
   long srcGridSize;
   long tgtGridSize;
   long srcCellIndex; /* current linear address for source grid cell   */
   long tgtCellIndex; /* current linear address for target grid cell   */
   double weights[6]; /* local wgt array */
 
-  num_wts = rv.num_wts;
+  numWeights = rv.numWeights;
 
   srcGridSize = srcGrid->size;
   tgtGridSize = tgtGrid->size;
@@ -1050,7 +1050,7 @@ correct_pole(RemapGrid *srcGrid, RemapGrid *tgtGrid, RemapVars &rv, std::vector<
 
   if (srcCellIndex != srcGridSize && tgtCellIndex != tgtGridSize)
     {
-      store_link_cnsrv(rv, srcCellIndex, tgtCellIndex, num_wts, weights, grid_store);
+      store_link_cnsrv(rv, srcCellIndex, tgtCellIndex, numWeights, weights, grid_store);
 
       srcGrid->cell_frac[srcCellIndex] += weights[0];
       tgtGrid->cell_frac[tgtCellIndex] += weights[3];
@@ -1098,7 +1098,7 @@ correct_pole(RemapGrid *srcGrid, RemapGrid *tgtGrid, RemapVars &rv, std::vector<
 
   if (srcCellIndex != srcGridSize && tgtCellIndex != tgtGridSize)
     {
-      store_link_cnsrv(rv, srcCellIndex, tgtCellIndex, num_wts, weights, grid_store);
+      store_link_cnsrv(rv, srcCellIndex, tgtCellIndex, numWeights, weights, grid_store);
 
       srcGrid->cell_frac[srcCellIndex] += weights[0];
       tgtGrid->cell_frac[tgtCellIndex] += weights[3];
@@ -1125,7 +1125,7 @@ normalize_weights(RemapGrid *tgtGrid, RemapVars &rv, std::vector<double> &src_ce
   long numLinks = rv.numLinks;
   // srcCellIndex: current linear address for source grid cell
   // tgtCellIndex: current linear address for target grid cell
-  double *weights = &rv.wts[0];
+  double *weights = &rv.weights[0];
 
   if (rv.normOpt == NormOpt::DESTAREA)
     {
@@ -1223,7 +1223,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
 
   progress::init();
 
-  long num_wts = rv.num_wts;
+  long numWeights = rv.numWeights;
 
   GridStore grid_store;
   grid_store_init(grid_store, tgtGrid->size);
@@ -1234,7 +1234,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
       cdo_print("South threshhold: %g", south_thresh);
     }
 
-  double start = Options::cdoVerbose ? cdo_get_wtime() : 0;
+  cdo::timer timer;
 
   long srcGridSize = srcGrid->size;
   long tgtGridSize = tgtGrid->size;
@@ -1280,7 +1280,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
   srch_corners = tgtNumCorners;
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(findex, rsearch, num_wts, src_centroid_lon, src_centroid_lat, grid_store, rv,      \
+#pragma omp parallel for default(none) shared(findex, rsearch, numWeights, src_centroid_lon, src_centroid_lat, grid_store, rv,      \
                                               Options::cdoVerbose, max_subseg, srch_corner_lat, srch_corner_lon, maxSearchCells, \
                                               srcNumCorners, srch_corners, srcGrid, tgtGrid, tgtGridSize, srcGridSize, srch_add)
 #endif
@@ -1430,7 +1430,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
 #pragma omp critical
 #endif
                     {
-                      store_link_cnsrv(rv, srcCellIndex, tgtCellIndex, num_wts, weights, grid_store);
+                      store_link_cnsrv(rv, srcCellIndex, tgtCellIndex, numWeights, weights, grid_store);
 
                       tgtGrid->cell_frac[tgtCellIndex] += weights[3];
                     }
@@ -1467,7 +1467,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
   findex = 0;
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(findex, rsearch, num_wts, tgt_centroid_lon, tgt_centroid_lat, grid_store, rv,      \
+#pragma omp parallel for default(none) shared(findex, rsearch, numWeights, tgt_centroid_lon, tgt_centroid_lat, grid_store, rv,      \
                                               Options::cdoVerbose, max_subseg, srch_corner_lat, srch_corner_lon, maxSearchCells, \
                                               tgtNumCorners, srch_corners, srcGrid, tgtGrid, tgtGridSize, srcGridSize, srch_add)
 #endif
@@ -1618,7 +1618,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
 #pragma omp critical
 #endif
                     {
-                      store_link_cnsrv(rv, srcCellIndex, tgtCellIndex, num_wts, weights, grid_store);
+                      store_link_cnsrv(rv, srcCellIndex, tgtCellIndex, numWeights, weights, grid_store);
 
                       srcGrid->cell_frac[srcCellIndex] += weights[0];
                     }
@@ -1687,24 +1687,24 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
 
       if ( Options::cdoVerbose )
         for ( long n = 0; n < numLinks; n++ )
-          printf("wts1: %d %g\n", n, rv.wts[3*n]);
+          printf("weights1: %d %g\n", n, rv.weights[3*n]);
 
       for ( long n = 0; n < numLinks; n++ )
         {
-          if ( rv.wts[3*n] < 0 )
+          if ( rv.weights[3*n] < 0 )
             {
               int i, n2, nd;
 
               for ( n2 = n+1; n2 < numLinks; n2++ )
-                if ( rv.wts[3*n2] >= 0 ) break;
+                if ( rv.weights[3*n2] >= 0 ) break;
 
               nd = n2-n;
               numLinks -= nd;
               for ( i = n; i < numLinks; i++ )
                 {
-                  rv.wts[3*i]   = rv.wts[3*(i+nd)];
-                  rv.wts[3*i+1] = rv.wts[3*(i+nd)+1];
-                  rv.wts[3*i+2] = rv.wts[3*(i+nd)+2];
+                  rv.weights[3*i]   = rv.weights[3*(i+nd)];
+                  rv.weights[3*i+1] = rv.weights[3*(i+nd)+1];
+                  rv.weights[3*i+2] = rv.weights[3*(i+nd)+2];
 
                   rv.srcCellIndices[i] = rv.srcCellIndices[i+nd];
                   rv.tgtCellIndices[i] = rv.tgtCellIndices[i+nd];
@@ -1761,11 +1761,11 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
       for (long n = 0; n < numLinks; ++n)
         {
           long tgtCellIndex = rv.tgtCellIndices[n];
-          tgt_centroid_lat[tgtCellIndex] += rv.wts[3 * n];
+          tgt_centroid_lat[tgtCellIndex] += rv.weights[3 * n];
         }
 
       /* 2012-01-24 Uwe Schulzweida: changed [tgtCellIndex] to [n] (bug fix) */
-      double norm_factor = 0;  // factor for normalizing wts
+      double norm_factor = 0;  // factor for normalizing weights
       for (long n = 0; n < tgtGridSize; ++n)
         {
           if (rv.normOpt == NormOpt::DESTAREA)
@@ -1776,9 +1776,9 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
             norm_factor = tgtGrid->cell_area[n];
 
           if (tgt_centroid_lat[n] > 0 && std::fabs(tgt_centroid_lat[n] - norm_factor) > .01)
-            cdo_print("Error: sum of wts for map1 %ld %g %g", n, tgt_centroid_lat[n], norm_factor);
+            cdo_print("Error: sum of weights for map1 %ld %g %g", n, tgt_centroid_lat[n], norm_factor);
         }
     }  // lcheck
 
-  if (Options::cdoVerbose) cdo_print("Cells search: %.2f seconds", cdo_get_wtime() - start);
+  if (Options::cdoVerbose) cdo_print("Cells search: %.2f seconds", timer.elapsed());
 }  // remap_conserv_weights_scrip
