@@ -42,9 +42,9 @@ bool is_sorted_list(size_t n, const size_t *list);
 
 void weight_links_alloc(size_t numNeighbors, size_t gridSize, std::vector<WeightLinks> &weightLinks);
 void weight_links_4_alloc(size_t gridSize, std::vector<WeightLinks4> &weightLinks);
-void store_weightlinks(int doAlloc, size_t numWeights, size_t *indices, double *weights, size_t cellIndex,
+void store_weightlinks(int doAlloc, size_t numWeights, const size_t *indices, const double *weights, size_t cellIndex,
                        std::vector<WeightLinks> &weightLinks);
-void store_weightlinks_bicubic(size_t *indices, double (&weights)[4][4], size_t cellIndex, std::vector<WeightLinks4> &weightLinks);
+void store_weightlinks_bicubic(const size_t *indices, double (&weights)[4][4], size_t cellIndex, std::vector<WeightLinks4> &weightLinks);
 void weight_links_to_remap_links(int doAlloc, size_t gridSize, std::vector<WeightLinks> &weightLinks, RemapVars &rv);
 void weight_links_4_to_remap_links(size_t gridSize, std::vector<WeightLinks4> &weightLinks, RemapVars &rv);
 
