@@ -874,7 +874,7 @@ remap_stat(int remapOrder, RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv
       cdo_print("  Grid2 Integral = %g", sum);
     }
 
-  cdo_print("  Number of weights %zu", rv.num_wts);
+  cdo_print("  Number of weights %zu", rv.numWeights);
   cdo_print("  Number of sparse matrix entries %zu", rv.numLinks);
   cdo_print("  Total number of dest cells %zu", tgtGrid.size);
 
