@@ -161,7 +161,7 @@ remap_heapsort(const size_t numLinks, size_t *add1, size_t *add2, size_t *idx)
 }
 
 void
-sort_add(size_t numLinks, size_t num_wts, size_t *add1, size_t *add2, double *weights)
+sort_add(size_t numLinks, size_t numWeights, size_t *add1, size_t *add2, double *weights)
 {
   /*
     This routine sorts address and weight arrays based on the destination
@@ -172,10 +172,10 @@ sort_add(size_t numLinks, size_t num_wts, size_t *add1, size_t *add2, double *we
     Input and Output arrays:
 
        long numLinks  ! num of links for this mapping
-       long num_wts    ! num of weights for this mapping
+       long numWeights    ! num of weights for this mapping
        add1            ! destination address array [numLinks]
        add2            ! source      address array
-       weights         ! remapping weights [numLinks*num_wts]
+       weights         ! remapping weights [numLinks*numWeights]
   */
 
   if (numLinks <= 1) return;
@@ -185,11 +185,11 @@ sort_add(size_t numLinks, size_t num_wts, size_t *add1, size_t *add2, double *we
 
   remap_heapsort(numLinks, add1, add2, &idx[0]);
 
-  std::vector<double> wgt_tmp(num_wts * numLinks);
-  memcpy(&wgt_tmp[0], weights, num_wts * numLinks * sizeof(double));
+  std::vector<double> wgt_tmp(numWeights * numLinks);
+  memcpy(&wgt_tmp[0], weights, numWeights * numLinks * sizeof(double));
 
   for (size_t i = 0; i < numLinks; ++i)
-    for (size_t n = 0; n < num_wts; ++n) weights[num_wts * i + n] = wgt_tmp[num_wts * idx[i] + n];
+    for (size_t n = 0; n < numWeights; ++n) weights[numWeights * i + n] = wgt_tmp[numWeights * idx[i] + n];
 
   if (Options::cdoVerbose)
     if (!isSorted(add1, add2, numLinks)) fprintf(stderr, ">>>> sort_add failed!!!\n");
@@ -267,7 +267,7 @@ merge_lists(size_t *nl, size_t *l11, size_t *l12, size_t *l21, size_t *l22, size
 }
 
 static void
-sort_par(size_t numLinks, size_t num_wts, size_t *add1, size_t *add2, double *weights, int parent, int par_depth)
+sort_par(size_t numLinks, size_t numWeights, size_t *add1, size_t *add2, double *weights, int parent, int par_depth)
 {
   /*
     This routine is the core of merge-sort. It does the following
@@ -371,15 +371,15 @@ sort_par(size_t numLinks, size_t num_wts, size_t *add1, size_t *add2, double *we
 //	       who_am_i,parent,my_depth,omp_get_thread_num()+1,omp_get_num_threads());
 #endif
 
-      std::vector<double> wgttmp(num_wts * nl[i]);
+      std::vector<double> wgttmp(numWeights * nl[i]);
 
       for (m = 0; m < nl[i]; ++m)
-        for (n = 0; n < num_wts; ++n) wgttmp[num_wts * m + n] = weights[num_wts * (add_srt[i] + m) + n];
+        for (n = 0; n < numWeights; ++n) wgttmp[numWeights * m + n] = weights[numWeights * (add_srt[i] + m) + n];
 
-      sort_iter(nl[i], num_wts, add1s[i], add2s[i], &wgttmp[0], who_am_i);
+      sort_iter(nl[i], numWeights, add1s[i], add2s[i], &wgttmp[0], who_am_i);
 
       for (m = 0; m < nl[i]; ++m)
-        for (n = 0; n < num_wts; ++n) weights[num_wts * (add_srt[i] + m) + n] = wgttmp[num_wts * m + n];
+        for (n = 0; n < numWeights; ++n) weights[numWeights * (add_srt[i] + m) + n] = wgttmp[numWeights * m + n];
     }
 
   /* ********************************* */
@@ -414,24 +414,24 @@ sort_par(size_t numLinks, size_t num_wts, size_t *add1, size_t *add2, double *we
   }
 
   {
-    std::vector<double> tmp(numLinks * num_wts);
+    std::vector<double> tmp(numLinks * numWeights);
 
 #ifdef _OPENMP
 #pragma omp parallel for if (depth < par_depth) private(i, n) num_threads(2)
 #endif
     for (i = 0; i < numLinks; ++i)
-      for (n = 0; n < num_wts; ++n) tmp[num_wts * i + n] = weights[num_wts * idx[i] + n];
+      for (n = 0; n < numWeights; ++n) tmp[numWeights * i + n] = weights[numWeights * idx[i] + n];
 
 #ifdef _OPENMP
 #pragma omp parallel for if (depth < par_depth) private(i, n) num_threads(2)
 #endif
     for (i = 0; i < numLinks; ++i)
-      for (n = 0; n < num_wts; ++n) weights[num_wts * i + n] = tmp[num_wts * i + n];
+      for (n = 0; n < numWeights; ++n) weights[numWeights * i + n] = tmp[numWeights * i + n];
   }
 }
 
 void
-sort_iter(size_t numLinks, size_t num_wts, size_t *add1, size_t *add2, double *weights, int parent)
+sort_iter(size_t numLinks, size_t numWeights, size_t *add1, size_t *add2, double *weights, int parent)
 {
   /*
     This routine is an interface between the parallelized (merge-sort)
@@ -471,12 +471,12 @@ sort_iter(size_t numLinks, size_t num_wts, size_t *add1, size_t *add2, double *w
 
   if (numLinks > MERGE_SORT_LIMIT_SIZE && parent <= (nthreads - 1))
     {
-      sort_par(numLinks, num_wts, add1, add2, weights, parent, par_depth);
+      sort_par(numLinks, numWeights, add1, add2, weights, parent, par_depth);
       if (Options::cdoVerbose) fprintf(stderr, "sort_iter: Finished iteration parent %i\n", parent);
     }
   else
     {
       // printf("sort_add: parent %d, par_depth %d numLinks %tz\n", parent, par_depth, numLinks);
-      sort_add(numLinks, num_wts, add1, add2, weights);
+      sort_add(numLinks, numWeights, add1, add2, weights);
     }
 }
