@@ -11,8 +11,7 @@
 #include "table.h"
 #include "cdo_output.h"
 #include "util_files.h"
-
-std::string getenv_string(const std::string &envVar);
+#include "util_string.h"
 
 namespace cdo
 {
@@ -29,7 +28,7 @@ define_table(const std::string &tablearg)
       const auto &tablepath = getenv_string("CD_TABLEPATH");
       if (tablepath.size())
         {
-          auto tablefile = tablepath + "/" + tablename;
+          std::string tablefile = tablepath + "/" + tablename;
           if (FileUtils::file_exists(tablefile)) tableID = tableRead(tablefile.c_str());
         }
     }
