@@ -17,6 +17,15 @@
 #include <cdi.h>
 #include "util_string.h"
 
+std::string
+getenv_string(const std::string &envVar)
+{
+  std::string envString;
+  auto envCstring = getenv(envVar.c_str());
+  if (envCstring) envString = envCstring;
+  return envString;
+}
+
 std::vector<std::string>
 split_string(const std::string &str, const std::string &delimiter)
 {
@@ -57,7 +66,7 @@ trim_flt(char *ss)
 {
   char *cp = ss;
   if (*cp == '-') cp++;
-  while (isdigit((int) *cp) || *cp == '.') cp++;
+  while (std::isdigit((int) *cp) || *cp == '.') cp++;
   if (*--cp == '.') return;
 
   char *ep = cp + 1;
