@@ -37,13 +37,13 @@ const auto unary_op_atan  = [](double x) noexcept { return std::atan(x); };
 
 // binary operators
 // clang-format off
-const auto binary_op_LT  = [](double x, double y) noexcept { return x < y; };
-const auto binary_op_GT  = [](double x, double y) noexcept { return x > y; };
-const auto binary_op_LE  = [](double x, double y) noexcept { return x <= y; };
-const auto binary_op_GE  = [](double x, double y) noexcept { return x >= y; };
-const auto binary_op_NE  = [](double x, double y) noexcept { return is_not_equal(x, y); };
-const auto binary_op_EQ  = [](double x, double y) noexcept { return is_equal(x, y); };
-const auto binary_op_LEG = [](double x, double y) noexcept { return (x < y) ? -1.0 : (x > y); };
+const auto binary_op_LT  = [](auto x, auto y) noexcept { return x < y; };
+const auto binary_op_GT  = [](auto x, auto y) noexcept { return x > y; };
+const auto binary_op_LE  = [](auto x, auto y) noexcept { return x <= y; };
+const auto binary_op_GE  = [](auto x, auto y) noexcept { return x >= y; };
+const auto binary_op_NE  = [](auto x, auto y) noexcept { return is_not_equal(x, y); };
+const auto binary_op_EQ  = [](auto x, auto y) noexcept { return is_equal(x, y); };
+const auto binary_op_LEG = [](auto x, auto y) noexcept { return (x < y) ? -1.0 : (x > y); };
 const auto binary_op_AND = [](double x, double y) noexcept { return is_not_equal(x, 0.0) && is_not_equal(y, 0.0); };
 const auto binary_op_OR  = [](double x, double y) noexcept { return is_not_equal(x, 0.0) || is_not_equal(y, 0.0); };
 const auto binary_op_POW = [](double x, double y) noexcept { return std::pow(x, y); };
