@@ -268,6 +268,18 @@ go_bandit([]() {
               "-inVariable_out1", "file3", "out" },
             "out [ in2_out1 [ inVariable_out1 [ file1 file2 ] inVariable_out1 "
             "[ file3 ] ] ]");
+
+      check("handles preceeding operator of finished variable input correctly "
+            "variable input at the end",
+            { "-in2_out1", "-inVariable_out1", "[", "file1", "file2", "]",
+              "-inVariable_out1", "file3", "out" },
+            "out [ in2_out1 [ inVariable_out1 [ file1 file2 ] inVariable_out1 "
+            "[ file3 ] ] ]");
+      check("handles preceeding operator of finished variable input correctly when positioned between in2out1 and variable",
+            { "-in2_out1", "-in1_out1", "-inVariable_out1", "[", "file1", "file2", "]",
+              "-inVariable_out1", "file3", "out" },
+            "out [ in2_out1 [ in1_out1 [ inVariable_out1 [ file1 file2 ] ] inVariable_out1 "
+            "[ file3 ] ] ]");
     });
 
     bandit::describe("Apply feature", [&]() {
